@@ -8,7 +8,7 @@
 /*
   This file is part of code_saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2023 EDF S.A.
+  Copyright (C) 1998-2025 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -32,7 +32,11 @@
  *============================================================================*/
 
 #if defined(HAVE_CONFIG_H)
-#  include "cs_config.h"
+#  include "base/cs_config.h"
+#endif
+
+#ifdef __cplusplus
+#include <type_traits>
 #endif
 
 /*============================================================================
@@ -111,6 +115,8 @@ extern "C" {
 
 #if defined(HAVE_CUDA)
 #define HAVE_ACCEL 1
+#elif defined(HAVE_SYCL)
+#define HAVE_ACCEL 1
 #elif defined(HAVE_OPENMP_TARGET)
 #define HAVE_ACCEL 1
 #endif
@@ -146,12 +152,28 @@ extern "C" {
 
 #else /* C++ */
 
-#  ifndef HAVE_RESTRICT /* Must be provided by caller */
-#    define restrict
+#  if defined(__GNUC__) || defined(__clang__) || defined (__NVCC__)
+#    define restrict __restrict__
+#  elif defined(_MSC_VER)
+#    define restrict __restrict
+#  else
+#    ifndef HAVE_RESTRICT /* Must be provided by caller */
+#      define restrict
+#    endif
 #  endif
 
 #endif /* __cplusplus */
 
+/* Definition of a DEPRECATED decorator which may be called in the code */
+
+#if defined(__GNUC__) || defined(__clang__)
+#  define DEPRECATED __attribute__((deprecated))
+#elif defined(_MSC_VER)
+#  define DEPRECATED __declspec(deprecated)
+#else
+#  define DEPRECATED
+#endif
+
 /*============================================================================
  * Definitions that may not always be provided directly by the system
  *============================================================================*/
@@ -205,6 +227,12 @@ extern "C" {
 #  define __bool_true_false_are_defined 1
 #endif
 
+/* C++ assert necessary for template */
+#if defined(__cplusplus)
+#include <typeinfo>
+#include "assert.h"
+#endif
+
 /* int32_t type */
 
 #if !defined(HAVE_INT32_T)
@@ -257,6 +285,21 @@ typedef unsigned long long uint64_t;
 #  endif
 #endif
 
+/* __has_builtin is missing in some cases (e.g. nvcc) */
+
+#ifndef __has_builtin
+  #define __has_builtin(x) 0
+#endif
+
+/* Legacy Intel compiler (retired) reports having
+ *  __builtin_FILE() and __builtin_LINE() but generates code calling
+ *  nonexisting functions with those names, leading to link errors. */
+#if defined(__INTEL_COMPILER)
+#  if __INTEL_COMPILER <= 2000
+#    define __has_builtin(x) 0
+#  endif
+#endif
+
 /*============================================================================
  * General types and macros used throughout code_saturne
  *============================================================================*/
@@ -297,13 +340,7 @@ typedef enum {
 /* Global integer index or number */
 
 #if defined(HAVE_LONG_GNUM)
-  #if (SIZEOF_LONG == 8)
-    typedef unsigned long       cs_gnum_t;
-  #elif (SIZEOF_LONG_LONG == 8)
-    typedef unsigned long long  cs_gnum_t;
-  #else
-    #error
-  #endif
+  typedef uint64_t  cs_gnum_t;
 #else
   typedef unsigned  cs_gnum_t;
 #endif
@@ -311,19 +348,22 @@ typedef enum {
 /* Local integer index or number */
 
 #if defined(HAVE_LONG_LNUM)
-  typedef long  cs_lnum_t;
+  typedef int64_t  cs_lnum_t;
 #else
-  typedef int   cs_lnum_t;
+  typedef int  cs_lnum_t;
 #endif
 
 /* Other types */
-typedef double            cs_coord_t;  /* Real number (coordinate value) */
+
+typedef double             cs_coord_t;   /* Real number (coordinate value) */
 
 typedef double              cs_real_t;   /* Fortran double precision */
 typedef char                cs_byte_t;   /* Byte (untyped memory unit) */
 typedef unsigned short int  cs_flag_t;   /* Flag storing metadata */
 
 typedef double              cs_nreal_t;  /* Real number (normalized value) */
+typedef double              cs_dreal_t;  /* Local distance */
+typedef double              cs_rreal_t;  /* Reconstruction distance */
 
 /* Vector or array block types */
 
@@ -362,6 +402,8 @@ typedef cs_real_66_t  cs_real_662_t[2];     /* vector of 2 6x6 matrices
 
 typedef cs_nreal_t  cs_nreal_3_t[3];        /* Vector of normalized real values
                                                (i.e. unit vector) */
+typedef cs_dreal_t  cs_dreal_3_t[3];        /* Vector joining 2 local coordinates */
+typedef cs_rreal_t  cs_rreal_3_t[3];        /* Reconstruction distance Vector */
 
 typedef struct {
 
@@ -372,6 +414,7 @@ typedef struct {
 
 /* Vector-valued quantity stored using its measure (i.e. length) and
    its direction given by a unitary vector */
+
 typedef struct {
 
   double  meas;
@@ -519,34 +562,47 @@ typedef enum {
 #endif
 
 /*----------------------------------------------------------------------------
- * Macros for Fortran interoperability
+ * Macro to check if we are compiling for device
  *----------------------------------------------------------------------------*/
 
-/*
- * Macro for handling of different symbol names (underscored or not,
- * lowercase or uppercase) between C and Fortran, for link resolution.
- */
-
-#if !defined (__hpux)
-#define CS_PROCF(x, y) x##_
-#else
-#define CS_PROCF(x, y) x
+#if defined(__CUDA_ARCH__) || defined(__HIP_DEVICE_COMPILE__) \
+  || defined(__SYCL_DEVICE_ONLY__)
+#define CS_DEVICE_COMPILE
 #endif
 
-/*
- * Macro used to handle automatic "Fortran string length" arguments
- * (not used by code_saturne calls, but set by many compilers).
- * Some compilers may not
- * support the variable length lists in mixed C/Fortran calls.
- */
+/*----------------------------------------------------------------------------
+ * Macros for function type qualifiers
+ *----------------------------------------------------------------------------*/
 
-#define CS_ARGF_SUPP_CHAINE , ...
+#ifdef __CUDACC__
+
+#define CS_F_HOST __host__
+#define CS_F_DEVICE __device__
+#define CS_F_HOST_DEVICE __host__ __device__
+#define CS_V_CONSTANT __constant__
+
+#else
+
+#define CS_F_HOST
+#define CS_F_DEVICE
+#define CS_F_HOST_DEVICE
+#define CS_V_CONSTANT static const
+
+#endif
+
+/*----------------------------------------------------------------------------
+ * Macros for lambda specifiers
+ *----------------------------------------------------------------------------*/
+
+#define CS_LAMBDA [=] CS_F_HOST_DEVICE
+#define CS_HOST_LAMBDA [=] CS_F_HOST
+#define CS_CLASS_LAMBDA [=, *this] CS_F_HOST_DEVICE
 
 /*=============================================================================
  * Global variables
  *============================================================================*/
 
-/* Empty but non-NULL string */
+/* Empty but non-null string */
 
 extern const char     cs_empty_string[];
 
@@ -590,7 +646,7 @@ extern MPI_Comm       cs_glob_mpi_comm;      /* Main MPI intra-communicator */
  *
  * \param[in, out]  s  pointer to a structure cast on-the-fly
  *
- * \return a NULL pointer
+ * \return a null pointer
  */
 /*----------------------------------------------------------------------------*/
 
@@ -644,4 +700,243 @@ cs_get_thread_id(void)
 }
 #endif /* __cplusplus */
 
+#ifdef __cplusplus
+
+/*=============================================================================
+ * Public C++ templates
+ *============================================================================*/
+
+namespace cs {
+
+/*----------------------------------------------------------------------------*/
+/*
+ * \brief  Return absolute value of a number.
+ *
+ * This function is overloaded in cs_math.h for floating-point values.
+ *
+ * \tparam T value type
+ *
+ * \param[in]  a  value
+ *
+ * \return absolute value of a
+ */
+/*----------------------------------------------------------------------------*/
+
+template <typename T>
+CS_F_HOST_DEVICE inline T
+abs(const T  a)
+{
+  return ((a) <  0  ? -(a) : (a));
+}
+
+/*----------------------------------------------------------------------------*/
+/*
+ * \brief  Return minimum of two values.
+ *
+ * This function is overloaded in cs_math.h for floating-point values.
+ *
+ * \tparam T value type
+ *
+ * \param[in]  a   first value
+ * \param[in]  b   second value
+ *
+ * \return minimum of a and b
+ */
+/*----------------------------------------------------------------------------*/
+
+template <typename T>
+CS_F_HOST_DEVICE inline T
+min(const T  a,
+    const T  b)
+{
+  return ((a) < (b) ?  (a) : (b));
+}
+
+/*----------------------------------------------------------------------------*/
+/*
+ * \brief  Return maximum of two values.
+ *
+ * This function is overloaded in cs_math.h for floating-point values.
+ *
+ * \tparam T value type
+ *
+ * \param[in]  a   first value
+ * \param[in]  b   second value
+ *
+ * \return maximum of a and b
+ */
+/*----------------------------------------------------------------------------*/
+
+template <typename T>
+CS_F_HOST_DEVICE inline T
+max(const T  a,
+    const T  b)
+{
+  return ((a) > (b) ?  (a) : (b));
+}
+
+/*----------------------------------------------------------------------------*/
+/*
+ * \brief Clamp function for a given scalar value.
+ *
+ * This function is overloaded in cs_math.h for floating-point values.
+ *
+ * \tparam T value type
+ *
+ * \param[in] x    initial value
+ * \param[in] xmin min value for clamping
+ * \param[in] xmax max value for clamping
+ *
+ * \return clamped value which is 'x' if xmin < x < xmax or lower/upper bound
+ * otherwise
+ */
+/*----------------------------------------------------------------------------*/
+
+template <typename T>
+CS_F_HOST_DEVICE inline T
+clamp(const T x,
+      const T xmin,
+      const T xmax)
+{
+  T x_tmp = ((xmin) > (x) ?  (xmin) : (x));
+  return ((xmax) < (x_tmp) ?  (xmax) : (x_tmp));
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Utility template to check if a pack of parameters is made of integral types.
+ */
+/*----------------------------------------------------------------------------*/
+
+template <class... Args>
+struct are_integral {
+  enum : bool { value = true};
+};
+
+/*----------------------------------------------------------------------------*/
+
+template <typename T, class... Args>
+struct are_integral<T, Args...> {
+  enum {
+    value = (std::is_integral<T>::value || std::is_enum<T>::value)
+          && are_integral<Args...>::value
+  };
+};
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Utility template which returns "true" for a given pack.
+ *        This is necessary of std::enable_if_t<> when the template pack
+ *        is not used for the if clause...
+ */
+/*----------------------------------------------------------------------------*/
+
+template <typename... Args>
+struct always_true : std::true_type {};
+
+/*----------------------------------------------------------------------------*/
+
+} // namespace cs
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Get the cs_datatype_t from a typename
+ *
+ * \tparam T : datatype
+ */
+/*----------------------------------------------------------------------------*/
+
+template <typename T>
+struct dependent_false : std::false_type {};
+
+template <typename T>
+static inline cs_datatype_t
+cs_datatype_from_type()
+{
+  static_assert(dependent_false<T>::value, "Unknown datatype");
+  return CS_DATATYPE_NULL;
+}
+
+/*----------------------------------------------------------------------------*/
+/* Specialized versions of the templated function                             */
+/*----------------------------------------------------------------------------*/
+
+template <>
+constexpr inline cs_datatype_t
+cs_datatype_from_type<char>()
+{
+  return CS_CHAR;
+}
+
+/*----------------------------------------------------------------------------*/
+
+template <>
+constexpr inline cs_datatype_t
+cs_datatype_from_type<float>()
+{
+  return CS_FLOAT;
+}
+
+/*----------------------------------------------------------------------------*/
+
+template <>
+constexpr inline cs_datatype_t
+cs_datatype_from_type<double>()
+{
+  return CS_DOUBLE;
+}
+
+/*----------------------------------------------------------------------------*/
+
+template <>
+constexpr inline cs_datatype_t
+cs_datatype_from_type<uint16_t>()
+{
+  return CS_UINT16;
+}
+
+/*----------------------------------------------------------------------------*/
+
+template <>
+constexpr inline cs_datatype_t
+cs_datatype_from_type<uint32_t>()
+{
+  return CS_UINT32;
+}
+
+/*----------------------------------------------------------------------------*/
+
+template <>
+constexpr inline cs_datatype_t
+cs_datatype_from_type<uint64_t>()
+{
+  return CS_UINT64;
+}
+
+/*----------------------------------------------------------------------------*/
+
+template <>
+constexpr inline cs_datatype_t
+cs_datatype_from_type<int32_t>()
+{
+  return CS_INT32;
+}
+
+/*----------------------------------------------------------------------------*/
+
+template <>
+constexpr inline cs_datatype_t
+cs_datatype_from_type<int64_t>()
+{
+  return CS_INT64;
+}
+
+/*----------------------------------------------------------------------------*/
+
+/*----------------------------------------------------------------------------*/
+
+#endif /* __cplusplus */
+
+/*----------------------------------------------------------------------------*/
+
 #endif /* __CS_DEFS_H__ */
