@@ -1,11 +1,11 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -21,7 +21,7 @@
 # this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
 # Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 import configparser
 import datetime, time
@@ -45,9 +45,9 @@ kib_unit_mult = {'K': 1.,
                  'P': 1024. ** 4,
                  'E': 1024. ** 5}
 
-#===============================================================================
+# ===============================================================================
 # Utility classes and functions
-#===============================================================================
+# ===============================================================================
 
 class case_state(Enum):
     "Enumeration for case state handling"
@@ -63,7 +63,7 @@ class case_state(Enum):
     EXCEEDED_TIME_LIMIT = 2
     FAILED = 3
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 def check_exec_dir_stamp(d):
 
@@ -86,12 +86,12 @@ def check_exec_dir_stamp(d):
 
     return retval
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # Check if an execution directory is inside a standard case structure
 #
 # This may not be the case if a separate staging directory or destination
 # directory has been specified.
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 def is_exec_dir_in_case(case_dir, exec_dir):
     """
@@ -115,7 +115,7 @@ def is_exec_dir_in_case(case_dir, exec_dir):
 
     return in_case
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 def get_case_dir(case=None, param=None, coupling=None, id=None):
 
@@ -202,7 +202,7 @@ def get_case_dir(case=None, param=None, coupling=None, id=None):
 
     return casedir, staging_dir
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 def get_case_state(run_dir, coupling=False, run_timeout=3600):
 
@@ -274,15 +274,15 @@ def get_case_state(run_dir, coupling=False, run_timeout=3600):
 
     # General case: try to analyze run directory
 
-    states = [('finished', case_state.COMPUTED),
+    states = [('exceeded_time_limit', case_state.EXCEEDED_TIME_LIMIT),
+              ('finished', case_state.COMPUTED),
               ('saving', case_state.FINALIZING),
               ('running', case_state.RUNNING),
               ('preparing', case_state.STAGING),
               ('prepared', case_state.STAGED),
               ('preprocessing', case_state.RUNNING),
               ('ready', case_state.PREPROCESSED),
-              ('failed', case_state.FAILED),
-              ('exceeded_time_limit', case_state.EXCEEDED_TIME_LIMIT)]
+              ('failed', case_state.FAILED)]
 
     for s in states:
         if os.path.isfile(os.path.join(run_dir, 'run_status.' + s[0])):
@@ -337,7 +337,7 @@ def get_case_state(run_dir, coupling=False, run_timeout=3600):
     if os.path.isfile(os.path.join(run_dir, 'error')):
         state = case_state.FAILED
 
-    # Now try to check elapsed time.
+    # Now try to check elapsed time and memory stats.
 
     p_log = os.path.join(run_dir, 'performance.log')
 
@@ -364,6 +364,8 @@ def get_case_state(run_dir, coupling=False, run_timeout=3600):
                 if l[:20] == '  Total memory used:':
                     c_mem_max = l[20:].strip().split()
                     t_mem = 0
+                if l[:12] == '  Non freed:':
+                    info['memory_leaks'] = int(l[12:].strip().split(' ')[0])
                 if t_mem == 2:
                     j = l.find('local maximum:')
                     if j > -1:
@@ -424,14 +426,14 @@ def get_case_state(run_dir, coupling=False, run_timeout=3600):
 
     return state, info
 
-#===============================================================================
+# ===============================================================================
 # Main class
-#===============================================================================
+# ===============================================================================
 
 class case:
     """Base class from which classes handling running case should inherit."""
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def __init__(self,
                  package,                     # main package
@@ -506,6 +508,11 @@ class case:
                 if d.name is None:
                     raise RunCaseError(err_str)
 
+        self.n_domains_aster = 0
+        for d in self.domains:
+            if isinstance(d, aster_domain):
+                self.n_domains_aster += 1
+
         # Names, directories, and files in case structure:
         # associate case domains and set case directory
 
@@ -571,6 +578,10 @@ class case:
         self.compute_prologue = None
         self.compute_epilogue = None
 
+        # Memory log and test
+
+        self.mem_log = False
+
         # Tool hooks
 
         self.debug_args = None
@@ -589,7 +600,7 @@ class case:
         self.error = ''
         self.error_long = ''
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def __define_dest_dir__(self):
 
@@ -599,7 +610,7 @@ class case:
                                         self.dest_dir)
                 self.dest_dir = os.path.abspath(dest_dir)
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def print_procs_distribution(self):
 
@@ -626,7 +637,7 @@ class case:
 
         sys.stdout.write('\n')
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def distribute_procs(self, n_procs=None):
 
@@ -756,7 +767,7 @@ class case:
 
         return n_procs_tot
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def define_exec_dir(self):
         """
@@ -776,7 +787,7 @@ class case:
                 self.define_result_dir()
             self.exec_dir = self.result_dir
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def set_exec_dir(self, force=False):
         """
@@ -805,7 +816,7 @@ class case:
         for d in self.domains:
             d.set_exec_dir(self.exec_dir)
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def define_result_dir(self):
 
@@ -826,7 +837,7 @@ class case:
 
         self.result_dir = os.path.join(r, self.run_id)
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def set_result_dir(self, force=True):
 
@@ -853,7 +864,7 @@ class case:
                              self.result_dir,
                              dest_root_dir=dest_root_dir)
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def summary_init(self, exec_env):
 
@@ -923,7 +934,7 @@ class case:
 
         s.close()
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def summary_finalize(self):
 
@@ -948,7 +959,7 @@ class case:
 
         s.close()
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def copy_log(self, name):
         """
@@ -966,7 +977,7 @@ class case:
             if self.error == '':
                 os.remove(src)
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def copy_script(self):
         """
@@ -986,13 +997,20 @@ class case:
         if src.startswith(cs_pkg_dir):
             return
 
-        # Copy single file
+        # Copy single file, unless already present
 
         dest = os.path.join(self.result_dir, os.path.basename(src))
         if os.path.isfile(src) and os.path.abspath(src) != os.path.abspath(dest):
-            shutil.copy2(src, dest)
+            batch_file_already_present = False
+            runcase = os.path.join(self.result_dir, 'runcase')
+            if os.path.isfile(runcase):
+                import filecmp
+                if filecmp.cmp(src, runcase):
+                    batch_file_already_present = True
+            if not batch_file_already_present:
+                shutil.copy2(src, dest)
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def copy_top_run_conf(self):
         """
@@ -1007,7 +1025,7 @@ class case:
         if os.path.isfile(src) and src != dest:
             shutil.copy2(src, dest)
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def solver_script_path(self):
         """
@@ -1015,7 +1033,7 @@ class case:
         """
         return os.path.join(self.exec_dir, self.package.runsolver)
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def debug_wrapper_args(self):
         """
@@ -1035,7 +1053,7 @@ class case:
         debug_args += dbg_wrapper_path + ' '
         return debug_args
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def generate_solver_mpmd_mpiexec(self, n_procs, mpi_env, tool_args=''):
         """
@@ -1047,7 +1065,7 @@ class case:
         app_id = 0
 
         for d in self.domains:
-            s_args = d.solver_command()
+            s_args = d.solver_command(n_tot_procs=n_procs)
             if len(cmd) > 0:
                 cmd += ' : '
             cmd += '-n ' + str(d.n_procs) \
@@ -1057,7 +1075,7 @@ class case:
 
         return cmd
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def generate_solver_mpmd_configfile(self,
                                         n_procs,
@@ -1073,7 +1091,7 @@ class case:
         app_id = 0
 
         for d in self.domains:
-            s_args = d.solver_command()
+            s_args = d.solver_command(n_tot_procs=n_procs)
             cmd = '-n ' + str(d.n_procs) \
                 + ' -wdir ' + os.path.basename(s_args[0]) \
                 + ' ' + tool_args + s_args[1] + s_args[2] + '\n'
@@ -1084,7 +1102,7 @@ class case:
 
         return e_path
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def generate_solver_mpmd_configfile_srun(self,
                                              n_procs,
@@ -1104,7 +1122,7 @@ class case:
         rank_id = 0
 
         for d in self.domains:
-            s_args = d.solver_command(need_abs_path=True)
+            s_args = d.solver_command(n_tot_procs=n_procs, need_abs_path=True)
 
             cmd = '%d-%d\t' % (rank_id, rank_id + d.n_procs - 1) \
                    + tool_args + s_args[1] + s_args[2] \
@@ -1117,7 +1135,7 @@ class case:
 
         return e_path
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def generate_solver_mpmd_configfile_ccc_mprun(self,
                                                   n_procs,
@@ -1134,7 +1152,7 @@ class case:
         app_id = 0
 
         for d in self.domains:
-            s_args = d.solver_command()
+            s_args = d.solver_command(n_tot_procs=n_procs)
             cmd = str(d.n_procs) +' ' \
                     + ' bash -c "' \
                     + ' cd ' + os.path.basename(s_args[0]) + ' &&' \
@@ -1147,7 +1165,7 @@ class case:
 
         return e_path
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def generate_solver_mpmd_script(self, n_procs,
                                     mpi_env,
@@ -1182,7 +1200,7 @@ class case:
         for d in self.domains:
             nr += d.n_procs
             e.write(test_pf + str(nr) + test_sf)
-            s_args = d.solver_command()
+            s_args = d.solver_command(n_tot_procs=n_procs)
             e.write('  cd ' + s_args[0] + '\n')
             env_load_sh = d.solver_set_env_command()
             if env_load_sh:
@@ -1208,7 +1226,7 @@ class case:
 
         return e_path
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def solver_script_body(self, n_procs, mpi_env, s):
         """
@@ -1356,7 +1374,7 @@ class case:
 
                 if n_procs:
                     b = cs_exec_environment.batch_info()
-                    if b.batch_type is None:
+                    if b.batch_type is None and mpiexec_mpmd:
                         mpi_cmd += '-n '+ str(n_procs) + ' '
 
             else:
@@ -1364,7 +1382,7 @@ class case:
 
             s.write(mpi_cmd + e_path + '\n')
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def generate_solver_script(self, exec_env):
         """
@@ -1410,6 +1428,9 @@ class case:
                                                  self.package.get_dir("prefix"))
             s.write('\n')
 
+        cs_exec_environment.write_export_env(s, 'PYTHONDONTWRITEBYTECODE', '1')
+        s.write('\n')
+
         # Add MPI directories to PATH if in nonstandard path
 
         cs_exec_environment.write_script_comment(s, \
@@ -1434,7 +1455,10 @@ class case:
                             'Export paths necessary for CATHARE coupling.\n')
                         config = configparser.ConfigParser()
                         config.read(self.package.get_configfiles())
-                        cathare_path = config.get('install', 'cathare')
+                        if d.cathare_version == 'v3':
+                            cathare_path = config.get('install', 'cathare3')
+                        else:
+                            cathare_path = config.get('install', 'cathare2')
                         for p in ['lib', 'ICoCo/lib']:
                             lp = os.path.join(cathare_path, p)
                             cs_exec_environment.write_prepend_path( \
@@ -1444,7 +1468,7 @@ class case:
                         s.write('\n')
 
         # Handle python coupling
-        if self.n_domains_python > 0:
+        if self.n_domains_python > 0 or self.n_domains_aster > 0:
             cs_exec_environment.write_script_comment(s, \
                 'Export paths necessary for python coupling.\n')
             pydir = self.package_compute.get_dir("pythondir")
@@ -1463,6 +1487,8 @@ class case:
                'Load environment if this script is run directly.\n')
             s.write('if test "$CS_ENVIRONMENT_SET" != "true" ; then\n')
             if self.package_compute.config.env_modules != "no":
+                cs_exec_environment.write_export_env(s, 'LMOD_PAGER',
+                                                     'none', prefix='  ')
                 s.write('  module purge\n')
                 for m in self.package_compute.config.env_modules.strip().split():
                     s.write('  module load ' + m + '\n')
@@ -1529,6 +1555,10 @@ class case:
                                                  str(n_threads))
             s.write('\n')
 
+        # Handle additional library options if needed
+
+        cs_exec_environment.write_catalyst2_vars(self.package_compute, s)
+
         # Handle rcfile if used
 
         rcfile = cs_exec_environment.get_rcfile(self.package_compute)
@@ -1549,6 +1579,12 @@ class case:
 
         s.write('cd ' + cs_exec_environment.enquote_arg(self.exec_dir) + '\n\n')
 
+        # If user asked for it, place CS_MEM_LOG variable
+        if self.mem_log:
+            s.write('# Memory log\n')
+            write_export_env(s, 'CS_MEM_LOG', 'cs_mem.log')
+            s.write('\n\n')
+
         # Add user-defined prologue if defined
 
         if self.compute_prologue:
@@ -1588,7 +1624,7 @@ class case:
 
         return s_path
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def update_scripts_tmp(self, src, dest, caption=None):
 
@@ -1635,7 +1671,7 @@ class case:
         except Exception:
             pass
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def add_exec_dir_stamp(self):
 
@@ -1648,7 +1684,7 @@ class case:
         f.write(self.exec_dir + '\n')
         f.close()
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def clear_exec_dir_stamp(self):
 
@@ -1662,7 +1698,7 @@ class case:
         except Exception:
             pass
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def exceeded_time_limit(self):
 
@@ -1676,7 +1712,7 @@ class case:
         else:
             return False
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def set_run_id(self,
                    run_id = None):
@@ -1700,7 +1736,7 @@ class case:
                 self.run_id = run_id_base + '_' + str(j)
                 self.define_result_dir()
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def prepare_data(self,
                      force_id = False):
@@ -1757,7 +1793,7 @@ class case:
             return 1
 
         # Setup data
-        #===========
+        # ===========
 
         sys.stdout.write('Preparing calculation data\n'
                          '--------------------------\n\n')
@@ -1796,7 +1832,7 @@ class case:
         else:
             return 0
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def init_prepared_data(self):
 
@@ -1811,7 +1847,7 @@ class case:
         for d in self.domains:
             d.init_staged_data()
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def preprocess(self,
                    n_procs = None,
@@ -1836,7 +1872,7 @@ class case:
         self.update_scripts_tmp('prepared', 'preprocessing')
 
         # Determine execution environment
-        #================================
+        # ================================
         # (priority for n_procs, in increasing order:
         # resource manager, method argument).
 
@@ -1867,7 +1903,7 @@ class case:
         self.print_procs_distribution()
 
         # Preprocessing
-        #==============
+        # ==============
 
         sys.stdout.write('Preprocessing calculation\n'
                          '-------------------------\n\n')
@@ -1923,7 +1959,7 @@ class case:
         else:
             return 0
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def run_solver(self):
 
@@ -1956,7 +1992,7 @@ class case:
             else:
                 max_time = self.time_limit
         if max_time != None:
-            os.putenv('CS_MAXTIME', str(max_time))
+            os.environ['CS_MAXTIME'] = str(max_time)
 
         # Tell the script it is being called through the main script
         # (implying environment modules are set and the environment loaded)
@@ -1964,7 +2000,7 @@ class case:
         rcfile = cs_exec_environment.get_rcfile(self.package_compute)
 
         if rcfile or self.package_compute.config.env_modules != "no":
-            os.putenv('CS_ENVIRONMENT_SET', 'true')
+            os.environ['CS_ENVIRONMENT_SET'] = 'true'
 
         # Now run the calculation
 
@@ -2026,7 +2062,7 @@ class case:
 
         return retcode
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def save_results(self):
 
@@ -2060,10 +2096,16 @@ class case:
                         pass
 
         e_caption = None
+
+        memory_leak = False
         for d in self.domains:
             d.copy_results()
             if d.error:
                 e_caption = d.error
+            # check for memory leaks if needed
+            if self.mem_log:
+                if d.check_memory_log() == 1:
+                    memory_leak = True
 
         # Remove directories if empty
 
@@ -2080,7 +2122,9 @@ class case:
 
         self.update_scripts_tmp('saving', None)
 
-    #---------------------------------------------------------------------------
+        return memory_leak
+
+    # ---------------------------------------------------------------------------
 
     def run(self,
             n_procs = None,
@@ -2262,6 +2306,7 @@ class case:
             retcode = cs_exec_environment.run_command(self.run_prologue)
             os.chdir(cwd)
 
+        mem_log_leaks = False
         try:
             retcode = 0
             if stages['prepare_data']:
@@ -2277,7 +2322,7 @@ class case:
                 self.run_solver()
 
             if stages['save_results'] == True:
-                self.save_results()
+                mem_log_leaks = self.save_results()
                 self.clear_exec_dir_stamp()
 
         finally:
@@ -2304,6 +2349,9 @@ class case:
             sys.stderr.write(err_str)
             retcode = 1
 
+        if self.mem_log and mem_log_leaks:
+            retcode += 2
+
         if self.run_epilogue:
             cwd = os.getcwd()
             os.chdir(self.exec_dir)
@@ -2312,7 +2360,7 @@ class case:
 
         return retcode
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def suggest_id(self,
                    run_id_prefix = None,
@@ -2370,6 +2418,6 @@ class case:
 
         return run_id
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # End
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
