@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -128,9 +128,10 @@ class config:
                         'ple',                          # PLE
                         'eos', 'coolprop',              # Equations of state
                         'ccm', 'cgns', 'med', 'hdf5',   # Mesh filters
-                        'catalyst', 'melissa',          # co-processing libraries
+                        'catalyst2', 'catalyst',        # co-processing libaries,
+                        'melissa',                      # in-situ statistics library
                         'medcoupling',                  # MED coupling
-                        'mumps',                        # Sparse direct solver
+                        'mumps', 'cudss',               # Sparse direct solver
                         'amgx', 'hypre', 'petsc',       # Linear algebra
                         'metis', 'scotch',              # Partionning libraries
                         'mpi',                          # MPI
@@ -147,7 +148,7 @@ class config:
             self.compilers[k] = d.get(k, None)
 
         self.flags = {}
-        for k in ('cflags', 'cxxflags', 'fcflags', 'nvccflags',
+        for k in ('cflags', 'cxxflags', 'fcflags', 'nvccflags', 'nvccflags_cpp',
                   'cflags_shared', 'cxxflags_shared', 'fcflags_shared'):
             self.flags[k] = d.get(k, '')
 
@@ -187,8 +188,9 @@ class config:
 
         self.exec_include = {'nc_solver' + self.exeext: "neptune_cfd"}
 
-        self.exec_libs = {'cs_solver' + self.exeext: "-lcs_solver",
-                          'nc_solver' + self.exeext: "-lneptune"}
+        self.exec_libs = {'cs_solver' + self.exeext: ["-lcs_solver"],
+                          'nc_solver' + self.exeext: ["-lnc_solver",
+                                                      "-lneptune"]}
 
         # Python-related information
 
@@ -214,13 +216,13 @@ class config:
         self.features = {}
         self.features['debug'] = d.get('debug', 'no')
         self.features['relocatable'] = d.get('relocatable', 'no')
-        self.features['shared'] = d.get('enable_shared', 'yes')
-        self.features['gui'] = d.get('cs_have_gui', 'yes')
-        self.features['frontend'] = d.get('cs_have_frontend', 'yes')
-        self.features['mpi'] = d.get('cs_have_mpi', 'yes')
-        self.features['openmp'] = d.get('cs_have_openmp', 'yes')
-        self.features['cuda'] = d.get('cs_have_cuda', 'no')
-        self.features['long-gnum'] = d.get('cs_have_long_gnum', 'yes')
+        self.features['shared'] = d.get('shared', 'yes')
+        self.features['gui'] = d.get('gui', 'yes')
+        self.features['frontend'] = d.get('frontend', 'yes')
+        self.features['mpi'] = d.get('mpi', 'yes')
+        self.features['openmp'] = d.get('openmp', 'yes')
+        self.features['cuda'] = d.get('cuda', 'no')
+        self.features['long-gnum'] = d.get('long-gnum', 'yes')
         self.features['build_os'] = d.get('build_os', '')
 
         # Now, one can setup the prerequisites information
@@ -261,6 +263,7 @@ class config:
         self.libs['hdf5'] = prerequisite('HDF5', 'hdf5', config_dict)
         self.libs['med']  = prerequisite('MED', 'med', config_dict)
 
+        self.libs['catalyst2'] = prerequisite('CATALYST2', 'catalyst2', config_dict)
         self.libs['catalyst'] = prerequisite('CATALYST', 'catalyst', config_dict)
         self.libs['melissa']  = prerequisite('MELISSA', 'melissa', config_dict)
         self.libs['medcoupling'] = prerequisite('MEDCOUPLING',
@@ -280,6 +283,7 @@ class config:
         self.libs['amgx']  = prerequisite('Amgx', 'amgx', config_dict)
         self.libs['hypre'] = prerequisite('HYPRE', 'hypre', config_dict)
         self.libs['mumps'] = prerequisite('MUMPS', 'mumps', config_dict)
+        self.libs['cudss'] = prerequisite('CUDSS', 'cudss', config_dict)
 
     def __get_search_paths_catalyst__(self):
         """
