@@ -5,7 +5,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -555,10 +555,13 @@ def run_gdb_debug(path, args=None, gdb_cmds=None,
     # Start building command to run
 
     if debugger_ui in ['terminal', 'cgdb']:
-        cmd_string = str(debugger)
-        for c in cmd:
-            cmd_string += ' ' + enquote_arg(str(c))
-        cmd = [term, '-e', cmd_string]
+        if 'gnome-terminal' in term:
+            cmd = [term, '--', debugger] + cmd
+        else:
+            cmd_string = str(debugger)
+            for c in cmd:
+                cmd_string += ' ' + enquote_arg(str(c))
+            cmd = [term, '-e', cmd_string]
 
     elif debugger_ui == 'gdbgui':
         cmd.insert(0, debugger)
@@ -774,6 +777,7 @@ def run_debug(cmds):
     if rank_filter != None:
         if rank_id not in rank_filter:
             cmd = cmds['program']
+            os.environ['CS_EXIT_ON_ERROR'] = 'ignore'
             return subprocess.call(cmd)
 
     # Tests for Valgrind
