@@ -5,7 +5,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2025 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -69,7 +69,7 @@ def abs_exec_path(path):
 def separate_args(s):
     """
     Separate arguments that may contain whitespace, depending on whether
-    whitespace is protected or not by ", ', and \ characters.
+    whitespace is protected or not by ", ', and \\ characters.
     If quotes are found after the beginning of a string, such as in
     --option="string 1", do not remove them.
     """
@@ -420,9 +420,10 @@ def write_script_comment(fd, comment):
 
 #-------------------------------------------------------------------------------
 
-def write_export_env(fd, var, value):
+def write_export_env(fd, var, value, prefix=''):
     """
     Write the correct command so as to export environment variables.
+    The optional prefix can be used for indenting or commenting
     """
 
     if not value:
@@ -438,7 +439,7 @@ def write_export_env(fd, var, value):
             else:
                 export_cmd = 'unset ' + var
     export_cmd = export_cmd + '\n'
-    fd.write(export_cmd)
+    fd.write(prefix + export_cmd)
 
 #-------------------------------------------------------------------------------
 
@@ -470,6 +471,39 @@ def write_prepend_path(fd, var, user_path):
 
 #-------------------------------------------------------------------------------
 
+def write_catalyst2_vars(pkg, fd):
+    """
+    Write Catalyst2 environment variables.
+    """
+
+    if pkg.config.libs['catalyst2'].have == False:
+        return
+
+    catalyst_path = None
+    if os.getenv('CATALYST_IMPLEMENTATION_PATHS') is None:
+        config = configparser.ConfigParser()
+        config.read(pkg.get_configfiles())
+        if config.has_option('install', 'catalyst_implementation_paths'):
+            catalyst_path = config.get('install', 'catalyst_implementation_paths')
+
+    fd.write(
+"""# Catalyst environment
+#---------------------
+""")
+    if catalyst_path:
+        fd.write("""if [ "$CATALYST_IMPLEMENTATION_PATHS" = "" ]; then
+  """)
+        write_export_env(fd, 'CATALYST_IMPLEMENTATION_PATHS', catalyst_path)
+        fd.write("fi\n")
+
+    # Using PARAVIEW_LOG_FILE currently leads to using 1 file per MPI rank,
+    # so we do not export this variable for now.
+    #write_export_env(fd, 'PARAVIEW_LOG_FILE', 'catalyst.log')
+    write_export_env(fd, 'VTK_SILENCE_GET_VOID_POINTER_WARNINGS', '1')
+    fd.write("\n")
+
+#-------------------------------------------------------------------------------
+
 def write_mps_start(fd):
     """
     Write MPS start code in run script.
@@ -636,7 +670,8 @@ def clean_os_environ_for_shell():
 
     # In case LMOD is present, avoid warnings on macros
     # for called scripts.
-    for ev in ('BASH_FUNC_module%%', 'BASH_FUNC_ml%%'):
+    for ev in ('BASH_FUNC_module%%', 'BASH_FUNC_ml%%',
+               'BASH_FUNC_scl%%'):
         if ev in os.environ:
             if is_bash:
                 saved_os_env_vars[ev] = os.environ[ev]
@@ -644,6 +679,25 @@ def clean_os_environ_for_shell():
 
 #-------------------------------------------------------------------------------
 
+def filtered_os_environ_for_shell(env=None):
+    """
+    Return filtered environment relative to sub-shells.
+    """
+
+    if env:
+        s_env = env.copy()
+    else:
+        s_env = os.environ.copy()
+
+    for ev in ('BASH_FUNC_module%%', 'BASH_FUNC_ml%%',
+               'BASH_FUNC_scl%%'):
+        if ev in s_env:
+            del s_env[ev]
+
+    return s_env
+
+#-------------------------------------------------------------------------------
+
 def full_os_environ_for_shell(env=None):
     """
     Return environment relative to sub-shells.
@@ -715,6 +769,8 @@ def run_command(args, pkg = None, echo = False,
                                  env=full_os_environ_for_shell(env),
                                  **kwargs)
         else:
+            if env is None:
+                env = filtered_os_environ_for_shell()
             p = subprocess.Popen(args,
                                  universal_newlines=True,
                                  env=env,
@@ -842,6 +898,10 @@ def source_shell_script(path):
 
     output = p.communicate()[0]
 
+    # clean environment to prevent conflict with that of salome
+    if "SALOME_ROOT_DIR" in os.environ.keys():
+        os.environ = {}
+
     for line in output.splitlines():
 
         (key, _, value) = line.partition("=")
@@ -966,7 +1026,7 @@ def source_syrthes_env(pkg, verbose=True, force=False):
     # use existing environment or load one based on current configuration.
 
     for p in sys.path:
-        if p[-14:] == '/share/syrthes' or p[-14:] == '\share\syrthes':
+        if p[-14:] == '/share/syrthes' or p[-14:] == '\\share\\syrthes':
             syr_profile = os.path.join(p[:-14], 'bin', 'syrthes.profile')
             if os.path.isfile(syr_profile):
                 if verbose:
@@ -1115,7 +1175,7 @@ class batch_info:
 
         if self.batch_type == 'PBS':
             cmd = "qstat -r $PBS_JOBID | grep $PBS_JOBID" \
-                + " | sed -e's/ \{1,\}/ /g' | cut -d ' ' -f 9"
+                + " | sed -e's/ \\{1,\\}/ /g' | cut -d ' ' -f 9"
             rtime = get_command_output(cmd)
         elif self.batch_type == 'SLURM':
             cmd = "squeue -h -j $SLURM_JOBID -o %L"
@@ -1514,19 +1574,18 @@ class mpi_environment:
         # We may have a specific syntax for tasks per node if
         # a launcher from a resource manager is used:
 
-        if resource_info and self.mpiexec:
-            if os.path.basename(self.mpiexec)[:4] == 'srun':
-                if resource_info.n_procs_ri != None \
-                  and resource_info.n_procs_ri != resource_info.n_procs:
-                    self.mpiexec_n = ' --ntasks='
-                elif not self.mpiexec_n_per_node:
-                    self.mpiexec_n_per_node = ' --ntasks-per-node='
+        init_method = None
 
-        # Initialize based on known MPI types, or default.
+        # If using srun, the launcher commands are those of srun, not
+        # directly those of the MPI library.
 
-        init_method = self.__init_other__
+        if self.mpiexec:
+            if os.path.basename(self.mpiexec) in ("srun", "ccc_mprun"):
+                init_method = self.__init_srun__
 
-        if len(self.type) > 0:
+        # Otherwise initialize based on known MPI types, or default.
+
+        if init_method is None and len(self.type) > 0:
             mpi_env_by_type = {'MPICH':self.__init_mpich__,
                                'Intel_MPI':self.__init_mpich__,
                                'MSMPI':self.__init_msmpi__,
@@ -1535,6 +1594,9 @@ class mpi_environment:
             if self.type in mpi_env_by_type:
                 init_method = mpi_env_by_type[self.type]
 
+        if init_method is None:
+            init_method = self.__init_other__
+
         p = os.getenv('PATH').split(':')
         if len(self.bindir) > 0:
             p = [self.bindir]
@@ -1564,7 +1626,13 @@ class mpi_environment:
             if not self.mpiexec_n_per_node[-1:].isdigit():
                 ppn = resource_info.n_procs_per_node()
                 if ppn:
-                    self.mpiexec_n_per_node += str(ppn)
+                    # Allow a syntax with replacement instead of concatenation.
+                    # This is needed for complex syntaxes of mpirun/mpiexec
+                    if '@PPN@' in self.mpiexec_n_per_node:
+                        self.mpiexec_n_per_node = \
+                                self.mpiexec_n_per_node.replace('@PPN@', str(ppn))
+                    else:
+                        self.mpiexec_n_per_node += str(ppn)
                 else:
                     self.mpiexec_n_per_node = None
 
@@ -1784,15 +1852,14 @@ class mpi_environment:
 
     def __init_openmpi__(self, p, resource_info=None, wdir = None):
         """
-        Initialize for OpenMPI environment.
+        Initialize for OpenMPI launcher.
         """
 
         # Determine base executable paths
 
-        # Caution: if srun is used, it is probably not in the same
-        # path as MPI executables.
+        absname = None
 
-        if self.mpiexec != None and self.mpiexec != 'srun':
+        if self.mpiexec != None:
             absname = self.__get_mpiexec_absname__(p)
 
         else:
@@ -1831,12 +1898,10 @@ class mpi_environment:
         if not self.mpiexec_n:
             self.mpiexec_n = ' -n '
 
-        # srun or ccc_mprun do not accept the "--npernode argument!
-        if launcher_base not in ("srun", "ccc_mprun"):
-            if resource_info != None and not self.mpiexec_n_per_node:
-                ppn = resource_info.n_procs_per_node()
-                if ppn:
-                    self.mpiexec_n_per_node = ' --npernode ' + str(ppn)
+        if resource_info != None and not self.mpiexec_n_per_node:
+            ppn = resource_info.n_procs_per_node()
+            if ppn:
+                self.mpiexec_n_per_node = ' --npernode ' + str(ppn)
 
         if not self.mpmd:
             if launcher_base[:7] == 'mpiexec':
@@ -1844,24 +1909,36 @@ class mpi_environment:
             elif launcher_base[:6] == 'mpirun':
                 self.mpmd = MPI_MPMD_script
 
-        # Other options to add
-
-        # Detect if resource manager is known by this Open MPI build
+        # Detect if resource manager is known by this Open MPI build.
 
         if resource_info != None:
             known_manager = False
-            rc_mca_by_type = {'SLURM':' slurm ',
-                              'LSF':' lsf ',
-                              'PBS':' tm ',
-                              'SGE':' gridengine '}
-            if resource_info.manager in rc_mca_by_type:
+            if resource_info.manager == 'SLURM':
+                # SLURM support is available by default in Open MPI 5 or newer.
+                known_manager = True
+                # In case Open MPI 4.0 or older,
+                # check if it is properly configured.
                 info = get_command_output(info_name)
-                if info.find(rc_mca_by_type[resource_info.manager]) > -1:
-                    known_manager = True
+                idx = info.find('Ident string:')
+                ompi_major = ''
+                if idx > -1:
+                    ompi_major = info[idx + 14]
+                    if ompi_major in ('3', '4'):
+                        if info.find('slurm') < 0:
+                            known_manager = False
             elif resource_info.manager == 'OAR':
                 self.mpiexec += ' -machinefile $OAR_FILE_NODES'
                 self.mpiexec += ' -mca pls_rsh_agent "oarsh"'
                 known_manager = True
+            else:
+                rc_mca_by_type = {'LSF':' lsf ',
+                                  'PBS':' tm ',
+                                  'SGE':' gridengine '}
+                if resource_info.manager in rc_mca_by_type:
+                    info = get_command_output(info_name)
+                    if info.find(rc_mca_by_type[resource_info.manager]) > -1:
+                        known_manager = True
+
             if known_manager == False:
                 hostsfile = resource_info.get_hosts_file(wdir)
                 if hostsfile != None:
@@ -1942,6 +2019,29 @@ class mpi_environment:
 
     #---------------------------------------------------------------------------
 
+    def __init_srun__(self, p, resource_info=None, wdir = None):
+        """
+        Initialize for SLURM srun launcher.
+
+        SLURM and the MPI library used must be configured correctly.
+        For example, with Open MPI, SLURM should be compiled with PMIX support,
+        so `srun --mpi=list` should return a list including `pmix`,
+        and Open MPI should also include PMIX support.
+        Otherwise, `srun` can be used to generate a hostfile, but should
+        not be used to run the code directly.
+        """
+
+        if os.path.basename(self.mpiexec)[:4] == 'srun':
+            if resource_info.n_procs_ri != None \
+               and resource_info.n_procs_ri != resource_info.n_procs:
+                self.mpiexec_n = ' --ntasks='
+            elif not self.mpiexec_n_per_node:
+                self.mpiexec_n_per_node = ' --ntasks-per-node='
+
+        self.info_cmds = ['ompi_info -a']
+
+    #---------------------------------------------------------------------------
+
     def __init_other__(self, p, resource_info=None, wdir = None):
         """
         Initialize MPI environment info for environments not handled
