@@ -5,7 +5,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -214,7 +214,7 @@ class cs_math_parser:
                     if quotes[0] == '"':
                         quotes.pop(0)
                     else:
-                        quotes.insert(0, "'")
+                        quotes.insert(0, '"')
 
                 if quotes[0] != ' ':
                     if quotes[0] == 'e' and l[c_id] in whitespace:
@@ -720,30 +720,44 @@ class cs_math_parser:
         if func_type == "vol":
             req_fields = split_req_components(req)
 
+        # First pass to recognize known loop variables
+        _has_for_range = False
+        for_str_pattern = re.compile(r"FOR_RANGE\([A-Za-z],\s*[0-9]+,\s*[0-9]+\)", re.IGNORECASE)
+        for _p in for_str_pattern.findall(expression):
+            _m = _p.replace('FOR_RANGE(','').replace(')','').split(',')
+            known_symbols.append(str(_m[0]))
+            _s = 'for (int {m[0]} = {m[1]}; {m[0]} < {m[2]}; {m[0]}++)'.format(m=_m)
+            _has_for_range = True
+
         # Parse the Mathematical expression and generate the C block code
         exp_lines = expression.split("\n")
         segments = self.separate_segments(exp_lines)
         tokens, comments = self.tokenize(segments)
 
         for t in tokens:
-            tk = t[0]
-            if tk not in known_symbols:
-                # We use a double if and not if/else because some symbols
-                # may be present in both lists
-                if tk in glob_tokens.keys():
-                    usr_defs.append(glob_tokens[tk] + '\n')
-                    known_symbols.append(tk)
-                if tk in loop_tokens.keys():
-                    usr_code.append(loop_tokens[tk] + '\n')
-                    if tk not in known_symbols:
-                        known_symbols.append(tk)
+            # In the case of components, ensure the main field is added
+            tklist = [t[0]]
+            if (bool(re.search('\[[0-9]\]', t[0]))):
+                tklist.append(re.sub('\[[0-9]\]', '', t[0]))
 
-                    # For momentum source terms, check for velocity
-                    if func_type == "src" and tk in ['u','v','w']:
-                        if 'velocity' not in known_symbols:
-                            if 'velocity' in glob_tokens:
-                                known_symbols.append('velocity')
-                                usr_defs.append(glob_tokens['velocity']+'\n')
+            for tk in tklist:
+                if tk not in known_symbols:
+                    # We use a double if and not if/else because some symbols
+                    # may be present in both lists
+                    if tk in glob_tokens.keys():
+                        usr_defs.append(glob_tokens[tk] + '\n')
+                        known_symbols.append(tk)
+                    if tk in loop_tokens.keys():
+                        usr_code.append(loop_tokens[tk] + '\n')
+                        if tk not in known_symbols:
+                            known_symbols.append(tk)
+
+                        # For momentum source terms, check for velocity
+                        if func_type == "src" and tk in ['u','v','w']:
+                            if 'velocity' not in known_symbols:
+                                if 'velocity' in glob_tokens:
+                                    known_symbols.append('velocity')
+                                    usr_defs.append(glob_tokens['velocity']+'\n')
 
         #-------------------------
 
@@ -793,7 +807,20 @@ class cs_math_parser:
                         new_v = 'retvals[e_id]'
 
                 elif func_type == 'ibm':
-                    new_v = '*ipenal'
+                    new_v = 'retval'
+
+                elif func_type in ['ibm_vol']:
+                    if nreq > 1:
+                        ir = req.index(tk)
+                        new_v = 'retvals[%d * c_id + %d]' % (nreq, ir)
+                    else:
+                        new_v = 'retvals[c_id]'
+                elif func_type == 'pca':
+                    if nreq > 1:
+                        ir = req.index(tk)
+                        new_v = 'retvals[%d * e_id + %d]' % (nreq, ir)
+                    else:
+                        new_v = 'retvals[e_id]'
 
                 if tk in req_to_replace:
                     req_to_replace.remove(tk)
@@ -817,8 +844,16 @@ class cs_math_parser:
 
         # Rebuild lines
         new_text = self.rebuild_text(tokens, comments)
-        for line in new_text[0].split('\n'):
-            usr_code.append(line + '\n')
+        if _has_for_range:
+            for line in new_text[0].split('\n'):
+                for _p in for_str_pattern.findall(line):
+                    _m = _p.replace('FOR_RANGE(','').replace(')','').split(',')
+                    _s = 'for (int {m[0]} = {m[1]}; {m[0]} < {m[2]}; {m[0]}++)'.format(m=_m)
+                    line = line.replace(_p, _s)
+                usr_code.append(line + '\n')
+        else:
+            for line in new_text[0].split('\n'):
+                usr_code.append(line + '\n')
         if len(new_text[1]) > 0:
             for c in new_text[1]:
                 usr_code.append('//' + c[0][1:] + '\n')
