@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -140,7 +140,11 @@ def arg_parser(argv):
     Process the passed command line arguments.
     """
 
-    prog = os.path.basename(sys.argv[0]) + " " + sys.argv[1]
+    try:
+        prog = os.path.basename(sys.argv[0]) + " " + sys.argv[1]
+    except Exception:
+        prog = "code_saturne"
+
     parser = argparse.ArgumentParser(description="Run a case or specified run stages.",
                                      prog=prog)
 
@@ -240,6 +244,12 @@ def arg_parser(argv):
                         help="automatically resubmit a computation if current " \
                              + "ends for a lack of sufficient wall time.")
 
+    parser.add_argument("--mem-log", dest="mem_log",
+                        action="store_true",
+                        help="set CS_MEM_LOG environment variable to 'cs_mem.log' " \
+                            + "and check that memory is correctly freed at the " \
+                            + "end of the computation.")
+
     parser.set_defaults(compute_build=False)
     parser.set_defaults(suggest_id=False)
     parser.set_defaults(stage=None)
@@ -253,6 +263,7 @@ def arg_parser(argv):
     parser.set_defaults(nthreads=None)
     parser.set_defaults(resource=None)
     parser.set_defaults(auto_restart=False)
+    parser.set_defaults(mem_log=False)
 
     return parser
 
@@ -388,10 +399,12 @@ def process_options(options, pkg):
            'n_procs': options.nprocs,
            'n_threads': options.nthreads,
            'time_limit': None,
+           'expected_time': None,
            'compute_build': compute_build,
            'debug_args': None,
            'tool_args': None,
-           'mpi_tool_args': None}
+           'mpi_tool_args': None,
+           'mem_log':options.mem_log}
 
     if options.debug_args:
         r_c['debug_args'] = cs_exec_environment.assemble_args(options.debug_args)
@@ -428,7 +441,8 @@ def read_run_config_file(i_c, r_c, s_c, pkg, run_conf=None):
     run_conf_kw = ('job_parameters', 'job_header',
                    'run_prologue', 'run_epilogue',
                    'compute_prologue', 'compute_epilogue',
-                   'debug_args', 'tool_args', 'mpi_tool_args')
+                   'debug_args', 'tool_args', 'mpi_tool_args',
+                   'mem_log')
 
     # Keys used for all cases/resources (global)
     run_conf_kw_glob = ('run_prologue', 'run_epilogue',
@@ -490,28 +504,48 @@ def read_run_config_file(i_c, r_c, s_c, pkg, run_conf=None):
     if not r_c['compute_build']:
         r_c['compute_build'] = run_conf.get_bool('run', 'compute_build')
 
+    specific_resource_name = ""
     resource_name = i_c['resource_name']
-    if not resource_name or not resource_name in run_conf.sections:
+
+    # Try to find specific configuration with run_id in the form
+    # [<resource>/run_id=<run_id>] otherwise use classical resource
+
+    if resource_name:
+        resource_name = resource_name.lower()
+        if r_c['run_id']:
+            specific_resource_name = resource_name + "/run_id=" + r_c['run_id'].lower()
+
+    if not resource_name \
+       or (not resource_name in run_conf.sections
+           and not specific_resource_name in run_conf.sections):
         resource_name = i_c['batch']
-        if resource_name:
-            resource_name = os.path.basename(resource_name).lower()
-            i = resource_name.rfind(".")
-            if i > -1:
-                resource_name = resource_name[i+1:]
-    if not resource_name or not resource_name in run_conf.sections:
-        resource_name = 'job_defaults'
+        if resource_name and r_c['run_id']:
+            specific_resource_name = resource_name + "/run_id=" + r_c['run_id'].lower()
+        if not resource_name \
+           or (not resource_name in run_conf.sections
+               and not specific_resource_name in run_conf.sections):
+            resource_name = 'job_defaults'
+
+    if r_c['run_id']:
+        specific_resource_name = resource_name + "/run_id=" + r_c['run_id'].lower()
+        if specific_resource_name in run_conf.sections:
+            resource_name = specific_resource_name
 
     run_conf_r = None
+
     if resource_name in run_conf.sections:
         run_conf_r = run_conf.sections[resource_name]
 
     if run_conf_r:
-        for kw in ('n_procs', 'n_threads', 'time_limit'):
+        for kw in ('n_procs', 'n_threads', 'time_limit', 'expected_time'):
             if kw in r_c:
                 if r_c[kw] != None:
                     continue
             r_c[kw] = None
-            v = run_conf.get_int(resource_name, kw)
+            if kw == 'expected_time':
+                v = run_conf.get_expected_time(resource_name, kw)
+            else:
+                v = run_conf.get_int(resource_name, kw)
             if v:
                 r_c[kw] = v
 
@@ -604,7 +638,7 @@ def generate_run_config_file(path, resource_name, r_c, s_c, pkg):
                        'finalize': s_c['save_results']}
 
     r_d = {}
-    for kw in ('n_procs', 'n_threads', 'time_limit'):
+    for kw in ('n_procs', 'n_threads', 'time_limit', 'expected_time'):
         if r_c[kw]:
             r_d[kw] = r_c[kw]
 
@@ -630,6 +664,9 @@ def run(argv=[], pkg=None, run_args=None, submit_args=None):
     returns return code, run id, and results directory path when created.
     """
 
+    # Avoid writing __pycache__ for user-defined Python code
+    sys.dont_write_bytecode = True
+
     if not pkg:
         from code_saturne.base.cs_package import package
         pkg = package()
@@ -729,6 +766,8 @@ def run(argv=[], pkg=None, run_args=None, submit_args=None):
     c.compute_prologue = r_c['compute_prologue']
     c.compute_epilogue = r_c['compute_epilogue']
 
+    c.mem_log = r_c['mem_log']
+
     c.debug_args = r_c['debug_args']
     c.tool_args = r_c['tool_args']
     c.mpi_tool_args = r_c['mpi_tool_args']
