@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -66,12 +66,15 @@ from code_saturne.model.InterfacialAreaModel import InterfacialAreaModel
 from code_saturne.model.NeptuneWallTransferModel import NeptuneWallTransferModel
 from code_saturne.model.InterfacialEnthalpyModel import InterfacialEnthalpyModel
 from code_saturne.model.HgnModel import HgnModel
+from code_saturne.model.HTSModel import HTSModel
 
 from code_saturne.model.LagrangianModel import LagrangianModel
 from code_saturne.model.TurboMachineryModel import TurboMachineryModel
 from code_saturne.model.MobileMeshModel import MobileMeshModel
 from code_saturne.model.FansModel import FansStatus
 
+from code_saturne.model.TurbulenceModel import TurbulenceModel
+
 # -------------------------------------------------------------------------------
 # log config
 # -------------------------------------------------------------------------------
@@ -124,6 +127,8 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
 
         self.modelNeptuneCFD     = QtPage.ComboModel(self.comboBoxNeptuneCFD,2,1)
 
+        self.modelHTS            = QtPage.ComboModel(self.comboBoxHTS,1,1)
+
         self.modelSinglePhase.addItem(self.tr("Incompressible"), 'off')
         self.modelSinglePhase.addItem(self.tr("Compressible, perfect gas with constant gamma"),
                                       'constant_gamma')
@@ -135,16 +140,17 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
         self.modelAtmospheric.addItem(self.tr("dry atmosphere"  ), "dry")
         self.modelAtmospheric.addItem(self.tr("humid atmosphere"), "humid")
         self.modelAtmospheric.addItem(self.tr("humid atmosphere for cooling towers"), "humid_ctwr")
+        self.modelAtmospheric.addItem(self.tr("cooling towers only"), "ctwr")
 
         self.modelReactiveFlows.addItem(self.tr("Gas combustion"),
                                         "gas_combustion")
         self.modelReactiveFlows.addItem(self.tr("Pulverized Coal"),
                                         "pulverized_coal")
 
-        self.modelGasCombustion.addItem(self.tr("perfect premixed flame (Eddy Break-Up)"),
-                                        "ebu")
         self.modelGasCombustion.addItem(self.tr("infinitely fast chemistry diffusion flame"),
                                         "d3p")
+        self.modelGasCombustion.addItem(self.tr("perfect premixed flame (Eddy Break-Up)"),
+                                        "ebu")
         self.modelGasCombustion.addItem(self.tr("partial premixed flame (Libby_Williams)"),
                                         "lwp")
 
@@ -172,6 +178,9 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
         self.modelNeptuneCFD.addItem(self.tr("Particle-laden flow"), "particles_flow")
         self.modelNeptuneCFD.addItem(self.tr("Multiregime liquid/gas flow"), "multiregime")
 
+        # HTS combobox
+        self.modelHTS.addItem(self.tr("Heat conduction"), "hts_conduction")
+
         # Lagrangian combobox
 
         self.modelLagrangian = QtPage.ComboModel(self.comboBoxLagrangian, 4, 1)
@@ -202,6 +211,7 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
         self.comboBoxSinglePhase.activated[str].connect(self.slotSinglePhase)
         self.comboBoxGroundwater.activated[str].connect(self.slotGroundwater)
         self.comboBoxHgn.activated[str].connect(self.slotHgn)
+        self.comboBoxHTS.activated[str].connect(self.slotHTS)
         self.comboBoxNeptuneCFD.currentTextChanged[str].connect(self.slotNeptuneCFD)
         self.checkBoxNeptuneHeatMass.stateChanged.connect(self.slotNeptuneHeatMass)
         self.checkBoxALE.stateChanged.connect(self.slotALE)
@@ -212,7 +222,7 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
 
         for ind in ['SinglePhase', 'Atmospheric',
                     'JouleEffect', 'Groundwater', 'ReactiveFlows',
-                    'Hgn', 'NeptuneCFD']:
+                    'Hgn', 'NeptuneCFD', 'HTS']:
             eval('self.radioButton'+ind+'.toggled.connect(self.slotRadioButton)')
 
         # Initializations based on code
@@ -278,6 +288,7 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
         self.comboBoxJouleEffect.hide()
         self.comboBoxGroundwater.hide()
         self.comboBoxHgn.hide()
+        self.comboBoxHTS.hide()
         self.comboBoxNeptuneCFD.hide()
 
         self.checkBoxNeptuneHeatMass.hide()
@@ -299,7 +310,8 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
                         'Hgn',
                         'NeptuneCFD',
                         'Lagrangian',
-                        'TurboMachinery']:
+                        'TurboMachinery',
+                        'HTS']:
             log.debug("__stringModelFromCombo() Incorrect name for QComboBox name")
             string = ""
         else:
@@ -343,6 +355,7 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
         self.comp  = CompressibleModel(self.case)
         self.darc  = GroundwaterModel(self.case)
         self.hgn   = HgnModel(self.case)
+        self.hts   = HTSModel(self.case)
 
         from code_saturne.model.TimeStepModel import TimeStepModel
 
@@ -353,6 +366,7 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
         gas = self.gas.getGasCombustionModel()
         compressible = self.comp.getCompressibleModel()
         homogeneous = self.hgn.getHgnModel()
+        hts = self.hts.getHTSModel()
 
         # Set combobox values
 
@@ -386,6 +400,9 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
         elif homogeneous != 'off':
             self.modelHgn.setItem(str_model=homogeneous)
 
+        elif hts != 'off':
+            self.modelHTS.setItem(str_model=hts)
+
         else:
             self.modelSinglePhase.setItem(str_model=compressible)
 
@@ -398,6 +415,7 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
         ReactiveFlows = self.gas.getGasCombustionModel()  != 'off' \
                         or self.pcoal.getCoalCombustionModel() != 'off'
         Hgn = homogeneous != 'off'
+        HTS = hts != 'off'
 
         self.checkPrev = 'SinglePhase'
         combo = None
@@ -406,7 +424,8 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
                     'JouleEffect',
                     'Groundwater',
                     'ReactiveFlows',
-                    'Hgn']:
+                    'Hgn',
+                    'HTS']:
 
             radioButton = eval('self.radioButton'+ind)
             model_on = eval(ind)
@@ -525,7 +544,6 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
 
         # Other features
 
-        self.checkBoxALE.hide()
         self.checkBoxFans.hide()
         self.checkBoxPther.hide()
 
@@ -540,7 +558,6 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
         self.modelTurboMachinery.setItem(str_model = mdl)
 
         # ALE
-
         ale_status = self.ale.getMethod()
         if ale_status == 'on':
             self.checkBoxALE.setChecked(True)
@@ -579,7 +596,8 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
                     'JouleEffect',
                     'Groundwater',
                     'ReactiveFlows',
-                    'NeptuneCFD']:
+                    'NeptuneCFD',
+                    'HTS']:
 
             radioButton = eval('self.radioButton'+ind)
             combo = eval('self.comboBox'+ind)
@@ -662,6 +680,14 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
                 self.checkBoxPther.hide()
 
                 self.modelLagrangian.enableItem(str_model='two_way')
+            if self.checkPrev == 'HTS':
+                self.hts.setHTSModel('off')
+                self.labelLagrangian.show()
+                self.comboBoxLagrangian.show()
+                self.labelTurboMachinery.show()
+                self.comboBoxTurboMachinery.show()
+                self.checkBoxALE.show()
+                self.checkBoxFans.show()
 
             if checkCur == 'ReactiveFlows':
                 if self.pcoal.getCoalCombustionModel() != 'off':
@@ -673,6 +699,14 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
                 combo.show()
                 model_expr = 'self.slotReactiveFlows(model)'
 
+            if checkCur == 'HTS':
+                self.labelLagrangian.hide()
+                self.comboBoxLagrangian.hide()
+                self.labelTurboMachinery.hide()
+                self.comboBoxTurboMachinery.hide()
+                self.checkBoxALE.hide()
+                self.checkBoxFans.hide()
+
             eval(model_expr)
 
         self.browser.configureTree(self.case)
@@ -778,7 +812,6 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
                 self.modelNeptuneCFD.setItem(str_model=model_p)
                 return
 
-        self.checkBoxALE.hide()
         self.checkBoxFans.hide()
 
         if model == "particles_flow":
@@ -877,6 +910,20 @@ class AnalysisFeaturesView(QWidget, Ui_AnalysisFeaturesForm):
 
         self.browser.configureTree(self.case)
 
+    @pyqtSlot(str)
+    def slotHTS(self, text):
+        """
+        Called when the comboBoxHTS changed
+        """
+        self.comboBoxHTS.show()
+
+        model = self.__stringModelFromCombo('HTS')
+        self.hts.setHTSModel(model)
+
+        TurbulenceModel(self.case).setTurbulenceModel('off')
+
+        self.browser.configureTree(self.case)
+
     @pyqtSlot(str)
     def slotTurboModel(self, text):
         """
