@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -20,7 +20,7 @@
 # this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
 # Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 """
 This module contains the following classes:
@@ -30,48 +30,47 @@ This module contains the following classes:
 - BoundaryConditionsMobileMeshView
 """
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # Standard modules
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 import logging
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # Third-party modules
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 from code_saturne.gui.base.QtCore    import *
 from code_saturne.gui.base.QtGui     import *
 from code_saturne.gui.base.QtWidgets import *
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # Application modules import
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 from code_saturne.model.Common import GuiParam
 from code_saturne.gui.base.QtPage import ComboModel
-from code_saturne.gui.base.QtPage import DoubleValidator, IntValidator
+from code_saturne.gui.base.QtPage import DoubleValidator
 
 from code_saturne.gui.case.BoundaryConditionsMobileMeshForm import Ui_BoundaryConditionsMobileMeshForm
 from code_saturne.model.MobileMeshModel import MobileMeshModel
-from code_saturne.model.LocalizationModel import LocalizationModel, Zone
 from code_saturne.model.Boundary import Boundary
 
 from code_saturne.gui.case.QMegEditorView import QMegEditorView
 from code_saturne.model.NotebookModel import NotebookModel
 from code_saturne.model.TimeTablesModel import TimeTablesModel
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # log config
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 logging.basicConfig()
 log = logging.getLogger("BoundaryConditionsMobileMeshView")
 log.setLevel(GuiParam.DEBUG)
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # Coupling base class
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 class Coupling:
     """
@@ -147,9 +146,9 @@ class Coupling:
         return getattr(self.__boundary, "getZoneName")()
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # LineEdit Coupling class
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 class LineEditCoupling(Coupling):
     """
@@ -187,9 +186,9 @@ class LineEditCoupling(Coupling):
         """
         self.setBoundaryDefinedValue(text)
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # Coupling Formula class
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 class FormulaCoupling(Coupling):
     """
@@ -216,12 +215,11 @@ class FormulaCoupling(Coupling):
             self.object_type = 'stiffness_matrix'
         elif getter == 'getDampingMatrix':
             self.object_type = 'damping_matrix'
-        elif getter == 'getFluidForceMatrix':
+        elif getter == "getFluidForce":
             self.object_type = 'fluid_force'
 
         button.clicked.connect(self.__slotFormula)
 
-
     def onBoundarySet(self):
         """
         Called when boundary is set.
@@ -229,7 +227,6 @@ class FormulaCoupling(Coupling):
         # call getter to create default value if needed
         self.getBoundaryDefinedValue()
 
-
     # NOTE: as above, do not use decorator to avoid crash in PyQt5.
 
     # @pyqtSlot(bool)
@@ -258,9 +255,9 @@ class FormulaCoupling(Coupling):
             log.debug("FormulaCoupling -> %s" % str(result))
             self.setBoundaryDefinedValue(result)
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # CouplingManager class
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 class CouplingManager:
     """
@@ -280,7 +277,6 @@ class CouplingManager:
         self.__initFormulaCouplings (mainView)
         self.case.undoStartGlobal()
 
-
     def __initLineEditCouplings(self, mainView):
         """
         Initialize the creation of LineEditCoupling
@@ -318,7 +314,6 @@ class CouplingManager:
                                           "setInitialVelocityZ"))
         self.__internalCouplings.extend(couplings)
 
-
     def __initFormulaCouplings(self, mainView):
         """
         Initialize the creation of the formula button
@@ -393,7 +388,7 @@ k11 = 2;\nk22 = 2;\nk33 = 2;\nk12 = 0;\nk13 = 0;\nk23 = 0;\nk21 = 0;\nk31 = 0;\n
         requiredFluidForce = [('fx', 'force applied to the structure along X'),
                               ('fy', 'force applied to the structure along Y'),
                               ('fz', 'force applied to the structure along Z')]
-        symbolsFluidForce = symbols[:];
+        symbolsFluidForce = symbols[:]
         symbolsFluidForce.append(('fluid_fx', 'force of flow along X'))
         symbolsFluidForce.append(('fluid_fy', 'force of flow along Y'))
         symbolsFluidForce.append(('fluid_fz', 'force of flow along Z'))
@@ -401,17 +396,20 @@ k11 = 2;\nk22 = 2;\nk33 = 2;\nk12 = 0;\nk13 = 0;\nk23 = 0;\nk21 = 0;\nk31 = 0;\n
         examplesFluidForce = """# The fluid force is zero in the Y direction.
 #
 fx = fluid_fx;\nfy = 0;\nfz = fluid_fz;"""
-        couplings.append(FormulaCoupling(mainView.pushButtonFluidForce,
-                                         mainView,
-                                         "getFluidForceMatrix",
-                                         "setFluidForceMatrix",
-                                         defaultFluidForce,
-                                         requiredFluidForce,
-                                         symbolsFluidForce,
-                                         examplesFluidForce))
+        couplings.append(
+            FormulaCoupling(
+                mainView.pushButtonFluidForce,
+                mainView,
+                "getFluidForce",
+                "setFluidForce",
+                defaultFluidForce,
+                requiredFluidForce,
+                symbolsFluidForce,
+                examplesFluidForce,
+            )
+        )
         self.__internalCouplings.extend(couplings)
 
-
     def setBoundary(self, boundary):
         """
         Assign a boundary.
@@ -421,9 +419,9 @@ fx = fluid_fx;\nfy = 0;\nfz = fluid_fz;"""
             coupling.setBoundary(boundary)
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # Main class
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 class BoundaryConditionsMobileMeshView(QWidget,
                                        Ui_BoundaryConditionsMobileMeshForm):
@@ -439,7 +437,6 @@ class BoundaryConditionsMobileMeshView(QWidget,
         Ui_BoundaryConditionsMobileMeshForm.__init__(self)
         self.setupUi(self)
 
-
     def setup(self, case):
         """
         Setup the widget
@@ -462,19 +459,24 @@ class BoundaryConditionsMobileMeshView(QWidget,
         self.comboMobilBoundary.activated[str].connect(self.__slotCombo)
         self.pushButtonMobilBoundary.clicked.connect(self.__slotFormula)
 
+        # Combo model FSISOLVER
+        self.__modelExtSOLVER = ComboModel(self.comboMobilExternalSolver, 2, 1)
+        self.__modelExtSOLVER.addItem(self.tr("code_aster"), "code_aster")
+        self.__modelExtSOLVER.addItem(self.tr("user"), "user")
+        self.comboMobilExternalSolver.activated[str].connect(self.__slotExtSolverType)
+
         # Coupling Manager
         self.__couplingManager = CouplingManager(self, case)
 
         self.case.undoStartGlobal()
 
-
     @pyqtSlot()
     def __slotFormula(self):
         """
         Run formula editor.
         """
         exp = self.__boundary.getALEFormula()
-        c = self.__boundary.getALEChoice();
+        c = self.__boundary.getALEChoice()
 
         if c == "fixed_velocity":
             if not exp:
@@ -522,6 +524,17 @@ class BoundaryConditionsMobileMeshView(QWidget,
             self.pushButtonMobilBoundary.setStyleSheet("background-color: green")
             self.pushButtonMobilBoundary.setToolTip(result)
 
+    @pyqtSlot(str)
+    def __slotExtSolverType(self, text):
+        """
+        Input External solver : code_aster or user.
+        """
+        solver = self.__modelExtSOLVER.dicoV2M[str(text)]
+
+        if solver == self.__boundary.getALEExtSolver():
+            return
+
+        self.__boundary.setALEExtSolver(solver)
 
     @pyqtSlot(str)
     def __slotCombo(self, text):
@@ -546,12 +559,12 @@ class BoundaryConditionsMobileMeshView(QWidget,
         else:
             self.pushButtonMobilBoundary.setStyleSheet("background-color: red")
 
-
     def update_view(self, modelData):
         """
         Show the widgets matching the model
         """
         self.__comboModel.setItem(str_model=modelData)
+
         if modelData in ["fixed_velocity", "fixed_displacement"]:
             self.pushButtonMobilBoundary.show()
         else:
@@ -560,37 +573,42 @@ class BoundaryConditionsMobileMeshView(QWidget,
             self.groupBoxStructureVelPos.show()
             self.groupBoxStructureCharacteristics.show()
             self.groupBoxForceApplied.show()
+            self.groupBoxExternalSoler.hide()
+            boundary = Boundary("coupling_mobile_boundary",
+                                self.__boundary.getLabel(), self.case)
+
+            self.__boundary = boundary
+            self.__couplingManager.setBoundary(boundary)
         else:
             self.groupBoxStructureVelPos.hide()
             self.groupBoxStructureCharacteristics.hide()
             self.groupBoxForceApplied.hide()
 
+        if modelData == "external_coupling":
+            self.__modelExtSOLVER.setItem(str_model=self.__boundary.getALEExtSolver())
+            self.groupBoxExternalSoler.show()
+        else:
+            self.groupBoxExternalSoler.hide()
 
     def showWidget(self, b):
         """
         Show the widget
         """
         if self.__model.getMethod() != "off":
+
             modelData = b.getALEChoice()
+            self.__boundary = b
             if b.getNature() == "wall":
                 self.__comboModel.enableItem(str_model="internal_coupling")
                 self.__comboModel.enableItem(str_model="external_coupling")
             else:
                 self.__comboModel.disableItem(str_model="internal_coupling")
                 self.__comboModel.disableItem(str_model="external_coupling")
-            if modelData == 'internal_coupling':
-                boundary = Boundary("coupling_mobile_boundary",
-                                    b.getLabel(), self.case)
-                self.__boundary = boundary
-                self.__couplingManager.setBoundary(boundary)
-            else:
-                self.__boundary = b
             self.update_view(modelData)
             self.show()
         else:
             self.hideWidget()
 
-
     def hideWidget(self):
         """
         Hide all
@@ -598,6 +616,6 @@ class BoundaryConditionsMobileMeshView(QWidget,
         self.hide()
 
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # End
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
