@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -239,7 +239,7 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
                                           'exchange_coefficient_formula')
             self.modelTypeMeteo.addItem(self.tr("Exchange coefficient (user law)"),
                                         'exchange_coefficient_formula')
-            self.modelTypeThermal.addItem(self.tr("SYRTHES coupling"), "syrthes_coupling")
+            self.modelTypeThermal.addItem(self.tr("CHT coupling"), "syrthes_coupling")
 
         elif self.nature == 'groundwater':
             self.modelTypeSpecies.addItem(self.tr("Prescribed (outgoing) flux"), 'neumann')
