@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -56,6 +56,7 @@ from code_saturne.model.FluidCharacteristicsModel import FluidCharacteristicsMod
 from code_saturne.model.DefineUserScalarsModel import DefineUserScalarsModel
 from code_saturne.model.ThermalScalarModel import ThermalScalarModel
 from code_saturne.model.GroundwaterModel import GroundwaterModel
+from code_saturne.model.HTSModel import HTSModel
 from code_saturne.gui.case.QMegEditorView import QMegEditorView
 from code_saturne.model.NotebookModel import NotebookModel
 from code_saturne.model.InternalCouplingModel import InternalCouplingModel
@@ -224,6 +225,11 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         s = self.m_th.getThermalScalarName()
         tsm = self.mdl.tsm
 
+        self.m_hts = HTSModel(self.case)
+        n_al = 2
+        if self.m_hts.getHTSModel() != 'off':
+            n_al = 3
+
         # Particular Widget init. taking into account chosen fluid model
         mdl_atmo, mdl_joule, mdl_thermal, mdl_gas, mdl_coal, mdl_comp, mdl_hgn=\
             self.mdl.getThermoPhysicalModel()
@@ -234,7 +240,7 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         self.modelMu        = ComboModel(self.comboBoxMu,       2, 1)
         self.modelSigma     = ComboModel(self.comboBoxSigma,    1, 1)
         self.modelCp        = ComboModel(self.comboBoxCp,       2, 1)
-        self.modelAl        = ComboModel(self.comboBoxAl,       2, 1)
+        self.modelAl        = ComboModel(self.comboBoxAl,       n_al, 1)
         self.modelDiff      = ComboModel(self.comboBoxDiff,     2, 1)
         self.modelNameDiff  = ComboModel(self.comboBoxNameDiff, 1, 1)
         self.modelViscv0    = ComboModel(self.comboBoxViscv0,   3, 1)
@@ -283,6 +289,8 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         if mdl_joule != 'off':
             self.modelAl.addItem(self.tr('predefined law'), 'predefined_law')
         self.modelAl.addItem(self.tr('user law'), 'user_law')
+        if n_al == 3:
+            self.modelAl.addItem(self.tr('user law, anisotropic'), 'user_law_anisotropic')
 
         self.modelDiff.addItem(self.tr('constant'), 'constant')
         self.modelDiff.addItem(self.tr('user law'), 'user_law')
@@ -312,7 +320,10 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         validatorP0 = DoubleValidator(self.lineEditP0, min=0.0)
         self.lineEditP0.setValidator(validatorP0)
 
-        validatorT0 = DoubleValidator(self.lineEditT0,  min=0.0)
+        min_t0 = 0.0
+        if tsm == 'temperature_celsius':
+            min_t0 = -273.15
+        validatorT0 = DoubleValidator(self.lineEditT0,  min=min_t0)
         validatorT0.setExclusiveMin(True)
         self.lineEditT0.setValidator(validatorT0)
 
@@ -430,10 +441,15 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         self.groupBoxMassMolar.hide()
 
         isLargeScaleMeteoChecked = AtmosphericFlowsModel(self.case).getLargeScaleMeteoStatus() == 'on'
-        if mdl_atmo != "off" and isLargeScaleMeteoChecked:
+        hasMeteoFile = AtmosphericFlowsModel(self.case).getMeteoDataStatus() == "on"
+        isMeteoChecked = hasMeteoFile or isLargeScaleMeteoChecked
+        if mdl_atmo != "off" and isMeteoChecked:
             self.groupBoxTemperature.setEnabled(False)
-            t = AtmosphericFlowsModel(self.case).getMeteoT0()
-            self.lineEditT0.setText(str(t))
+            if isLargeScaleMeteoChecked:
+                t = AtmosphericFlowsModel(self.case).getMeteoT0()
+                self.lineEditT0.setText(str(t))
+            elif hasMeteoFile:
+                self.groupBoxTemperature.hide()
 
         elif mdl_comp != "off" or mdl_coal != "off":
             m = self.mdl.getMassemol()
@@ -464,14 +480,19 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         darc = GroundwaterModel(self.case).getGroundwaterModel()
         if darc != 'off':
             self.groupBoxPressure.hide()
-        elif mdl_atmo != 'off' and isLargeScaleMeteoChecked:
-            self.groupBoxPressure.setEnabled(False)
-            p = AtmosphericFlowsModel(self.case).getMeteoPsea()
-            self.lineEditP0.setText(str(p))
-            self.groupBoxPressure.setEnabled(False)
+        elif mdl_atmo != 'off' and isMeteoChecked:
+            if isLargeScaleMeteoChecked:
+                self.groupBoxPressure.setEnabled(False)
+                p = AtmosphericFlowsModel(self.case).getMeteoPsea()
+                self.lineEditP0.setText(str(p))
+                self.groupBoxPressure.setEnabled(False)
+            elif hasMeteoFile:
+                self.groupBoxPressure.hide()
 
         else:
             p = self.mdl.getPressure()
+            if p is None:
+                p = self.defaultFluidCharacteristicsValues()['reference_pressure']
             self.lineEditP0.setText(str(p))
 
         if self.mdl.tables == 0 or mdl_joule != 'off' or mdl_comp != 'off':
@@ -499,7 +520,7 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
             self.widgetRefMu.hide()
             self.widgetVofMu.setVisible(is_main_zone)
             self.groupBoxSigma.setVisible(is_main_zone)
-        elif mdl_atmo != 'off' and isLargeScaleMeteoChecked:
+        elif mdl_atmo != 'off' and isMeteoChecked:
             self.widgetRefRho.hide()
             self.widgetVofRho.hide()
             self.widgetRefMu.setVisible(is_main_zone)
@@ -682,6 +703,10 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
                     __button.setEnabled(False)
                     __button.hide()
 
+            # HTS
+            if self.m_hts.getHTSModel() != 'off':
+                self.groupBoxMu.setVisible(False)
+
             # Compressible Flows
             if mdl_comp != 'off':
                 self.groupBoxViscv0.setVisible(is_main_zone)
