@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -121,7 +121,7 @@ class InterfacialForcesView(QWidget, Ui_InterfacialForces):
                         "standard": 'Standard',
                         "zuber": 'Zuber',
                         "coef_cst": 'Constant coefficient',
-                        "Tomiyama_SMD": 'Tomiyama SMD',
+                        "Tomiyama": 'Tomiyama',
                         "Zeng_Baalbaki": "Zeng and Baalbaki",
                         "Large_Interface_Model": "Large Interface Model",
                         "Large_Bubble_Model": "Large Bubble Model",
@@ -254,6 +254,7 @@ class InterfacialForcesView(QWidget, Ui_InterfacialForces):
         GTD_condition_1 = (TurbulenceModel(self.case).getTurbulenceModel("1") in
                            ["k-epsilon",
                             "k-epsilon_linear_production",
+                            "k-omega-SST",
                             "rij-epsilon_ssg",
                             "rij-epsilon_ebrsm"])
 
@@ -271,7 +272,7 @@ class InterfacialForcesView(QWidget, Ui_InterfacialForces):
     def lockDropletFlowOptions(self):
         self.comboBoxDispersedDrag.setEnabled(False)
 
-        self.modelLift.disableItem(str_model="Tomiyama_SMD")
+        self.modelLift.disableItem(str_model="Tomiyama")
         self.modelLift.disableItem(str_model="coef_cst")
         self.comboBoxLift.setEnabled(True)
 
