@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -286,7 +286,7 @@ class LagrangianView(QWidget, Ui_LagrangianForm):
         else:
             self.checkBoxISUILA.setChecked(False)
 
-        status = self.model.getCarrierFlowStationary()
+        status = self.model.getCarrierFlowSteady()
         if status == "on":
             self.checkBoxISTTIO.setChecked(True)
         else:
@@ -391,9 +391,9 @@ class LagrangianView(QWidget, Ui_LagrangianForm):
         Input ISTTIO.
         """
         if self.checkBoxISTTIO.isChecked():
-            self.model.setCarrierFlowStationary("on")
+            self.model.setCarrierFlowSteady("on")
         else:
-            self.model.setCarrierFlowStationary("off")
+            self.model.setCarrierFlowSteady("off")
 
 
     @pyqtSlot()
