@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -333,7 +333,7 @@ class StandardItemModelMainFields(QStandardItemModel):
                          self.tr("Phase of\nfield"),
                          self.tr("Interfacial criterion"),
                          self.tr("Carrier phase"),
-                         self.tr("Compressible"),
+                         self.tr("Variable density"),
                          self.tr("Energy\nresolution")]
 
         self.setColumnCount(len(self.headers))
