@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -73,18 +73,25 @@ class item_class(object):
     '''
     custom data object
     '''
-    def __init__(self, idx, name, value, oturns_var, editable, restart, description):
-        self.index  = idx
-        self.name   = name
-        self.value  = value
-        self.oturns = oturns_var
-        self.edit   = editable
-        self.read   = restart
-        self.descr  = description
+    def __init__(self, idx, name, value, oturns_var, editable, restart, log,
+                 description):
+        self.index   = idx
+        self.name    = name
+        self.value   = value
+        self.oturns  = oturns_var
+        self.edit    = editable
+        self.restart = restart
+        self.log     = log
+        self.descr   = description
+
 
     def __repr__(self):
-        return "variable : %s // value : %s // used with openturns : %s"\
-               % (self.name, self.value, self.oturns)
+        return ("index : %s // variable : %s // value : %s // " \
+                "used with openturns : %s // editable : %s // " \
+                "read at restart : %s // log : %s //" \
+                % (str(self.index), str(self.name), str(self.value), \
+                   str(self.oturns), str(self.edit), str(self.restart), \
+                   str(self.log)))
 
 #-------------------------------------------------------------------------------
 # Treeitem class
@@ -114,7 +121,7 @@ class TreeItem(object):
 
 
     def columnCount(self):
-        return 6
+        return 7
 
 
     def data(self, column, role):
@@ -133,8 +140,10 @@ class TreeItem(object):
             elif column == 3 and role == Qt.DisplayRole:
                 return self.item.edit
             elif column == 4 and role == Qt.DisplayRole:
-                return self.item.read
+                return self.item.restart
             elif column == 5 and role == Qt.DisplayRole:
+                return self.item.log
+            elif column == 6 and role == Qt.DisplayRole:
                 return self.item.descr
         return None
 
@@ -149,6 +158,22 @@ class TreeItem(object):
         return 0
 
 
+    def __repr__(self):
+        msg = "TreeItem: item : %s\n" % repr(self.item)
+
+        if self.parentItem:
+            msg += "parentItem : %s\n" % str(self.parentItem.header)
+        else:
+            msg += "parentItem : ALL\n"
+
+        msg += "childItems : "
+        for child in self.childItems:
+            msg += child.header + " "
+        msg += "\n"
+
+        return msg
+
+
 #-------------------------------------------------------------------------------
 # StandarItemModelOutput class
 #-------------------------------------------------------------------------------
@@ -175,7 +200,7 @@ class VariableStandardItemModel(QAbstractItemModel):
         if parent and parent.isValid():
             return parent.internalPointer().columnCount()
         else:
-            return 6
+            return 7
 
 
     def data(self, index, role):
@@ -201,6 +226,8 @@ class VariableStandardItemModel(QAbstractItemModel):
             elif index.column() == 4:
                 return self.tr("Read at restart")
             elif index.column() == 5:
+                return self.tr("Print to default log file")
+            elif index.column() == 6:
                 return self.tr("Description")
 
         # Display
@@ -218,7 +245,6 @@ class VariableStandardItemModel(QAbstractItemModel):
         if (index.row(), index.column()) in self.disabledItem:
             return Qt.ItemIsEnabled
 
-        itm = index.internalPointer()
         if index.column() == 3:
             if "Yes" in self.mdl.getVariableOt(index.row()):
                 return Qt.NoItemFlags
@@ -231,16 +257,18 @@ class VariableStandardItemModel(QAbstractItemModel):
     def headerData(self, section, orientation, role):
         if orientation == Qt.Horizontal and role == Qt.DisplayRole:
             if section == 0:
-                return self.tr("variable name")
+                return self.tr("Variable name")
             elif section == 1:
-                return self.tr("value")
+                return self.tr("Value")
             elif section == 2:
-                return self.tr("OpenTurns Variable")
+                return self.tr("OpenTurns\nVariable")
             elif section == 3:
                 return self.tr("Editable")
             elif section == 4:
-                return self.tr("Read at restart")
+                return self.tr("Read at\nrestart")
             elif section == 5:
+                return self.tr("Print to default\nlog file")
+            elif section == 6:
                 return self.tr("Description")
         return None
 
@@ -294,13 +322,15 @@ class VariableStandardItemModel(QAbstractItemModel):
     def populateModel(self):
         for idx in self.mdl.getVarList():
             parentItem = self.rootItem
-            cname  = self.mdl.getVariableName(idx)
-            value  = self.mdl.getVariableValue(idx)
-            oturns = self.mdl.getVariableOt(idx)
-            edit   = self.mdl.getVariableEditable(idx)
-            read   = self.mdl.getVariableRestart(idx)
-            descr  = self.mdl.getVariableDescription(idx)
-            item = item_class(idx, cname, value, oturns, edit, read, descr)
+            cname   = self.mdl.getVariableName(idx)
+            value   = self.mdl.getVariableValue(idx)
+            oturns  = self.mdl.getVariableOt(idx)
+            edit    = self.mdl.getVariableEditable(idx)
+            restart = self.mdl.getVariableRestart(idx)
+            log     = self.mdl.getVariableLog(idx)
+            descr   = self.mdl.getVariableDescription(idx)
+            item = item_class(idx, cname, value, oturns, edit, restart, log,
+                              descr)
             new_item = TreeItem(item, cname, parentItem)
             parentItem.appendChild(new_item)
 
@@ -322,18 +352,38 @@ class VariableStandardItemModel(QAbstractItemModel):
             value = from_qvariant(value, to_text_string)
             item.item.oturns = value
             self.mdl.setVariableOt(item.item.index, item.item.oturns)
+            # Input OT variables not editable and not written in log file
+            if value == "Yes: Input":
+                item.item.edit = "No"
+                self.mdl.setVariableEditable(item.item.index, item.item.edit)
+                item.item.log = "No"
+                self.mdl.setVariableLog(item.item.index, item.item.log)
+            # Output OT variables are editable and written in log file
+            elif value == "Yes: Output":
+                item.item.edit = "Yes"
+                self.mdl.setVariableEditable(item.item.index, item.item.edit)
+                # value already set to Yes in model
+                item.item.log = "Yes"
 
         elif index.column() == 3:
             editable = from_qvariant(value, to_text_string)
             item.item.edit = editable
             self.mdl.setVariableEditable(item.item.index, item.item.edit)
+            if editable == "Yes":
+                # value already set to Yes in model
+                item.item.log = "Yes"
 
         elif index.column() == 4:
             restart = from_qvariant(value, to_text_string)
-            item.item.read = restart
-            self.mdl.setVariableRestart(item.item.index, item.item.read)
+            item.item.restart = restart
+            self.mdl.setVariableRestart(item.item.restart, idx=item.item.index)
 
         elif index.column() == 5:
+            log = from_qvariant(value, to_text_string)
+            item.item.log = log
+            self.mdl.setVariableLog(item.item.index, item.item.log)
+
+        elif index.column() == 6:
             description = from_qvariant(value, to_text_string)
             item.item.descr = description
             self.mdl.setVariableDescription(item.item.index, item.item.descr)
@@ -348,7 +398,7 @@ class VariableStandardItemModel(QAbstractItemModel):
 
 class NotebookView(QWidget, Ui_NotebookForm):
     """
-    Class to open the Body Forces (gravity) Page.
+    Class to open the Notebook Page.
     """
 
     def __init__(self, parent, case):
@@ -395,15 +445,22 @@ class NotebookView(QWidget, Ui_NotebookForm):
 
         RestartOptions = ["Yes","No"]
         restartDelegate = ComboDelegate(self.treeViewNotebook,
-                                         opts_list=RestartOptions)
+                                        opts_list=RestartOptions)
         self.treeViewNotebook.setItemDelegateForColumn(4, restartDelegate)
 
+        LogOptions = ["No","Yes"]
+        logDelegate = ComboDelegate(self.treeViewNotebook,
+                                    opts_list=LogOptions)
+        self.treeViewNotebook.setItemDelegateForColumn(5, logDelegate)
+
         descriptionDelegate = LabelDelegate(self.treeViewNotebook)
-        self.treeViewNotebook.setItemDelegateForColumn(5, descriptionDelegate)
+        self.treeViewNotebook.setItemDelegateForColumn(6, descriptionDelegate)
 
         self.treeViewNotebook.resizeColumnToContents(0)
         self.treeViewNotebook.resizeColumnToContents(2)
+        self.treeViewNotebook.resizeColumnToContents(4)
         self.treeViewNotebook.resizeColumnToContents(5)
+        self.treeViewNotebook.resizeColumnToContents(6)
 
         # Connections
         self.toolButtonAdd.clicked.connect(self.slotAddVariable)
@@ -416,19 +473,6 @@ class NotebookView(QWidget, Ui_NotebookForm):
 
 
     def dataChanged(self):
-        row = self.treeViewNotebook.currentIndex().row()
-        col = self.treeViewNotebook.currentIndex().column()
-        next_item = self.treeViewNotebook.model().index(row, col+1)
-        # Check for updates
-        ot_status = self.mdl.getVariableOt(row)
-        edit_status = self.mdl.getVariableEditable(row)
-        if ot_status == "Yes: Input" and edit_status == "Yes":
-            self.mdl.setVariableEditable(row, "No")
-            self.modelVar.setData(next_item, "No")
-        elif ot_status == "Yes: Output" and edit_status == "No":
-            self.mdl.setVariableEditable(row, "Yes")
-            self.modelVar.setData(next_item, "Yes")
-
         self.update()
 
 
@@ -437,7 +481,7 @@ class NotebookView(QWidget, Ui_NotebookForm):
         """
         Add one variable
         """
-        name = self.mdl.addVariable()
+        self.mdl.addVariable()
         self.modelVar = VariableStandardItemModel(self.parent, self.case, self.mdl)
         self.treeViewNotebook.setModel(self.modelVar)
         self.treeViewNotebook.expandAll()
