@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -437,6 +437,47 @@ class SchemeNVDLimiterDelegate(QItemDelegate):
             if idx.column() == index.column():
                 model.setData(idx, value)
 
+#-------------------------------------------------------------------------------
+# Combo box delegate for b_diff_flux_rc
+#-------------------------------------------------------------------------------
+
+class SchemeBoundaryDiffFluxDelegate(QItemDelegate):
+    """
+    Use of a combo box in the table.
+    """
+    def __init__(self, parent=None, xml_model=None):
+        super(SchemeBoundaryDiffFluxDelegate, self).__init__(parent)
+        self.parent = parent
+        self.mdl = xml_model
+
+
+    def createEditor(self, parent, option, index):
+        editor = QComboBox(parent)
+        row = index.row()
+        category = index.model().dataScheme[row]['category']
+        if category > 0:
+            if index.model().dataScheme[row]['ircflu'] != 'off':
+                editor.addItem("Enabled")
+            editor.addItem("Disabled")
+        editor.installEventFilter(self)
+        return editor
+
+
+    def setEditorData(self, comboBox, index):
+        dico = {"all": 0, "off": 1}
+        row = index.row()
+        string = index.model().dataScheme[row]['b_diff_flux_rc']
+        idx = dico[string]
+        comboBox.setCurrentIndex(idx)
+
+
+    def setModelData(self, comboBox, model, index):
+        value = comboBox.currentText()
+        selectionModel = self.parent.selectionModel()
+        for idx in selectionModel.selectedIndexes():
+            if idx.column() == index.column():
+                model.setData(idx, value)
+
 #-------------------------------------------------------------------------------
 # Scheme class
 #-------------------------------------------------------------------------------
@@ -459,15 +500,16 @@ class StandardItemModelScheme(QStandardItemModel):
                         self.tr("Slope\nTest"),
                         self.tr("NVD\nLimiter"),
                         self.tr("Flux\nReconstruction"),
+                        self.tr("Boundary Flux\nReconstruction"),
                         self.tr("RHS Sweep\nReconstruction")]
         self.keys = ['name', 'ischcv', 'blencv', 'isstpc', 'nvd_limiter',
-                     'ircflu', 'nswrsm']
+                     'ircflu', 'b_diff_flux_rc', 'nswrsm']
         self.setColumnCount(len(self.headers))
 
         # Initialize the flags
         for row in range(self.rowCount()):
             for column in range(self.columnCount()):
-                if column in (1, 2, 3, 4, 6):
+                if column in (1, 2, 3, 4, 6, 7):
                     role = Qt.DisplayRole
                 else:
                     role = Qt.CheckStateRole
@@ -493,10 +535,18 @@ class StandardItemModelScheme(QStandardItemModel):
                     "and diffusive fluxes at the faces should be reconstructed\n"
                     "at non-orthogonal mesh faces.\n"
                     "Deactivating this reconstruction can have a stabilizing\n"
-                    "effect on the calculation.\n"
+                    "effect on the calculation.\n\n"
                     "It is sometimes useful with the k−ε model, if the mesh\n"
                     "is strongly non-orthogonal in the near-wall region,\n"
                     " where the gradients of k and ε are strong"),
+            self.tr("Equation parameter: 'b_diff_flux_rc'\n\n"
+                    "Flux reconstruction: indicate whether the diffusiv fluxes\n"
+                    "should be reconstructed at non-orthogonal boundary faces.\n"
+                    "Deactivating this reconstruction can have a stabilizing\n"
+                    "effect on the calculation, with less precision loss than\n"
+                    "deactiving fluxes in the volume (i.e. ircflu = 0).\n\n"
+                    "It can be useful if the mesh is strongly non-orthogonal\n"
+                    "in the near-wall region, where gradients are strong"),
             self.tr("Equation parameter: 'nswrsm'\n\n"
                     "RHS Sweep Reconstruction: number of iterations for the\n"
                     "reconstruction of the right-hand sides of the equation")
@@ -523,6 +573,11 @@ class StandardItemModelScheme(QStandardItemModel):
                                'off': "Disabled",
                                'beta_limiter': "Beta limiter"}
 
+        self.dicoV2M_b_diff_flux_rc = {"Enabled": 'all',
+                                       "Disabled": 'off'}
+        self.dicoM2V_b_diff_flux_rc = {'all': "Enabled",
+                                       'off': "Disabled"}
+
         for v in self.NPE.getSchemeList():
             name = v[0]
             dico           = {}
@@ -534,6 +589,7 @@ class StandardItemModelScheme(QStandardItemModel):
             dico['isstpc'] = self.NPE.getSlopeTest(name)
             dico['nvd_limiter'] = self.NPE.getNVDLimiter(name)
             dico['ircflu'] = self.NPE.getFluxReconstruction(name)
+            dico['b_diff_flux_rc'] = self.NPE.getBoundaryDiffFluxReconstruction(name)
             dico['nswrsm'] = self.NPE.getRhsReconstruction(name)
             dico['category'] = v[1]
             self.dataScheme.append(dico)
@@ -556,7 +612,7 @@ class StandardItemModelScheme(QStandardItemModel):
 
         if role == Qt.ToolTipRole:
             col = index.column()
-            if col > 0 and col < 7:
+            if col > 0 and col < 8:
                 return self.tooltips[col-1]
             elif col > 0:
                 return self.tr("code_saturne keyword: " + key)
@@ -575,6 +631,11 @@ class StandardItemModelScheme(QStandardItemModel):
                     return v.upper()
                 else:
                     return v
+            elif key == 'b_diff_flux_rc':
+                if self.dataScheme[row]['ircflu'] != 'off':
+                    return self.dicoM2V_b_diff_flux_rc[dico[key]]
+                else:
+                    return ""
             else:
                 return dico[key]
 
@@ -619,6 +680,11 @@ class StandardItemModelScheme(QStandardItemModel):
                 return Qt.NoItemFlags
         elif column == 5:
             return Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsUserCheckable
+        elif column == 6:
+            if self.dataScheme[row]['ircflu'] != 'off':
+                return Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsEditable
+            else:
+                return Qt.NoItemFlags
         else:
             return Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsEditable
 
@@ -695,9 +761,16 @@ class StandardItemModelScheme(QStandardItemModel):
             else:
                 self.dataScheme[row]['ircflu'] = "on"
             self.NPE.setFluxReconstruction(name, self.dataScheme[row]['ircflu'])
+            e_index = self.index(row, column+1)
+            self.dataChanged.emit(index, e_index)
+
+        # set b_diff_flux_rc
+        elif column == 6:
+            self.dataScheme[row]['b_diff_flux_rc'] = self.dicoV2M_b_diff_flux_rc[str(from_qvariant(value, to_text_string))]
+            self.NPE.setBoundaryDiffFluxReconstruction(name, self.dataScheme[row]['b_diff_flux_rc'])
 
         # set NSWRSM
-        elif column == 6:
+        elif column == 7:
             self.dataScheme[row]['nswrsm'] = from_qvariant(value, int)
             self.NPE.setRhsReconstruction(name, self.dataScheme[row]['nswrsm'])
 
@@ -712,19 +785,19 @@ class GradientTypeDelegate(QItemDelegate):
     """
     Use of a combo box in the table.
     """
-    def __init__(self, parent=None, boundary=False):
+    def __init__(self, parent=None, category='c_gradient_r'):
         super(GradientTypeDelegate, self).__init__(parent)
         self.parent = parent
-        self.boundary = boundary
+        self.category = category
 
 
     def createEditor(self, parent, option, index):
         editor = QComboBox(parent)
         row = index.row()
-        if self.boundary:
-            editor.addItem("Automatic")
-        else:
+        if self.category == 'c_gradient_r':
             editor.addItem("Global")
+        else:
+            editor.addItem("Automatic")
         editor.addItem("Green Iter")
         editor.addItem("LSQ")
         editor.addItem("LSQ Ext")
@@ -741,10 +814,7 @@ class GradientTypeDelegate(QItemDelegate):
                 "green_lsq": 4, "green_lsq_ext": 5,
                 "green_vtx": 6}
         row = index.row()
-        if self.boundary:
-            string = index.model().dataScheme[row]['b_gradient_r']
-        else:
-            string = index.model().dataScheme[row]['c_gradient_r']
+        string = index.model().dataScheme[row][self.category]
         idx = dico[string]
         comboBox.setCurrentIndex(idx)
 
@@ -848,11 +918,13 @@ class StandardItemModelGradient(QStandardItemModel):
         self.populateModel()
         self.headers = [self.tr("Name"),
                         self.tr("Volume\nGradient"),
+                        self.tr("Reconstruction\nGradient"),
                         self.tr("Boundary\nReconstruction"),
                         self.tr("Fixed-point\nThreshold"),
                         self.tr("Limiter\nType"),
                         self.tr("Limiter\nFactor")]
-        self.keys = ['name', 'c_gradient_r', 'b_gradient_r', 'epsrgr',
+        self.keys = ['name', 'c_gradient_r', 'b_gradient_r',
+                     'd_gradient_r', 'epsrgr',
                      'imligr', 'climgr']
         self.setColumnCount(len(self.headers))
 
@@ -873,6 +945,14 @@ class StandardItemModelGradient(QStandardItemModel):
                     "- Green LSQ: Green-Gauss with LSQ gradient face values\n"
                     "- Green LSQ Ext: Green-Gauss with LSQ Ext gradient face values\n"
                     "- Green VTX: Green-Gauss with vertex interpolated face values."),
+            self.tr("Equation parameter: 'd_gradient_r'\n\n"
+                    "Reconstruction gradient for diffusion;\n"
+                    "- Green Iter: Green-Gauss with iterative face value reconstruction\n"
+                    "- LSQ: least-squares on standard (face-adjacent) neighborhood\n"
+                    "- LSQ Ext: least-squares on extended neighborhood\n"
+                    "- Green LSQ: Green-Gauss with LSQ gradient face values\n"
+                    "- Green LSQ Ext: Green-Gauss with LSQ Ext gradient face values\n"
+                    "- Green VTX: Green-Gauss with vertex interpolated face values."),
             self.tr("Equation parameter: 'b_gradient_r'\n\n"
                     "Local boundary gradient for reconstruction at boundaries;\n"
                     "Using the default least-squares reconstruction\n"
@@ -922,6 +1002,7 @@ class StandardItemModelGradient(QStandardItemModel):
             dico = {}
             dico['name']  = name
             dico['c_gradient_r'] = self.NPE.getCellGradientType(name)
+            dico['d_gradient_r'] = self.NPE.getDiffusionGradientType(name)
             dico['b_gradient_r'] = self.NPE.getBoundaryGradientType(name)
             dico['epsrgr'] = self.NPE.getGradientEpsilon(name)
             dico['imligr'] = self.NPE.getGradientLimiter(name)
@@ -946,17 +1027,17 @@ class StandardItemModelGradient(QStandardItemModel):
 
         if role == Qt.ToolTipRole:
             col = index.column()
-            if col > 0 and col < 6:
+            if col > 0 and col < 7:
                 return self.tooltips[col-1]
             elif col > 0:
                 return self.tr("code_saturne keyword: " + key)
 
         elif role == Qt.DisplayRole:
-            if column in (1, 2):
+            if column in (1, 2, 3):
                 return self.dicoM2V[dico[key]]
-            elif column == 4:
-                return self.dicoM2V_imligr[dico[key]]
             elif column == 5:
+                return self.dicoM2V_imligr[dico[key]]
+            elif column == 6:
                 if self.dataScheme[row]['imligr'] != 'none':
                     return dico[key]
                 else:
@@ -982,7 +1063,7 @@ class StandardItemModelGradient(QStandardItemModel):
 
         if column == 0:
             return Qt.ItemIsEnabled | Qt.ItemIsSelectable
-        elif column == 5:
+        elif column == 6:
             if self.dataScheme[row]['imligr'] != 'none':
                 return Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsEditable
             else:
@@ -1020,16 +1101,21 @@ class StandardItemModelGradient(QStandardItemModel):
             self.NPE.setBoundaryGradientType(name, b_gradient_r)
 
         elif column == 3:
+            d_gradient_r = self.dicoV2M[str(from_qvariant(value, to_text_string))]
+            self.dataScheme[row]['d_gradient_r'] = d_gradient_r
+            self.NPE.setDiffusionGradientType(name, d_gradient_r)
+
+        elif column == 4:
             v = from_qvariant(value, float)
             self.dataScheme[row]['epsrgr'] = v
             self.NPE.setGradientEpsilon(name, v)
 
-        elif column == 4:
+        elif column == 5:
             imligr = self.dicoV2M_imligr[str(from_qvariant(value, to_text_string))]
             self.dataScheme[row]['imligr'] = imligr
             self.NPE.setGradientLimiter(name, imligr)
 
-        elif column == 5:
+        elif column == 6:
             if value != "":
                 v = from_qvariant(value, float)
                 self.dataScheme[row]['climgr'] = v
@@ -1446,7 +1532,7 @@ class StandardItemModelClipping(QStandardItemModel):
             title = self.tr("Information")
             msg = self.tr("The minimal value is greater than the maximal "\
                           "value. Therefore there will be no clipping for the "\
-                          "scalar named:\n\n%1").arg(name)
+                          "scalar named:\n\n" + name)
             QMessageBox.information(self.parent, title, msg)
             return OK
 
@@ -1499,8 +1585,11 @@ class NumericalParamEquationView(QWidget, Ui_NumericalParamEquationForm):
         delegateNVDLIM = SchemeNVDLimiterDelegate(self.tableViewScheme)
         self.tableViewScheme.setItemDelegateForColumn(4, delegateNVDLIM)
 
+        delegateBDiffFluxRC = SchemeBoundaryDiffFluxDelegate(self.tableViewScheme)
+        self.tableViewScheme.setItemDelegateForColumn(6, delegateBDiffFluxRC)
+
         delegateNSWRSM = RhsReconstructionDelegate(self.tableViewScheme, self.turb)
-        self.tableViewScheme.setItemDelegateForColumn(6, delegateNSWRSM)
+        self.tableViewScheme.setItemDelegateForColumn(7, delegateNSWRSM)
 
         # Solver
         self.modelSolver = StandardItemModelSolver(self.NPE)
@@ -1550,17 +1639,22 @@ class NumericalParamEquationView(QWidget, Ui_NumericalParamEquationForm):
         delegateIMRGRA = GradientTypeDelegate(self.tableViewGradient)
         self.tableViewGradient.setItemDelegateForColumn(1, delegateIMRGRA)
 
-        delegateIMRGRB = GradientTypeDelegate(self.tableViewGradient, boundary=True)
-        self.tableViewGradient.setItemDelegateForColumn(2, delegateIMRGRB)
+        delegateIMRGRD = GradientTypeDelegate(self.tableViewGradient,
+                                              category='d_gradient_r')
+        self.tableViewGradient.setItemDelegateForColumn(2, delegateIMRGRD)
+
+        delegateIMRGRB = GradientTypeDelegate(self.tableViewGradient,
+                                              category='b_gradient_r')
+        self.tableViewGradient.setItemDelegateForColumn(3, delegateIMRGRB)
 
         delegateEPSRGR = GradientFloatDelegate(self.tableViewGradient, 1.0)
-        self.tableViewGradient.setItemDelegateForColumn(3, delegateEPSRGR)
+        self.tableViewGradient.setItemDelegateForColumn(4, delegateEPSRGR)
 
         delegateIMLIGR = GradientLimiterDelegate(self.tableViewGradient)
-        self.tableViewGradient.setItemDelegateForColumn(4, delegateIMLIGR)
+        self.tableViewGradient.setItemDelegateForColumn(5, delegateIMLIGR)
 
         delegateCLIMGR = GradientFloatDelegate(self.tableViewGradient)
-        self.tableViewGradient.setItemDelegateForColumn(5, delegateCLIMGR)
+        self.tableViewGradient.setItemDelegateForColumn(6, delegateCLIMGR)
 
         # Clipping
         self.modelClipping = StandardItemModelClipping(self, self.NPE)
