@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -221,6 +221,12 @@ class OpenTurnsDialogView(QDialog, Ui_OpenTurnsDialogForm):
             self.groupBoxDistantLaunch.hide()
 
         self.setAvailableBuildsList(host_name)
+        # reset default build name
+        if host_name != 'localhost':
+            dist_builds_list = self.distant_host_builds[host_name]
+            self.mdl.setBuildName(str(dist_builds_list[0]))
+        else:
+            self.mdl.setBuildName('default')
 
         self.mdl.arch_path = self.hosts_binpath[host_name]
 
@@ -414,9 +420,6 @@ class OpenTurnsDialogView(QDialog, Ui_OpenTurnsDialogForm):
                 self.modelOtDistantBuilds.addItem(self.tr(db), db)
 
 
-
-
-
     def create_cs_exec_function(self):
         """
         This function generates the _exec function needed by OpenTurns for a study
@@ -475,11 +478,10 @@ class OpenTurnsDialogView(QDialog, Ui_OpenTurnsDialogForm):
 
         script_cmd += toffset + "import sys\n"
 
-        salome_pydir = os.path.join(self.case['package'].dirs['pythondir'],
-                                    'salome')
+        salome_pydir = os.path.join(self.case['package'].dirs['pythondir'])
         script_cmd += toffset
         script_cmd += "sys.path.insert(-1, '%s')\n\n" % salome_pydir
-        script_cmd += toffset + "from CFDSTUDYOTURNS_StudyInterface import cfd_openturns_study"
+        script_cmd += toffset + "from cfdstudy.CFDSTUDYOTURNS_StudyInterface import cfd_openturns_study"
         script_cmd += "\n\n"
 
         script_cmd += toffset + cmd1 + 'study_path = "' + self.mdl.otstudy_path + '",\n'
