@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -41,7 +41,7 @@ import vtk
 import libSalomePy
 import salome
 import SMESH
-import CFDSTUDYGUI_DataModel
+import cfdstudy.CFDSTUDYGUI_DataModel
 
 try:
     from vtkmodules.vtkRenderingCorePython import *
