@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -1214,7 +1214,7 @@ class MainView(object):
                         itt.status     = nn.getAttribute('status')
                         itt.subplot_id = int(nn.getAttribute('subplot_id'))
             self.lineEditTime.setText(str(self.timeRefresh))
-            self.timer.start(self.timeRefresh * 1000)
+            self.timer.start(int(self.timeRefresh * 1000))
             self.spinBox.setValue(int(self.subplotNumber))
 
 
