@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -60,6 +60,7 @@ class AtmosphericFlowsModel(Variables, Model):
     dry                 = 'dry'
     humid               = 'humid'
     humid_ctwr          = 'humid_ctwr'
+    ctwr                = 'ctwr'
     read_meteo_data     = 'read_meteo_data'
     large_scale_meteo   = 'large_scale_meteo'
     act_chemistry       = 'activate_chemistry'
@@ -79,16 +80,17 @@ class AtmosphericFlowsModel(Variables, Model):
                                    AtmosphericFlowsModel.constant,
                                    AtmosphericFlowsModel.dry,
                                    AtmosphericFlowsModel.humid,
-                                   AtmosphericFlowsModel.humid_ctwr)
+                                   AtmosphericFlowsModel.humid_ctwr,
+                                   AtmosphericFlowsModel.ctwr)
 
         self.var_list_humid = [('ym_water', 'TotWater'),
                                ('number_of_droplets', 'TotDrop')]
 
-        self.var_list_ctwr = [('y_p', 'Yp rain'),
-                              ('y_p_t_l', 'Yp.Tp rain'),
+        self.var_list_ctwr = [('ym_l_r', 'ym rain'),
+                              ('ymh_l_r', 'ym.hl rain'),
                               ('y_l_packing', 'Yl packing'),
-                              ('enthalpy_liquid', 'Enthalpy liq packing'),
-                              ('ym_water', 'Ym water bulk')]
+                              ('yh_l_packing', 'Yl.hl packing'),
+                              ('ym_water', 'ym water bulk')]
 
         self.prop_list_dry   = [('real_temperature', 'RealTemp')]
 
@@ -98,9 +100,9 @@ class AtmosphericFlowsModel(Variables, Model):
         self.prop_list_ctwr   = [('humidity', 'Humidity'),
                                  ('x_s', 'Humidity sat'),
                                  ('enthalpy', 'Enthalpy humid air'),
-                                 ('temperature_liquid', 'Temperature liq packing'),
+                                 ('temp_l_packing', 'Temperature liq packing'),
                                  ('vertvel_l', 'Velocity liq packing'),
-                                 ('t_rain', 'Temperature rain'),
+                                 ('temp_l_r', 'Temperature rain'),
                                  ('x_c', 'Gas mass fraction')]
 
 
@@ -123,6 +125,8 @@ class AtmosphericFlowsModel(Variables, Model):
         self.__default['meteo_zref'] = 10.
         self.__default['meteo_uref'] = 5.
         self.__default['meteo_ustar'] = -1.
+        self.__default['meteo_qw0'] = 0.
+        self.__default['meteo_qwstar'] = 0.
 
     @Variables.undoLocal
     def setAtmosphericFlowsModel(self, model):
@@ -132,11 +136,11 @@ class AtmosphericFlowsModel(Variables, Model):
         self.isInList(model, self.__atmosphericModel)
         self.__node_atmos[self.model] = model
         self.__updateScalarAndProperty()
-        if (model == "humid" or model == "dry" or model == "humid_ctwr"):
+        if (model == "humid" or model == "dry" or model == "humid_ctwr" or model == "ctwr"):
             NumericalParamGlobalModel(self.case).setHydrostaticPressure("on")
             if (model == "dry"):
                 ThermalScalarModel(self.case).setThermalModel('potential_temperature')
-            elif (model == "humid"):
+            elif (model == "humid" or model == "humid_ctwr"):
                 ThermalScalarModel(self.case).setThermalModel('liquid_potential_temperature')
             else:
                 ThermalScalarModel(self.case).setThermalModel('temperature_celsius')
@@ -331,6 +335,29 @@ class AtmosphericFlowsModel(Variables, Model):
     def setMeteoZref(self, tag):
         self.__node_atmos.xmlSetData('meteo_zref', tag)
 
+    #-------------------------------------------------------------------------
+    @Variables.noUndo
+    def getMeteoQw0(self):
+        f = self.__node_atmos.xmlGetDouble('meteo_qw0')
+        if f is None:
+            f = self.__default['meteo_qw0']
+            self.setMeteoQw0(f)
+        return f
+    @Variables.undoLocal
+    def setMeteoQw0(self, tag):
+        self.__node_atmos.xmlSetData('meteo_qw0', tag)
+
+    #-------------------------------------------------------------------------
+    @Variables.noUndo
+    def getMeteoQwstar(self):
+        f = self.__node_atmos.xmlGetDouble('meteo_qwstar')
+        if f is None:
+            f = self.__default['meteo_qwstar']
+            self.setMeteoQwstar(f)
+        return f
+    @Variables.undoLocal
+    def setMeteoQwstar(self, tag):
+        self.__node_atmos.xmlSetData('meteo_qwstar', tag)
 
     #-------------------------------------------------------------------------
     @Variables.noUndo
@@ -459,7 +486,7 @@ class AtmosphericFlowsModel(Variables, Model):
             for v in self.prop_list_dry:
                 self.setNewProperty(node, v[0], label=v[1])
 
-        elif model == AtmosphericFlowsModel.humid:
+        elif model == AtmosphericFlowsModel.humid or model == AtmosphericFlowsModel.humid_ctwr:
             self.__fluidProp.setPropertyMode('density', 'predefined_law')
             for v in self.var_list_humid:
                 self.setNewVariable(node, v[0], tpe="model", label=v[1])
@@ -467,7 +494,7 @@ class AtmosphericFlowsModel(Variables, Model):
                 self.setNewProperty(node, v[0], label=v[1])
 
 
-        elif model == AtmosphericFlowsModel.humid_ctwr:
+        elif model == AtmosphericFlowsModel.humid_ctwr or model == AtmosphericFlowsModel.ctwr:
             self.__fluidProp.setPropertyMode('density', 'predefined_law')
             for v in self.var_list_ctwr:
                 self.setNewVariable(node, v[0], tpe="model", label=v[1])
