@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -67,19 +67,17 @@ class GasCombustionModel(Variables, Model):
         nModels          = self.case.xmlGetNode('thermophysical_models')
         self.node_turb   = nModels.xmlInitNode('turbulence',        'model')
         self.node_gas    = nModels.xmlInitNode('gas_combustion',    'model')
-        self.node_coal   = nModels.xmlInitNode('solid_fuels',       'model')
-        self.node_joule  = nModels.xmlInitNode('joule_effect',      'model')
         self.node_prop   = self.case.xmlGetNode('physical_properties')
         self.node_fluid  = self.node_prop.xmlInitNode('fluid_properties')
 
-        self.gasCombustionModel = ('off', 'ebu', 'd3p','lwp')
+        self.gasCombustionModel = ('off', 'd3p', 'ebu', 'lwp')
         self.d3p_list = ("adiabatic", "extended")
         self.ebu_list = ("spalding", "enthalpy_st", "mixture_st", "enthalpy_mixture_st")
         self.lwp_list = ("2-peak_adiabatic", "2-peak_enthalpy",
                          "3-peak_adiabatic", "3-peak_enthalpy",
                          "4-peak_adiabatic", "4-peak_enthalpy")
 
-        self.sootModels = ('off', 'constant_soot_yield', 'moss')
+        self.sootModels = ('off', 'constant_soot_yield', 'moss', 'smoke')
 
 
     def defaultGasCombustionValues(self):
@@ -127,12 +125,12 @@ class GasCombustionModel(Variables, Model):
         node_fluid  = node_prop.xmlInitNode('fluid_properties')
 
         old_model = self.node_gas['model']
-        ThermalScalarModel(self.case).setThermalModel('off')
 
         if model == 'off':
             self.node_gas['model'] = model
             self.node_gas['option'] = "off"
             ThermalRadiationModel(self.case).setRadiativeModel('off')
+            ThermalScalarModel(self.case).setThermalModel('off')
             for tag in ('variable',
                         'property',
                         'reference_mass_molar',
@@ -147,9 +145,14 @@ class GasCombustionModel(Variables, Model):
             node_fluid.xmlRemoveChild('property', name='dynamic_diffusion')
 
         else:
+            nModels = self.case.xmlGetNode('thermophysical_models')
+
+            for m in ('solid_fuels', 'joule_effect'):
+                n = nModels.xmlGetNode(m, 'model')
+                if n:
+                    n.xmlRemoveNode()
+
             self.node_gas['model'] = model
-            self.node_coal['model']  = 'off'
-            self.node_joule['model'] = 'off'
             self.setNewFluidProperty(node_fluid, 'dynamic_diffusion')
 
             if old_model != model:
@@ -232,23 +235,23 @@ class GasCombustionModel(Variables, Model):
         option = self.getGasCombustionOption()
         list_options = ["3-peak_adiabatic", "3-peak_enthalpy",
                         "4-peak_adiabatic", "4-peak_enthalpy"]
-        acceptable_options = ["2-peak_enthalpy", "3-peak_enthalpy",
-                              "4-peak_enthalpy"]
         lst = []
 
-        ThermalScalarModel(self.case).setThermalModel('off')
-
         if model == 'd3p':
             lst.append("mixture_fraction")
             lst.append("mixture_fraction_variance")
             if option == 'extended':
                 ThermalScalarModel(self.case).setThermalModel('enthalpy')
+            else:
+                ThermalScalarModel(self.case).setThermalModel('off')
         elif model == 'ebu':
             lst.append("fresh_gas_fraction")
             if option == "mixture_st" or option =="enthalpy_mixture_st":
                 lst.append("mixture_fraction")
-            elif option == "enthalpy_st" or option =="enthalpy_mixture_st":
+            if option == "enthalpy_st" or option =="enthalpy_mixture_st":
                 ThermalScalarModel(self.case).setThermalModel('enthalpy')
+            else:
+                ThermalScalarModel(self.case).setThermalModel('off')
         elif model == 'lwp':
             lst.append("mixture_fraction")
             lst.append("mixture_fraction_variance")
@@ -256,8 +259,10 @@ class GasCombustionModel(Variables, Model):
             lst.append("mass_fraction_covariance")
             if option in list_options:
                 lst.append("mass_fraction_variance")
-            if option in acceptable_options:
+            if option.find("enthalpy") > -1:
                 ThermalScalarModel(self.case).setThermalModel('enthalpy')
+            else:
+                ThermalScalarModel(self.case).setThermalModel('off')
         return lst
 
 
@@ -400,6 +405,7 @@ class GasCombustionModel(Variables, Model):
         self.default['soot_model']               = 'off'
         self.default['soot_density']             = 0.0
         self.default['soot_fraction']            = 0.0
+        self.default['lsp_fuel']                 = 0.0
         return self.default
 
     @Variables.noUndo
@@ -443,11 +449,17 @@ class GasCombustionModel(Variables, Model):
         self.isInList(model, self.sootModels)
         node  = self.node_gas.xmlInitChildNode('soot_model', 'model')
         node['model'] = model
+        if model == 'smoke':
+            self.node_gas.xmlRemoveChild('soot_fraction')
         if model == 'moss':
             self.node_gas.xmlRemoveChild('soot_fraction')
+            self.node_gas.xmlRemoveChild('lsp_fuel')
+        if model == 'constant_soot_yield':
+            self.node_gas.xmlRemoveChild('lsp_fuel')
         if model == 'off':
             self.node_gas.xmlRemoveChild('soot_density')
             self.node_gas.xmlRemoveChild('soot_fraction')
+            self.node_gas.xmlRemoveChild('lsp_fuel')
 
     @Variables.noUndo
     def getSootDensity(self):
@@ -491,6 +503,26 @@ class GasCombustionModel(Variables, Model):
         self.node_soot = self.node_gas.xmlGetNode('soot_model')
         self.node_soot.xmlSetData('soot_fraction', val)
 
+    @Variables.noUndo
+    def getSootLspFuel(self):
+        """
+        Return value of lsp fuel
+        """
+        val = self.node_gas.xmlGetDouble('lsp_fuel')
+        if val is None:
+            val = self._defaultValues()['lsp_fuel']
+            self.setSootLspFuel(val)
+        return val
+
+    @Variables.undoGlobal
+    def setSootLspFuel(self, val):
+        """
+        Put value of lsp fuel
+        """
+        self.isPositiveFloat(val)
+        self.node_soot = self.node_gas.xmlGetNode('soot_model')
+        self.node_soot.xmlSetData('lsp_fuel', val)
+
 #-------------------------------------------------------------------------------
 # Gas combustion test case
 #-------------------------------------------------------------------------------
