@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -60,7 +60,7 @@ class InterfacialForcesModel(Variables, Model):
         self.__availableDispersedDragModelList = ["none", "ishii", "Wen_Yu", "Gobin"]
 
         self.__availableAddedMassModelsLists = ["none", "standard", "zuber"]
-        self.__availableLiftModelsLists = ["none", "coef_cst", "Tomiyama_SMD", "Zeng_Baalbaki"]
+        self.__availableLiftModelsLists = ["none", "coef_cst", "Tomiyama", "Zeng_Baalbaki"]
 
         # Init freeCouples for forces : criterion checking !
         self.__allCouples = []
@@ -174,12 +174,13 @@ class InterfacialForcesModel(Variables, Model):
 
         if flow_type == "boiling_flow":
             default['disperseddragmodel'] = "ishii"
-            default['liftmodel'] = "Tomiyama_SMD"
+            default['liftmodel'] = "Tomiyama"
             default['addedmassmodel'] = "zuber"
             default['wallforcemodel'] = "tomiyama"
             GTD_condition_1 = (self.turb_m.getTurbulenceModel("1") in
                                ["k-epsilon",
                                 "k-epsilon_linear_production",
+                                "k-omega-SST",
                                 "rij-epsilon_ssg'",
                                 "rij-epsilon_ebrsm"])
             GTD_condition_2 = (self.turb_m.getTurbulenceModel("2") == "none")
@@ -588,7 +589,7 @@ class InterfacialForcesTestCase(ModelTest):
     def checkGetAvailableLiftModels(self):
         """Check whether the InterfacialEnthalpyModel class could get the AvailableLiftModels"""
         mdl = InterfacialForcesModel(self.case)
-        assert mdl.getAvailableLiftModels() == ["none", "coef_cst", "Tomiyama_SMD", "Zeng_Baalbaki"], \
+        assert mdl.getAvailableLiftModels() == ["none", "coef_cst", "Tomiyama", "Zeng_Baalbaki"], \
             'Could not get AvailableLiftModels'
 
 
