@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -473,12 +473,28 @@ class LocalizationModel(object):
         if newZone is None:
             newZone = Zone(self._typeZone, case=self.case)
 
-        if newZone.getLocalization() == newZone.defaultValues()['localization'] or newZone.getLabel() == newZone.defaultValues()['label'] or checkPresence == True:
+        has_default_zone = False
+
+        if newZone.getLocalization() == newZone.defaultValues()['localization'] \
+                or newZone.getLabel() == newZone.defaultValues()['label'] \
+                or checkPresence == True:
           zones = self.getZones()
 
+          if self._typeZone == 'VolumicZone':
+            # Ensure that default volume zone is created if needed and
+            # it does not allready exist in xml
+            for zone in zones:
+              if zone.getLocalization() == zone.defaultValues()['localization'] and \
+                      zone.getLabel() == zone.defaultValues()['label']:
+                has_default_zone = True
+                break
+          else:
+            has_default_zone = True
+
         # Set localization
 
-        if newZone.getLocalization() == newZone.defaultValues()['localization']:
+        if newZone.getLocalization() == newZone.defaultValues()['localization'] \
+                and has_default_zone:
             oldLocalization = ""
             newLocalization = ""
             for zone in zones:
