@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -126,7 +126,6 @@ class MainFieldsInitializationModel(Variables, Model):
         n = node.xmlInitChildNode('initial_value', zone_id=zone)
         n.xmlSetData('formula', str)
 
-
     @Variables.noUndo
     def getFormula(self, zone, fieldId, var_name):
         """
@@ -136,6 +135,9 @@ class MainFieldsInitializationModel(Variables, Model):
         self.mainFieldsModel.isFieldIdValid(fieldId)
 
         node = self.XMLvariables.xmlGetNode('variable', field_id=fieldId, name=var_name)
+        if not node:
+            msg = "There is an error: this node " + str(node) + "should be present"
+            raise ValueError(msg)
         n = node.xmlInitChildNode('initial_value', zone_id=zone)
         return n.xmlGetString('formula')
 
@@ -144,30 +146,22 @@ class MainFieldsInitializationModel(Variables, Model):
     def getFormulaComponents(self, zone, fieldId, var_name):
         exp = self.getFormula(zone, fieldId, var_name)
 
+        sym = [('x', "X cell's gravity center"),
+               ('y', "Y cell's gravity center"),
+               ('z', "Z cell's gravity center")]
+
         if var_name == 'velocity':
             req = [('u', 'Velocity along X'),
                    ('v', 'Velocity along Y'),
                    ('w', 'Velocity along Z')]
 
-            sym = [('x', "X cell's gravity center"),
-                   ('y', "Y cell's gravity center"),
-                   ('z', "Z cell's gravity center")]
-
         elif var_name == 'volume_fraction':
             req = [('vol_f', 'volume fraction')]
 
-            sym = [('x', "X cell's gravity center"),
-                   ('y', "Y cell's gravity center"),
-                   ('z', "Z cell's gravity center")]
-
         elif var_name == 'enthalpy':
             th_sca_label = self.getEnergyModel(zone, fieldId)
             req = [(th_sca_label, str(th_sca_label))]
 
-            sym = [('x', "X cell's gravity center"),
-                   ('y', "Y cell's gravity center"),
-                   ('z', "Z cell's gravity center")]
-
         for (name, val) in NotebookModel(self.case).getNotebookList():
             sym.append((name, 'value (notebook) = ' + str(val)))
 
@@ -182,7 +176,9 @@ class MainFieldsInitializationModel(Variables, Model):
         self.__verifyZone(zone)
         self.mainFieldsModel.isFieldIdValid(fieldId)
 
-        node = self.XMLNonCondvariables.xmlGetNode('variable', field_id=fieldId, name=var_name)
+        node = self.XMLNonCondvariables.xmlGetNode('variable',
+                                                   conv_field=fieldId,
+                                                   name=var_name)
         n = node.xmlInitChildNode('initial_value', zone_id=zone)
         n.xmlSetData('formula', str)
 
@@ -195,7 +191,9 @@ class MainFieldsInitializationModel(Variables, Model):
         self.__verifyZone(zone)
         self.mainFieldsModel.isFieldIdValid(fieldId, strict_check=False)
 
-        node = self.XMLNonCondvariables.xmlGetNode('variable', field_id=fieldId, name=var_name)
+        node = self.XMLNonCondvariables.xmlGetNode('variable',
+                                                   conv_field=fieldId,
+                                                   name=var_name)
         n = node.xmlInitChildNode('initial_value', zone_id=zone)
         return n.xmlGetString('formula')
 
@@ -225,7 +223,7 @@ class MainFieldsInitializationModel(Variables, Model):
         self.mainFieldsModel.isFieldIdValid(fieldId, strict_check=False)
 
         node = self.XMLScalar.xmlGetNode('variable',
-                                         field_id=fieldId,
+                                         conv_field=fieldId,
                                          name=var_name)
         n = node.xmlInitChildNode('initial_value', zone_id=zone)
         n.xmlSetData('formula', str)
@@ -240,7 +238,7 @@ class MainFieldsInitializationModel(Variables, Model):
         self.mainFieldsModel.isFieldIdValid(fieldId, strict_check=False)
 
         node = self.XMLScalar.xmlGetNode('variable',
-                                         field_id=fieldId,
+                                         conv_field=fieldId,
                                          name=var_name)
         n = node.xmlInitChildNode('initial_value', zone_id=zone)
         return n.xmlGetString('formula')
