@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -102,6 +102,7 @@ class NumericalParamEquationModel(Model):
         self.default = {}
         self.default['verbosity'] = 0
         self.default['c_gradient_r'] = 'global'
+        self.default['d_gradient_r'] = 'automatic'
         self.default['b_gradient_r'] = 'automatic'
         self.default['epsrgr'] = 1e-4
         self.default['imligr'] = 'none'
@@ -123,6 +124,7 @@ class NumericalParamEquationModel(Model):
             default['slope_test'] = 'on'
             default['nvd_limiter'] = 'gamma'
         default['flux_reconstruction'] = 'on'
+        default['boundary_diffusion_flux_reconstruction'] = 'all'
 
         default['solver_choice'] = 'automatic'
         default['preconditioning_choice'] = 'automatic'
@@ -191,9 +193,9 @@ class NumericalParamEquationModel(Model):
         """ Private method: return list of pulverized coal scalar's nodes """
         nodList = []
         node = self.node_models.xmlGetNode('solid_fuels', 'model')
-        model = node['model']
-        if model != 'off':
-            nodList = node.xmlGetNodeList('variable')
+        if node:
+            if node['model'] != 'off':
+                nodList = node.xmlGetNodeList('variable')
         return nodList
 
 
@@ -201,9 +203,9 @@ class NumericalParamEquationModel(Model):
         """ Private method: return list of gas combustion scalar's nodes """
         nodList = []
         node = self.node_models.xmlGetNode('gas_combustion', 'model')
-        model = node['model']
-        if model != 'off':
-            nodList = node.xmlGetNodeList('variable')
+        if node:
+            if  node['model'] != 'off':
+                nodList = node.xmlGetNodeList('variable')
         return nodList
 
 
@@ -211,10 +213,9 @@ class NumericalParamEquationModel(Model):
         """ Private method: return list of meteo scalar's nodes """
         nodList = []
         node = self.node_models.xmlGetNode('atmospheric_flows', 'model')
-        if not node: return []
-        model = node['model']
-        if model != 'off':
-            nodList = node.xmlGetNodeList('variable')
+        if node:
+            if  node['model'] != 'off':
+                nodList = node.xmlGetNodeList('variable')
         return nodList
 
 
@@ -222,10 +223,9 @@ class NumericalParamEquationModel(Model):
         """ Private method: return list of electric scalar's nodes """
         nodList = []
         node = self.node_models.xmlGetNode('joule_effect', 'model')
-        if not node: return []
-        model = node['model']
-        if model != 'off':
-            nodList = node.xmlGetNodeList('variable')
+        if node:
+            if  node['model'] != 'off':
+                nodList = node.xmlGetNodeList('variable')
         return nodList
 
 
@@ -233,10 +233,9 @@ class NumericalParamEquationModel(Model):
         """ Private method: return list of compressible scalar's nodes """
         nodList = []
         node = self.node_models.xmlGetNode('compressible_model', 'model')
-        if not node: return []
-        model = node['model']
-        if model != 'off':
-            nodList = node.xmlGetNodeList('variable')
+        if node:
+            if  node['model'] != 'off':
+                nodList = node.xmlGetNodeList('variable')
         return nodList
 
 
@@ -438,7 +437,7 @@ class NumericalParamEquationModel(Model):
     def getScheme(self, name):
         """ Return value of order scheme for specified variable """
         node = self._getSchemeNameNode(name)
-        if node['_convect'] == 'off':
+        if node['_convect'] == 'no':
             return None
         value = self._defaultValues(name)['order_scheme']
         n = node.xmlGetNode('order_scheme')
@@ -549,7 +548,7 @@ class NumericalParamEquationModel(Model):
     def getNVDLimiter(self, name):
         """ Return value of NVD limiter for specified variable """
         node = self._getSchemeNameNode(name)
-        if node['_convect'] == 'off':
+        if node['_convect'] == 'no':
             return None
 
         sv = self._defaultValues(name)['order_scheme']
@@ -562,9 +561,10 @@ class NumericalParamEquationModel(Model):
         value = self._defaultValues(name)['nvd_limiter']
         n = node.xmlGetNode('nvd_limiter')
         if n:
-                value = n['choice']
+            value = n['choice']
         return value
 
+
     @Variables.undoLocal
     def setNVDLimiter(self, name, value):
         """ Put status of NVD limiter for specified variable """
@@ -602,6 +602,27 @@ class NumericalParamEquationModel(Model):
             n['status']=value
 
 
+    @Variables.noUndo
+    def getBoundaryDiffFluxReconstruction(self, name):
+        """ Return  boundary diffusion flux reconstruction mode for specified variable """
+        node = self._getSchemeNameNode(name)
+        value = self._defaultValues()['boundary_diffusion_flux_reconstruction']
+        if node.xmlGetNode('boundary_diffusion_flux_reconstruction'):
+            value = node.xmlGetNode('boundary_diffusion_flux_reconstruction')['mode']
+        return value
+
+
+    @Variables.undoLocal
+    def setBoundaryDiffFluxReconstruction(self, name, value):
+        """ Put status of flux reconstruction for specified variable """
+        node = self._getSchemeNameNode(name)
+        if value == self._defaultValues()['boundary_diffusion_flux_reconstruction']:
+            node.xmlRemoveChild('boundary_diffusion_flux_reconstruction')
+        else:
+            n = node.xmlInitNode('boundary_diffusion_flux_reconstruction')
+            n['mode']=value
+
+
     @Variables.noUndo
     def getRhsReconstruction(self, name):
         """ Return value of RHS reconstruction for specified variable """
@@ -672,6 +693,33 @@ class NumericalParamEquationModel(Model):
             node.xmlSetData('boundary_gradient_type', value)
 
 
+    @Variables.noUndo
+    def getDiffusionGradientType(self, name):
+        """
+        Return diffusion reconstruction gradient type for specified variable.
+        """
+        node = self._getSchemeNameNode(name)
+        value = node.xmlGetString('diffusion_gradient_type')
+        if not value:
+            value = self.default['d_gradient_r']
+
+        return value
+
+
+    @Variables.undoGlobal
+    def setDiffusionGradientType(self, name, value):
+        """
+        Set diffusion reconstruction gradient type for specified variable.
+        """
+        self.isInList(value, ('automatic', 'green_iter', 'lsq', 'lsq_ext',
+                              'green_lsq', 'green_lsq_ext', 'green_vtx'))
+        node = self._getSchemeNameNode(name)
+        if value == self.default['d_gradient_r']:
+            node.xmlRemoveChild('diffusion_gradient_type')
+        else:
+            node.xmlSetData('diffusion_gradient_type', value)
+
+
     @Variables.noUndo
     def getGradientEpsilon(self, name):
         """
