@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -69,7 +69,7 @@ class OutputControlModel(Model):
         Return in a dictionnary which contains default values.
         """
         default = {}
-        default['listing_printing_frequency'] = 1
+        default['listing_printing_frequency'] = 0
         default['probe_recording_frequency'] = 1
         default['probe_recording_frequency_time'] = 0.1
         default['probe_format'] = "CSV"
@@ -106,7 +106,6 @@ class OutputControlModel(Model):
         f = self.node_out.xmlGetInt('listing_printing_frequency')
         if f is None:
             f = self.defaultInitialValues()['listing_printing_frequency']
-            self.setListingFrequency(f)
         return f
 
 
@@ -117,6 +116,8 @@ class OutputControlModel(Model):
         """
         self.isInt(freq)
         self.node_out.xmlSetData('listing_printing_frequency', freq)
+        if (freq == self.defaultInitialValues()['listing_printing_frequency']):
+            self.node_out.xmlRemoveChild('listing_printing_frequency')
 
 
     @Variables.noUndo
@@ -577,6 +578,29 @@ class OutputControlModel(Model):
         n['choice'] = choice
 
 
+    @Variables.noUndo
+    def getCatalystImplementation(self):
+        """
+        Return the selected Catalyst implementation type.
+        """
+        implementation = None
+        node_c = self.node_out.xmlGetNode('catalyst')
+        if node_c:
+            implementation = node_c.xmlGetString('implementation')
+        if implementation is None:
+            implementation = "paraview"
+        return implementation
+
+
+    @Variables.undoLocal
+    def setCatalystImplementation(self, implementation):
+        """
+        Set the selected Catalyst implementation type.
+        """
+        node_c = self.node_out.xmlInitNode('catalyst')
+        node_c.xmlSetData('implementation', implementation, default='paraview')
+
+
     def defaultMeshValues(self):
         """Return the default values"""
         default = {}
@@ -1223,19 +1247,30 @@ class OutputControlModel(Model):
 
         num = 0
 
-        for line in lines:
+        for i, line in enumerate(lines):
             tmp = line.strip().split(',')
-            if len(tmp) != 3:
-                continue
-            try:
-               xp, yp, zp = float(tmp[0]), float(tmp[1]), float(tmp[2])
-               self.addMonitoringPoint(xp, yp, zp)
-               num = num + 1
-            except Exception:
-               if num != 0:
-                   print("Probes import error for line: " + str(line))
-                   print(tmp)
-                   print(len(tmp))
+            if len(tmp) == 3:
+                try:
+                    xp, yp, zp = float(tmp[0].strip()), float(tmp[1].strip()), float(tmp[2].strip())
+                    self.addMonitoringPoint(xp, yp, zp)
+                    num = num + 1
+                except Exception:
+                    if i != 0:
+                        print("Probes import error for line: " + str(i+1) + ": " + str(line))
+                        print("expected \"x, y, z\"")
+            elif len(tmp) == 4:
+                try:
+                    name, xp, yp, zp = tmp[0].strip(), float(tmp[1].strip()), float(tmp[2].strip()), float(tmp[3].strip())
+                    self.addMonitoringPoint(xp, yp, zp)
+                    self.setMonitoringPointName(str(num+1), name)
+                    num = num + 1
+                except Exception:
+                    if i != 0:
+                        print("Probes import error for line: " + str(i+1) + ": " + str(line))
+                        print("expected \"name, x, y, z\"")
+            elif i > 0:
+                print("Probes import error for line: " + str(line))
+                print("expected \"name, x, y, z\" or  \"x, y, z\"")
 
         return num
 
