@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -185,12 +185,14 @@ class OutputVolumicVariablesModel(Variables, Model):
 
             # Check that we wish to show the field
             if not (node['support'] and node['support'] == "boundary"):
-                # Add main field. "-1" is used as default since for
-                # vectors/tensors it yields all components
-                dicoLabel2Name[label] = (name, str(-1))
 
                 # Check if we want to also get components
                 dim = node['dimension']
+
+                # Add main field. "-1" is used as default since for
+                # vectors/tensors it yields all components
+                dicoLabel2Name[label] = (name, str(-1), str(dim))
+
                 if dim and int(dim) > 1 and get_components:
                     # If we consider the Rij tensor, the user will see
                     # R11, R22, ... in the GUI instead of Rij[0], Rij[1], ...
@@ -232,7 +234,8 @@ class OutputVolumicVariablesModel(Variables, Model):
                 component = label[1]
                 is_recognized = (label[0] == xml_variable['name'])
                 if component:
-                    is_recognized = (label == (xml_variable['name'], xml_variable['component']))
+                    if component != xml_variable['component']:
+                        is_recognized = False
                 if is_recognized:
                     recognized_variables.append(name)
         return recognized_variables
@@ -244,7 +247,9 @@ class OutputVolumicVariablesModel(Variables, Model):
         authorized_variables = dicoLabel2Name.keys()
         for var in variables:
             self.isInList(var, authorized_variables)
-            (name, comp) = dicoLabel2Name[var]
+            t = dicoLabel2Name[var]  # tuple with 2 or 3 values
+            name = t[0]
+            comp = t[1]
             if comp is None:
                 comp = -1
             node.xmlAddChild('var_prop', name=name, component=comp)
@@ -801,8 +806,8 @@ class OutputVolumicVariablesModel(Variables, Model):
         for node in self.case.xmlGetNodeList('formula'):
             f = node.xmlGetTextNode()
             if f:
-                f.replace(old_label, new_label)
-                node.xmlSetTextNode(f)
+                new_f = f.replace(old_label, new_label)
+                node.xmlSetTextNode(new_f)
 
 
     def _updateBoundariesNodes(self, old_label, new_label):
