@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -541,16 +541,6 @@ class SolutionDomainModel(MeshModel, Model):
     @Variables.undoLocal
     def setMeshOrigin(self, choice):
 
-        node = self.node_ecs.xmlInitNode('mesh_origin', 'choice')
-        if choice not in ('mesh_import', 'mesh_input', 'mesh_cartesian'):
-            choice = 'mesh_import'
-
-        node['choice'] = choice
-
-        if choice != 'mesh_import':
-            for m in self.getMeshList():
-                self.delMesh(m)
-
         if choice != 'mesh_input':
             self.delMeshInput()
 
@@ -559,6 +549,20 @@ class SolutionDomainModel(MeshModel, Model):
             if n:
                 n.xmlRemoveNode()
 
+        if choice != 'mesh_import':
+            for m in self.getMeshList():
+                self.delMesh(m)
+
+        if choice in ('mesh_input', 'mesh_cartesian'):
+            node = self.node_ecs.xmlInitNode('mesh_origin', 'choice')
+            node['choice'] = choice
+
+        else:
+            # choice = 'mesh_import'
+            node = self.node_ecs.xmlGetNode('mesh_origin', 'choice')
+            if node:
+                node.xmlRemoveNode()
+
 
 # Methods to manage the cartesian mesh
 #======================================
