@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -26,6 +26,7 @@ import sys, unittest
 from code_saturne.model.XMLvariables import Variables, Model
 from code_saturne.model.XMLengine import *
 from code_saturne.model.MainFieldsModel import *       # TODO change
+from code_saturne.model.NotebookModel import NotebookModel
 import copy
 
 #-------------------------------------------------------------------------------
@@ -38,12 +39,12 @@ class TurbulenceModelsDescription:
     continuousTurbulenceModels = ['none', 'mixing_length',
                                   'k-epsilon', 'k-epsilon_linear_production',
                                   'rij-epsilon_ssg', 'rij-epsilon_ebrsm',
-                                  'les_smagorinsky', 'les_wale']
+                                  'les_smagorinsky', 'les_wale', 'k-omega-SST']
 
     reverseCouplingModels = ['k-epsilon', 'k-epsilon_linear_production',
-                             'rij-epsilon_ssg', 'rij-epsilon_ebrsm']
+                             'rij-epsilon_ssg', 'rij-epsilon_ebrsm', 'k-omega-SST']
 
-    dispersedTurbulenceModels = ['none', 'q2-q12-tchen', 'q2-q12', 'r2-q12', 'r2-r12-tchen']
+    dispersedTurbulenceModels = ['none', 'q2-q12-tchen', 'r2-q12', 'q2-q12', 'r2-r12-tchen']
 
     bubblyFlowsTurbulenceModels = ["none", "q2-q12-tchen", "r2-r12-tchen"]
     dropletFlowsTurbulenceModels = ["none", "q2-q12", "r2-q12"]
@@ -58,6 +59,7 @@ class TurbulenceModelsDescription:
     turbulenceVariables['mixing_length'] = []
     turbulenceVariables['k-epsilon'] = ['k', 'epsilon']
     turbulenceVariables['k-epsilon_linear_production'] = ['k', 'epsilon']
+    turbulenceVariables['k-omega-SST'] = ['k', 'omega']
     turbulenceVariables['rij-epsilon_ssg'] = ['reynolds_stress', 'epsilon']
     turbulenceVariables['rij-epsilon_ebrsm'] = ['reynolds_stress', 'epsilon', 'alpha']
     turbulenceVariables['les_smagorinsky'] = []
@@ -70,6 +72,7 @@ class TurbulenceModelsDescription:
 
     turbulenceVariables['all'] = turbulenceVariables['k-epsilon'] \
                                + turbulenceVariables['k-epsilon_linear_production'] \
+                               + turbulenceVariables['k-omega-SST'] \
                                + turbulenceVariables['rij-epsilon_ssg'] \
                                + turbulenceVariables['rij-epsilon_ebrsm'] \
                                + turbulenceVariables['les_smagorinsky'] \
@@ -83,6 +86,7 @@ class TurbulenceModelsDescription:
     turbulenceProperties['mixing_length'] = ["turb_viscosity"]
     turbulenceProperties['k-epsilon'] = ["turb_viscosity"]
     turbulenceProperties['k-epsilon_linear_production'] = ["turb_viscosity"]
+    turbulenceProperties['k-omega-SST'] = ["turb_viscosity"]
     turbulenceProperties['rij-epsilon_ssg'] = ["turb_viscosity"]
     turbulenceProperties['rij-epsilon_ebrsm'] = ["turb_viscosity"]
     turbulenceProperties['les_smagorinsky'] = ["turb_viscosity"]
@@ -108,12 +112,13 @@ class TurbulenceModel(Variables, Model):
         """
         #
         # XML file parameters
-        self.mainFieldsModel = MainFieldsModel(case)
-        self.case = case
-        self.XMLClosure      = self.case.xmlGetNode('closure_modeling')
-        self.XMLturbulence   = self.XMLClosure.xmlInitNode('turbulence')
-        self.XMLNodeVariable = self.XMLturbulence.xmlInitNode('variables')
-        self.XMLNodeproperty = self.XMLturbulence.xmlInitNode('properties')
+        self.mainFieldsModel  = MainFieldsModel(case)
+        self.case             = case
+        self.XMLClosure       = self.case.xmlGetNode('closure_modeling')
+        self.XMLturbulence    = self.XMLClosure.xmlInitNode('turbulence')
+        self.XMLNodeVariable  = self.XMLturbulence.xmlInitNode('variables')
+        self.XMLNodeproperty  = self.XMLturbulence.xmlInitNode('properties')
+        self.XMLturbVariables = self.XMLturbulence.xmlGetNode('variables')
 
 
     def defaultValues(self):
@@ -175,11 +180,11 @@ class TurbulenceModel(Variables, Model):
            for var in TurbulenceModelsDescription.turbulenceVariables[model]:
              if var == "reynolds_stress":
                  self.setNewVariableProperty("variable", "",
-                                                             self.XMLNodeVariable,
-                                                             fieldId,
-                                                             var,
-                                                             var+"_"+field_name,
-                                                             dim=6)
+                                             self.XMLNodeVariable,
+                                             fieldId,
+                                             var,
+                                             var+"_"+field_name,
+                                             dim=6)
              elif var == 'covariance_qfp':
                  if field.carrier_id == 'all':
                      _carr_lst = self.mainFieldsModel.getContinuousFieldList()
@@ -187,21 +192,20 @@ class TurbulenceModel(Variables, Model):
                      _carr_lst = [self.mainFieldsModel.getFieldFromId(field.carrier_id)]
 
                  for _f in _carr_lst:
-                     _vname = "_".join([var, _f.f_id])
                      _vlabel = "_".join([var, _f.label, field_name])
                      self.setNewVariableProperty("variable", "",
                                                  self.XMLNodeVariable,
                                                  fieldId,
-                                                 _vname,
+                                                 var,
                                                  _vlabel)
              else:
                  if var == 'covariance_qfp':
                      var += "_" + self.mainFieldsModel.getFieldLabelsList()[0]
                  self.setNewVariableProperty("variable", "",
-                                                             self.XMLNodeVariable,
-                                                             fieldId,
-                                                             var,
-                                                             var+"_"+field_name)
+                                             self.XMLNodeVariable,
+                                             fieldId,
+                                             var,
+                                             var+"_"+field_name)
 
            for var in TurbulenceModelsDescription.turbulenceProperties[model]:
                self.setNewVariableProperty("property", "", self.XMLNodeproperty, fieldId, var, var+"_"+field_name)
@@ -222,6 +226,40 @@ class TurbulenceModel(Variables, Model):
                            else:
                                self.setTwoWayCouplingModel(fld.f_id, TurbulenceModelsDescription.continuousCouplingModels[0])
 
+           # Update initialisation values to default init formula if the turbulence model is changed
+           # If more zones are present, all initialization are set to Default
+           if model != "none":
+               from code_saturne.model.LocalizationModel import LocalizationModel
+               for zone in LocalizationModel('VolumicZone', self.case).getZones():
+                   zoneId = zone.getCodeNumber()
+                   turbFormula = self.getDefaultTurbFormula(zoneId, fieldId, model)
+                   self.setFormula(zoneId, fieldId, model, turbFormula)
+
+
+    @Variables.noUndo
+    def getInitialTurbulenceChoice(self, zone, fieldId):
+        """
+        get the initialization mode for the turbulence
+        """
+        node_init = self.XMLturbulence.xmlGetNode('init_choice', zone_id=zone, field_id=fieldId)
+        choice = ''
+        if not node_init:
+            init_mode = 'reference_value'
+            self.setInitialTurbulenceChoice(zone, fieldId, init_mode)
+            node_init = self.XMLturbulence.xmlGetNode('init_choice', zone_id=zone, field_id=fieldId)
+        choice = node_init['choice']
+
+        return choice
+
+
+    @Variables.undoLocal
+    def setInitialTurbulenceChoice(self, zone, fieldId, init_mode):
+        """
+        set the initialization mode for the turbulence
+        """
+        node_init = self.XMLturbulence.xmlInitNode('init_choice', zone_id=zone, field_id=fieldId)
+        node_init['choice'] = init_mode
+
 
     @Variables.noUndo
     def getTurbulenceModel(self, fieldId):
@@ -246,6 +284,135 @@ class TurbulenceModel(Variables, Model):
 
         return model
 
+    @Variables.undoLocal
+    def setFormula(self, zone, fieldId, turbModel, formula):
+        """
+        Gives a formula for initial values
+        """
+        self.mainFieldsModel.isFieldIdValid(fieldId, strict_check=True)
+
+        node = self.XMLturbVariables
+        n = node.xmlInitChildNode('initialization',
+                                  field_id=fieldId,
+                                  zone_id=zone).xmlInitChildNode('formula')
+        if formula != None:
+            n.xmlSetTextNode(formula)
+        else:
+            n.xmlRemoveNode()
+
+    @Variables.noUndo
+    def getFormula(self, zone, fieldId, turbModel):
+        """
+        Return a formula for initial values
+        """
+        self.mainFieldsModel.isFieldIdValid(fieldId)
+
+        node = self.XMLturbVariables
+        if not node:
+            msg = "There is an error: this node " + str(node) + " should be present"
+            raise ValueError(msg)
+
+        turbInit = node.xmlInitNode('initialization',
+                                    field_id=fieldId,
+                                    zone_id=zone)
+
+        formula = turbInit.xmlGetString('formula')
+        if not formula:
+                formula = self.getDefaultTurbFormula(zone, fieldId, turbModel)
+        return formula
+
+    @Variables.noUndo
+    def getFormulaComponents(self, zone, fieldId, turbModel):
+        exp = self.getFormula(zone, fieldId, turbModel)
+
+        sym = [('x', "X cell's gravity center"),
+               ('y', "Y cell's gravity center"),
+               ('z', "Z cell's gravity center")]
+
+        req = []
+
+        if 'k-epsilon' in turbModel:
+            req = [('k', 'turbulent kinetic energy'),
+                   ('eps', 'turbulent kinetic energy dissipation')]
+        elif 'k-omega' in turbModel:
+            req = [('k', 'turbulent kinetic energy'),
+                   ('omg', 'turbulent kinetic energy dissipation rate')]
+        elif 'rij-epsilon' in turbModel:
+            req = [('RXX', 'XX Reynolds stress component'),
+                   ('RYY', 'YY Reynolds stress component'),
+                   ('RZZ', 'ZZ Reynolds stress component'),
+                   ('RXY', 'XY Reynolds stress component'),
+                   ('RXZ', 'XZ Reynolds stress component'),
+                   ('RYZ', 'YZ Reynolds stress component'),
+                   ('eps', 'turbulent kinetic energy dissipation')]
+        elif 'q2' in turbModel:
+            req = [('qp', 'particle agitation energy'),
+                   ('qfp', 'fluid-particle velocity covariance')]
+        elif 'r2-q12' in turbModel:
+            req = [('RXX', 'XX Particle reynolds stress component'),
+                   ('RYY', 'YY Particle reynolds stress component'),
+                   ('RZZ', 'ZZ Particle reynolds stress component'),
+                   ('RXY', 'XY Particle reynolds stress component'),
+                   ('RXZ', 'XZ Particle reynolds stress component'),
+                   ('RYZ', 'YZ Particle reynolds stress component'),
+                   ('qfp', 'fluid-particle velocity covariance')]
+        elif 'r2-r12' in turbModel:
+            req = [('RXX', 'XX Particle reynolds stress component'),
+                   ('RYY', 'YY Particle reynolds stress component'),
+                   ('RZZ', 'ZZ Particle reynolds stress component'),
+                   ('RXY', 'XY Particle reynolds stress component'),
+                   ('RXZ', 'XZ Particle reynolds stress component'),
+                   ('RYZ', 'YZ Particle reynolds stress component'),
+                   ('R12XX', 'XX Fluid-Particle covariance'),
+                   ('R12YY', 'YY Fluid-Particle covariance'),
+                   ('R12ZZ', 'ZZ Fluid-Particle covariance'),
+                   ('R12XY', 'XY Fluid-Particle covariance'),
+                   ('R12XZ', 'XZ Fluid-Particle covariance'),
+                   ('R12YZ', 'YZ Fluid-Particle covariance')]
+
+        for (name, val) in NotebookModel(self.case).getNotebookList():
+            sym.append((name, 'value (notebook) = ' + str(val)))
+
+        return exp, req, sym
+
+    @Variables.noUndo
+    def getDefaultTurbFormula(self, zone, fieldId, turb_model):
+        """
+        set the default turbulence formula when needed (ref value init choice
+        for example). The expressions were previously defined in the function
+        nc_gui_initialize_setup in the routine nc_gui.cxx.
+        """
+        if 'k-epsilon' in turb_model:
+            formula = """k = 1e-5;\neps = 1e-3;"""
+        elif 'k-omega' in turb_model:
+            formula = """k = 1e-5;\nomg = 1;"""
+        elif 'rij' in turb_model:
+            formula = (
+            "RXX = 1e-5; RYY = 1e-5; RZZ = 1e-5; RXY = 0; RXZ = 0; RYZ = 0;\n"
+            "eps = 1e-3;"
+            )
+        elif 'q2' in turb_model:
+            formula = """qp = 1e-5;\nqfp = 2e-5;"""
+        elif 'r2-q12' in turb_model:
+            formula = (
+            "RXX = 1e-5; RYY = 1e-5; RZZ = 1e-5; RXY = 0; RXZ = 0; RYZ = 0;\n"
+            "qfp = 2e-5;"
+            )
+        elif 'r2-r12' in turb_model:
+            formula = (
+            "RXX = 1e-5; RYY = 1e-5; RZZ = 1e-5; RXY = 0.; RXZ = 0.; RYZ = 0.;\n"
+            "R12XX = 1e-5; R12YY = 1e-5; R12ZZ = 1e-5; R12XY = 0; R12XZ = 0; R12YZ = 0;"
+            )
+        elif 'mixing' in turb_model or 'none' in turb_model:
+            return ()
+        else:
+            msg = "Reference value initialization for turbulence model "\
+                    + turb_model + " is not defined"
+            raise ValueError(msg)
+
+        return formula
+
+
     @Variables.undoLocal
     def setThermalTurbulentFlux(self, fieldId, model):
 
@@ -289,7 +456,7 @@ class TurbulenceModel(Variables, Model):
         else:
             if field.enthalpy_model == 'off':
                 node['turb_flux'] = 'none'
-            elif node['turb_flux'] == 'none':
+            elif node['turb_flux'] in (None, 'none'):
                node['turb_flux'] = 'sgdh'
 
 
@@ -391,7 +558,7 @@ class TurbulenceModel(Variables, Model):
 
     def modelLevelIsAboveTwoEquations(self, fieldId):
         """
-        return 1 if turbulent model of field is k-eps or Rij
+        return 1 if turbulent model of field is k-eps, k-omg or Rij
         """
         if fieldId == "all":
             flag = 1
@@ -402,6 +569,7 @@ class TurbulenceModel(Variables, Model):
             self.mainFieldsModel.isFieldIdValid(fieldId)
             if (self.getTurbulenceModel(fieldId) == "k-epsilon" \
              or self.getTurbulenceModel(fieldId) == "k-epsilon_linear_production" \
+             or self.getTurbulenceModel(fieldId) == "k-omega-SST" \
              or self.getTurbulenceModel(fieldId) == "rij-epsilon_ssg" \
              or self.getTurbulenceModel(fieldId) == "rij-epsilon_ebrsm" \
              or self.getTurbulenceModel(fieldId) == "les_smagorinsky" \
