@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -1345,7 +1345,12 @@ class Case(Dico, XMLDocument):
         """
         # return self['saved'] == "no"
 
-        s = self.toIOString()
+        d = XMLDocument().parseString(self.toPrettyString())
+        d.xmlCleanHiddenDefaults(d.root())
+        self.xmlCleanEmptyLines(d.root())
+        d.xmlCleanHighLevelBlank(d.root())
+        s = d.toString()
+
         if s == self.xml_saved:
             return False
         else:
