@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -60,6 +60,7 @@ from code_saturne.model.AtmosphericFlowsModel import AtmosphericFlowsModel
 from code_saturne.model.LagrangianModel import LagrangianModel
 from code_saturne.model.ThermalRadiationModel import ThermalRadiationModel
 from code_saturne.model.SolutionDomainModel import SolutionDomainModel
+from code_saturne.model.HTSModel import HTSModel
 
 #-------------------------------------------------------------------------------
 # class BaseXmlInit
@@ -203,19 +204,22 @@ class XMLinit(BaseXmlInit):
             # Initialization (order is important)
 
             grdflow = GroundwaterModel(self.case).getGroundwaterModel()
+            hts = HTSModel(self.case).getHTSModel()
 
             self.node_models = self.case.xmlInitNode('thermophysical_models')
             node = self.node_models.xmlInitNode('velocity_pressure')
             if grdflow == 'groundwater':
                 self.setNewVariable(node, 'hydraulic_head')
-            else:
+            elif hts == 'off':
                 self.setNewVariable(node, 'pressure')
                 n = node.xmlGetNode('variable', name='pressure')
                 n['_convect'] = 'no'
-            self.setNewVariable(node, 'velocity', dim = '3')
-            self.setNewProperty(node, 'total_pressure')
 
-            if grdflow != 'groundwater':
+            if hts == 'off':
+                self.setNewVariable(node, 'velocity', dim = '3')
+                self.setNewProperty(node, 'total_pressure')
+
+            if grdflow != 'groundwater' and hts == 'off':
                 n = self.setNewProperty(node, 'yplus')
                 n['support'] = 'boundary'
                 n['label'] = 'Yplus'
@@ -546,12 +550,12 @@ class XMLinit(BaseXmlInit):
                         if n:
                             n.xmlRemoveNode()
                         ThermalScalarModel(self.case).setThermalModel('potential_temperature')
-                    if (mdl == "humid"):
+                    if (mdl == "humid" or mdl == "humid_ctwr"):
                         n = node.xmlGetNode('scalar', name="liquid_potential_temperature")
                         if n:
                             n.xmlRemoveNode()
                         ThermalScalarModel(self.case).setThermalModel('liquid_potential_temperature')
-                    if (mdl == "humid_ctwr"):
+                    if (mdl == "ctwr"):
                         n = node.xmlGetNode('scalar', name="temperature_celsius")
                         if n:
                             n.xmlRemoveNode()
@@ -2052,6 +2056,21 @@ class XMLinit(BaseXmlInit):
         mesh_origin = mdl.getMeshOrigin()
         mdl.setMeshOrigin(mesh_origin)
 
+        # Remove references to inactive models (cleanup of access to other
+        # models is needed before they can beadded here)
+        nModels = self.case.xmlGetNode('thermophysical_models')
+        for m in ('solid_fuels', 'joule_effect', 'groundwater_model', 'hgn_model'):
+            n = nModels.xmlGetNode(m, 'model')
+            if n:
+                if n['model'] == 'off':
+                    n.xmlRemoveNode()
+
+            n = nModels.xmlGetNode('radiative_transfer')
+            if n:
+                idiver = n.xmlGetInt('thermal_radiative_source_term')
+                if idiver in (0, 1):
+                    n.xmlRemoveChild('thermal_radiative_source_term')
+
         return
 
 #-------------------------------------------------------------------------------
