@@ -4,7 +4,7 @@
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -49,6 +49,7 @@ from code_saturne.model.MainFieldsModel import MainFieldsModel
 from code_saturne.model.InterfacialForcesModel import InterfacialForcesModel
 from code_saturne.model.NeptuneWallTransferModel import NeptuneWallTransferModel
 from code_saturne.model.NucleateBoilingModel import NucleateBoilingModel
+from code_saturne.model.ThermalParticlesRadiationModel import ThermalParticlesRadiationModel
 
 from code_saturne.model.EosWrapper import eosWrapper
 
@@ -201,10 +202,10 @@ class XMLinitNeptune(BaseXmlInit):
                 self.__backwardCompatibilityFrom_6_3()
 
         if from_vers[:3] < "8.0":
-            if from_vers[:3] < "7.1":
-                self.__backwardCompatibilityFrom_7_0()
-            if from_vers[:3] < "7.2":
-                self.__backwardCompatibilityFrom_7_1()
+            self.__backwardCompatibilityTo_8_0()
+
+        if from_vers[:3] < "9.0":
+            self.__backwardCompatibilityTo_9_0()
 
 
     def __backwardCompatibilityFrom_2_0(self):
@@ -759,21 +760,23 @@ class XMLinitNeptune(BaseXmlInit):
 
         # Check that all zones have the 'physical_properties' flag
         XMLVolumicNode = self.case.xmlGetNode('volumic_conditions')
-        for node in XMLVolumicNode.xmlGetChildNodeList('zone', 'label', 'id'):
-            if not node['physical_properties']:
-                # The 'all_cells' zone is always used for physical properties
-                # for the v7.0
-                if node['label'] == "all_cells":
-                    node['physical_properties'] = 'on'
-                else:
-                    node['physical_properties'] = 'off'
+        if XMLVolumicNode:
+            for node in XMLVolumicNode.xmlGetChildNodeList('zone', 'label', 'id'):
+                if not node['physical_properties']:
+                    # The 'all_cells' zone is always used for physical properties
+                    # for the v7.0
+                    if node['label'] == "all_cells":
+                        node['physical_properties'] = 'on'
+                    else:
+                        node['physical_properties'] = 'off'
 
         # Rename "inclusions" drag model into "Gobin"
         cm_node = self.case.xmlGetNode("closure_modeling")
         if_node = cm_node.xmlGetNode("interfacial_forces")
-        for node in if_node.xmlGetChildNodeList("force"):
-            if (node.xmlGetNode("drag_model")["model"] == "inclusions"):
-                node.xmlGetNode("drag_model")["model"] = "Gobin"
+        if if_node:
+            for node in if_node.xmlGetChildNodeList("force"):
+                if (node.xmlGetNode("drag_model")["model"] == "inclusions"):
+                    node.xmlGetNode("drag_model")["model"] = "Gobin"
 
     def __backwardCompatibilityFrom_7_1(self):
         """
@@ -881,7 +884,7 @@ class XMLinitNeptune(BaseXmlInit):
                                                               "covariance_qfp_1_2")
 
 
-    def _backwardCompatibilityCurrentVersion(self):
+    def __backwardCompatibilityTo_8_0(self):
         """
         Change XML in order to ensure backward compatibility.
         """
@@ -899,6 +902,106 @@ class XMLinitNeptune(BaseXmlInit):
                                    elasticity_val)
                 particles_rad_node.xmlRemoveChild('elasticity')
 
+    def __backwardCompatibilityTo_9_0(self):
+        """
+        Change XML in order to ensure backward compatibility.
+        """
+
+        # Update field_id to conv_field for scalars and non-condensable
+        # gases
+        scalars_node = self.case.xmlGetNode("additional_scalars")
+        if scalars_node:
+            n1 = scalars_node.xmlGetNode("scalars")
+            if n1:
+                for node in n1.xmlGetChildNodeList("variable"):
+                    if node['conv_field'] == None:
+                        old_f_id = node["field_id"]
+                        node["conv_field"] = old_f_id
+                        node["field_id"] = "none"
+
+        XMLNodeNonCondens = self.case.xmlGetNode('non_condensable_list')
+        if XMLNodeNonCondens != None:
+            for node in XMLNodeNonCondens.xmlGetNodeList('variable'):
+                if node['conv_field'] == None:
+                    old_f_id = node["field_id"]
+                    node["conv_field"] = old_f_id
+                    node["field_id"] = "none"
+
+        # Update particles emissivity coefficients
+        tprm = ThermalParticlesRadiationModel(self.case)
+        ipp_node = None
+        if tprm.isActivated == 'on':
+            tm_node = self.case.xmlGetNode('thermophysical_models')
+            irt_node = tm_node.xmlGetNode('interparticles_radiative_transfer')
+
+            if irt_node:
+                ipp_node = tm_node.xmlInitNode('solid_particles_properties')
+                e_node_list = irt_node.xmlGetChildNodeList('emissivity')
+                if len(e_node_list) == 1:
+                    ipp_irt_node = ipp_node.xmlInitNode('particles_radiative_transfer')
+
+                    val_e = irt_node.xmlGetChildString('emissivity')
+                    irt_node.xmlRemoveChild('emissivity')
+
+                    mfm = MainFieldsModel(self.case)
+                    for field in mfm.getSolidPhaseList():
+                        ipp_irt_node.xmlSetData('emissivity', val_e, field_id = field.f_id)
+
+                irt_node.xmlRemoveNode()
+
+        # Update polydispersion
+        _has_polydispersion = False
+        mfm = MainFieldsModel(self.case)
+        tm_node = self.case.xmlGetNode('thermophysical_models')
+        flds_node = tm_node.xmlGetNode('fields')
+        for f in mfm.getSolidPhaseList():
+            nn = flds_node.xmlGetChildNode('field', field_id=f.f_id)
+            node_poly = nn.xmlGetChildNode('polydispersed')
+            if node_poly:
+                if nn.xmlGetString('polydispersed') == 'on':
+                    _has_polydispersion = True
+                node_poly.xmlRemoveNode()
+
+        if _has_polydispersion:
+            # Only create node if needed, since default is 'off'
+            ipp_node = tm_node.xmlInitNode('solid_particles_properties')
+            ipp_node.xmlSetData('polydispersion', 'on')
+
+        # Particles compaction
+        sc_node = tm_node.xmlGetChildNode('solid_compaction')
+        if sc_node != None:
+            sc_val = tm_node.xmlGetDouble('solid_compaction')
+            sc_node.xmlRemoveNode()
+            if not ipp_node:
+                ipp_node = tm_node.xmlInitNode('solid_particles_properties')
+            ipp_node.xmlSetData('solid_compaction', sc_val)
+
+        # Particles elasticity
+        if tm_node.xmlGetChildNode('solid_elasticity_coefficient'):
+            sec_val = tm_node.xmlGetDouble('solid_elasticity_coefficient')
+            tm_node.xmlRemoveChild('solid_elasticity_coefficient')
+
+            if not ipp_node:
+                ipp_node = tm_node.xmlInitNode('solid_particles_properties')
+
+            for f in mfm.getSolidPhaseList():
+                ipp_node.xmlSetData('elasticity_coefficient', sec_val, field_id=f.f_id)
+
+
+        # Threshold
+        if ipp_node:
+            if not ipp_node.xmlGetNode('min_frictional_threshold'):
+                ipp_node.xmlSetData('min_frictional_threshold', 0.6)
+
+        return
+
+    def _backwardCompatibilityCurrentVersion(self):
+        """
+        Change XML in order to ensure backward compatibility.
+        """
+        self.__backwardCompatibilityTo_9_0()
+        return;
+
 #-------------------------------------------------------------------------------
 # XMLinit test case
 #-------------------------------------------------------------------------------
