@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 # This file is part of code_saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2023 EDF S.A.
+# Copyright (C) 1998-2024 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -20,18 +20,18 @@
 # this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
 # Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # Standard modules
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 import os, sys, string, logging, traceback
 from string import *
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # Third-party modules
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 try:
     import matplotlib
@@ -41,9 +41,9 @@ except ImportError:
 
 matplotlib.use("Agg")
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # matplotlib config
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 import matplotlib.pyplot as plt
 from matplotlib import rcParams
@@ -57,9 +57,9 @@ rcParams['figure.figsize']  = (4,4)
 rcParams['font.family']     = 'sans-serif'
 rcParams['text.usetex']     = True
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # additional colors
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 bedf      = (0.    , 0.3569, 0.7333)
 dbedf     = (0.0353, 0.2078, 0.4784)
@@ -74,18 +74,18 @@ brown     = (0.5451, 0.2706, 0.0745)
 red       = (1.    , 0.    , 0.    )
 black     = (0.    , 0.    , 0.    )
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 # log config
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
 
 logging.basicConfig()
 log = logging.getLogger(__file__)
 log.setLevel(logging.NOTSET)
-#log.setLevel(logging.DEBUG)
+# log.setLevel(logging.DEBUG)
 
-#===============================================================================
+# ===============================================================================
 # Plot class
-#===============================================================================
+# ===============================================================================
 
 class Plot(object):
     """
@@ -169,19 +169,19 @@ class Plot(object):
 
         self.cmd += parser.getPltCommands(node)
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def setMeasurement(self, bool):
         self.ismesure = bool
         if self.ismesure and self.fmt == "":
             self.fmt = 'ko'
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def measurement(self):
         return self.ismesure
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def uploadData(self, xcol, ycol, xplus, xscale, yplus, yscale):
         """
@@ -190,12 +190,36 @@ class Plot(object):
         j = 0
         error = ""
 
-        for line in self.f.readlines():
+        lines = self.f.readlines()
+        separator = ' '
+        if len(lines) > 1:
+            for line in lines[1:]:
+                sline = line.lstrip()
+                if sline and sline[0] != "#":
+                    line_test = line
+                    break
+        elif len(lines) > 0:
+            line_test = lines[0]
+        else:
+            line_test = ''
+        if line_test.find(';') > -1:
+            separator = ';'
+        elif line_test.find(':') > -1:
+            separator = ':'
+        elif line_test.find(', ') > -1:
+            separator = ', '
+        elif line_test.find(' ') > -1:
+            separator = ' '
+        elif line_test.find('\t') > -1:
+            separator = '\t'
+        elif line_test.find(',') > -1:
+            separator = ','
+
+        for line in lines:
             line = line.lstrip()
             if line and line[0] != '#':
                 j += 1
-                line = line.replace(", ", " ") # compatibility with CSV
-                line = line.replace(";", " ") # compatibility with CSV
+                line = line.replace(separator, " ") # compatibility with CSV
                 line = line.lstrip()
 
                 # for CSV files, try to detect a header to skip it
@@ -221,7 +245,7 @@ class Plot(object):
 
         return error
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def uploadErrorBar(self, errorbar, errorp, col):
         """
@@ -298,10 +322,10 @@ class Plot(object):
                         error.append(errorp/100.*float(line.split()[col-1]))
                 return error
 
-#===============================================================================
+# ===============================================================================
 # Probes class
 # Curve or plot for monitoring point (probe)
-#===============================================================================
+# ===============================================================================
 
 class Probes(object):
     """
@@ -348,14 +372,14 @@ class Probes(object):
 
         f.close()
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def measurement(self):
         return self.ismesure
 
-#===============================================================================
+# ===============================================================================
 # Subplot class
-#===============================================================================
+# ===============================================================================
 
 class Subplot(object):
     """
@@ -405,9 +429,9 @@ class Subplot(object):
 
         self.cmd += parser.getPltCommands(node)
 
-#===============================================================================
+# ===============================================================================
 # Figure class
-#===============================================================================
+# ===============================================================================
 
 class Figure(object):
     """
@@ -448,7 +472,7 @@ class Figure(object):
                 print("    ERROR: figure '" + self.file_name + "': subplot " \
                       + str(id) + " not defined.")
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def layout(self):
         """
@@ -516,7 +540,7 @@ class Figure(object):
             nbcol = (nbr-1) / nbrow+1
             hs = 0.3
             if nbcol > 2:
-              hs = 0.45
+                hs = 0.45
             ri = 0.9
             le = 0.15
             ws = 0.6
@@ -530,9 +554,9 @@ class Figure(object):
 
         return nbrow, nbcol, hs, ri, le, ws
 
-#===============================================================================
+# ===============================================================================
 # Plotter class
-#===============================================================================
+# ===============================================================================
 
 class Plotter(object):
     """
@@ -550,7 +574,7 @@ class Plotter(object):
         self.curves  = []
         self.figures = []
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def __number_of_column(self, file_name):
         """
@@ -566,15 +590,30 @@ class Plotter(object):
         f.close()
         return nbr
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
-    def plot_study(self, study_label, study_object, disable_tex, default_fmt):
+    def plot_study(self, dest, study_object, list_cases, disable_tex, default_fmt):
         """
-        Method used to plot all plots from a I{study_label} (all cases).
-        @type study_label: C{String}
-        @param study_label: label of a study
+        Method used to plot all plots from a I{study} (all cases).
+        @param study_object: study object: C{Study}
+        @param list_cases: list of cases of a study: C{list}
+        @param disable_tex,: option to disable latex: C{boolean}
+        @param default_fmt: default format: C{String}
 
         """
+        # initialization necessary in case of several studies
+        self.curves = []
+
+        # store all messages
+        msg = ""
+
+        study_label = study_object.label
+
+        # open log file related to generation of figures for a given study
+        log_name = "smgr_draw_" + study_label + ".log"
+        log_path = os.path.join(dest, log_name)
+        log_draw = open(log_path, mode='w')
+
         # disable tex in Matplotlib (use Mathtext instead)
         rcParams['text.usetex'] = not disable_tex
 
@@ -582,65 +621,53 @@ class Plotter(object):
         nodes_list, files = self.parser.getMeasurement(study_label)
         for i in range(len(files)):
             nodes = nodes_list[i]
-            file  = files[i]
+            fi  = files[i]
             for node in nodes:
-                curve = Plot(node, self.parser, file)
-                curve.setMeasurement(True)
-                self.curves.append(curve)
+
+                if not os.path.isfile(fi):
+                    file_name = os.path.basename(fi)
+                    msg += "    This measurement file does not exist: %s \
+                                (last call with path: %s)\n" % (file_name, fi)
+
+                else:
+                    curve = Plot(node, self.parser, fi)
+                    curve.setMeasurement(True)
+                    self.curves.append(curve)
 
         # Read the files for probes
-        for case in study_object.cases:
-            if case.plot == "on" and case.is_run != "KO":
+        for case in list_cases:
+            if case.plot:
+
+                # Read the files for probes
                 for node in self.parser.getChildren(case.node, "probes"):
                     file_name, dest, fig = self.parser.getProbes(node)
 
-                    f = os.path.join(self.parser.getDestination(),
-                                     study_label,
-                                     case.label, case.resu,
-                                     dest, "monitoring", file_name)
+                    f = os.path.join(case.run_dir, "monitoring", dest, file_name)
                     if not os.path.isfile(f):
-                        print("\n\nThis file does not exist: %s\n (last call with path: %s)\n" % (file_name, f))
+                        msg += "    This probes file does not exist: %s \
+                                (last call with path: %s)\n" % (file_name, f)
 
                     else:
                         for ycol in range(2, self.__number_of_column(f) + 1):
                             curve = Probes(f, fig, ycol)
                             self.curves.append(curve)
 
-        # Read the files of results of cases
-        for case in study_object.cases:
-            if case.plot == "on" and case.is_run != "KO" and not case.disabled:
+                # Read the files of results of cases
                 for node in self.parser.getChildren(case.node, "data"):
                     plots, file_name, dest, repo = self.parser.getResult(node)
 
-                    if dest:
-                        d = dest
-                        dd = self.parser.getDestination()
-                    elif repo:
-                        d = repo
-                        dd = self.parser.getRepository()
-
-                    if case.subdomains:
-                        dom_list = case.subdomains
-                    else:
-                        dom_list = [""]
-
                     iok = False
-                    for ddd in dom_list:
+                    for sd in (".", "monitoring", "profiles"):
 
-                        for sd in (".", "monitoring", "profiles"):
+                        f = os.path.join(case.run_dir, sd, dest, file_name)
 
-                            f = os.path.join(dd,
-                                             study_label,
-                                             case.label, case.resu,
-                                             d, ddd, sd, file_name)
-
-                            if os.path.isfile(f):
-                                iok = True
-                                break
+                        if os.path.isfile(f):
+                            iok = True
+                            break
 
                     if not iok:
-                        print("\n\nThis file does not exist: %s\n"
-                              "(last call with path: %s)\n" % (file_name, f))
+                        msg += "    This file does not exist: %s  \
+                                (last call with path: %s)\n" % (file_name, f)
 
                     else:
                         for nn in plots:
@@ -659,13 +686,13 @@ class Plotter(object):
                     f = os.path.join(dd, study_label, "POST", file_name)
 
                     if not os.path.isfile(f):
-                        raise ValueError("\n\nThis file does not exist: %s\n"
-                                         " (call with path: %s)\n" % (file_name, f))
-
-                    for nn in plots:
-                        curve = Plot(nn, self.parser, f)
-                        curve.setMeasurement(False)
-                        self.curves.append(curve)
+                        msg += "    This file does not exist: %s \
+                                (last call with path: %s)\n" % (file_name, f)
+                    else:
+                        for nn in plots:
+                            curve = Plot(nn, self.parser, f)
+                            curve.setMeasurement(False)
+                            self.curves.append(curve)
 
         subplots = []
         for node in self.parser.getSubplots(study_label):
@@ -682,7 +709,9 @@ class Plotter(object):
                         missing_sps.append(sp)
 
         for sp in missing_sps:
-            print("    ERROR: subplot " + str(sp) + " referenced but not defined.")
+            msg += "    ERROR: subplot " + str(sp) + " referenced but not defined.\n"
+
+        self.figures = []
 
         # Build the list of figures to handle
         for node in self.parser.getFigures(study_label):
@@ -709,12 +738,25 @@ class Plotter(object):
             study_object.matplotlib_figures.append(f)
 
             # save the figure
-            self.__save(f, figure)
+            try:
+                self.__save(f, figure)
+            except Exception as e:
+                log_draw.write(e.args[0])
 
         # close current figure
         plt.close()
 
-    #---------------------------------------------------------------------------
+        # close draw log file
+        log_draw.close()
+
+        if os.path.getsize(log_path) > 0:
+            msg += "    /!\ ERRORS during figure generation. See %s\n" %log_path
+        else:
+            os.remove(log_path)
+
+        return msg
+
+    # ---------------------------------------------------------------------------
 
     def __draw_curve(self, ax, curve, p):
         """
@@ -740,7 +782,6 @@ class Plotter(object):
         else:
             lines = ax.plot(xspan, yspan, curve.fmt, label=curve.legend)
 
-
         # additional matplotlib raw commands for line2D
         line = lines[0]
         for cmd in curve.cmd:
@@ -750,7 +791,7 @@ class Plotter(object):
                 print("Error with the matplotlib command: %s" % cmd)
                 traceback.print_exc()
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def __draw_axis(self, ax, p):
         if p.xlabel:
@@ -762,7 +803,7 @@ class Plotter(object):
         if p.ylim:
             ax.set_ylim((p.ylim[0], p.ylim[1]))
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def __draw_legend(self, ax, p, bool, hs, ws, ri, le):
         if p.legstatus == "on":
@@ -809,7 +850,7 @@ class Plotter(object):
                                         right=ri2,
                                         left=le2)
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def plot_figure(self, figure):
         """
@@ -865,7 +906,7 @@ class Plotter(object):
 
         # title of the figure
         if figure.title:
-           plt.suptitle(figure.title, fontsize=12)
+            plt.suptitle(figure.title, fontsize=12)
 
         # additional matplotlib raw commands for subplot
         for p in figure.subplots:
@@ -878,7 +919,7 @@ class Plotter(object):
                     print("Error with the matplotlib command: %s" % cmd)
                     traceback.print_exc()
 
-    #---------------------------------------------------------------------------
+    # ---------------------------------------------------------------------------
 
     def __save(self, f, figure):
         """method used to save the figure"""
@@ -895,4 +936,4 @@ class Plotter(object):
             else:
                 plt.savefig(f, format=fmt)
 
-#-------------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
