@@ -5,12 +5,12 @@
  * Example in cs_user_extra_operations_mean_profiles.c
  *============================================================================*/
 
-/* code_saturne version 8.1 */
+/* code_saturne version 9.1 */
 
 /*
   This file is part of code_saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2023 EDF S.A.
+  Copyright (C) 1998-2025 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -27,7 +27,9 @@
   Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
-#include "cs_defs.h"
+/*----------------------------------------------------------------------------*/
+
+#include "cs_headers.h"
 
 /*----------------------------------------------------------------------------
  * Standard C library headers
@@ -43,11 +45,7 @@
  * Local headers
  *----------------------------------------------------------------------------*/
 
-#include "cs_headers.h"
-
-/* User header */
-
-#include "cs_user_profile.h"
+#include "user_examples/cs_user_profile.h"
 
 /*----------------------------------------------------------------------------
  * MEDCOUPLING library headers
@@ -55,8 +53,8 @@
 
 #if defined(HAVE_MEDCOUPLING)
 
-#include "cs_medcoupling_intersector.h"
-#include "cs_medcoupling_mesh.hxx"
+#include "base/cs_medcoupling_intersector.h"
+#include "base/cs_medcoupling_mesh.hxx"
 
 #include <MEDCoupling_version.h>
 
@@ -97,7 +95,7 @@ using namespace MEDCoupling;
  * Private functions and global variables
  */
 
-static user_profile_info_t _profile_list = { NULL, 0 };
+static user_profile_info_t _profile_list = { nullptr, 0 };
 
 /*----------------------------------------------------------------------------
  *  Intersector structure for MedCoupling
@@ -133,8 +131,8 @@ _compute_min_max(cs_lnum_t       n_vals,
   cs_real_t _min = DBL_MAX, _max = -DBL_MAX;
 
   for (cs_lnum_t i = 0; i < n_vals; i++) {
-    _min = CS_MIN(_min, var[i]);
-    _max = CS_MAX(_max, var[i]);
+    _min = cs::min(_min, var[i]);
+    _max = cs::max(_max, var[i]);
   }
 
 #if defined(HAVE_MPI)
@@ -162,12 +160,12 @@ _compute_min_max(cs_lnum_t       n_vals,
  *----------------------------------------------------------------------------*/
 
 static user_profile_med_t *
-_allocate_med_mesh_struct(cs_lnum_t n_layers)
+_allocate_med_mesh_struct([[maybe_unused]] cs_lnum_t n_layers)
 {
-  user_profile_med_t *med_t = NULL;
-  BFT_MALLOC(med_t, 1, user_profile_med_t);
+  user_profile_med_t *med_t = nullptr;
+  CS_MALLOC(med_t, 1, user_profile_med_t);
 #if defined(HAVE_MEDCOUPLING)
-  BFT_MALLOC(med_t->layer_mesh, n_layers, MEDCouplingUMesh *);
+  CS_MALLOC(med_t->layer_mesh, n_layers, MEDCouplingUMesh *);
   for (int layer_id = 0; layer_id < n_layers; layer_id++) {
     char name[10];
     snprintf(name, 10, "%s_%d", "layer", layer_id);
@@ -225,7 +223,7 @@ _create_1d_sample_(user_profile_t  *profile,
   /* Reset n_elts_sample */
   *n_elts_sample = 0;
 
-  if (f == NULL) {
+  if (f == nullptr) {
     bft_printf("Warning field %s set for profile calc does not exist\n",
                field);
     return;
@@ -234,10 +232,10 @@ _create_1d_sample_(user_profile_t  *profile,
 
   // Define pointer and variable for cs_selector
   cs_lnum_t  n_selected_cells = 0;
-  cs_lnum_t *selected_cells   = NULL;
+  cs_lnum_t *selected_cells   = nullptr;
 
   // Allocate memory for the cells list which will be populated by cs_selector
-  BFT_MALLOC(selected_cells, n_cells, cs_lnum_t);
+  CS_MALLOC(selected_cells, n_cells, cs_lnum_t);
 
   cs_selector_get_cell_list(profile->criteria,
                             &n_selected_cells,
@@ -252,7 +250,7 @@ _create_1d_sample_(user_profile_t  *profile,
     cs_real_t weight_cell        = 0.0;
 
     if (strcmp(weighted, "MASS") == 0) {
-      if (density != NULL)
+      if (density != nullptr)
         weight_cell = cell_vol[c_id] * density->val[c_id];
       else
         weight_cell = cell_vol[c_id] * ro0;
@@ -289,10 +287,10 @@ _create_1d_sample_(user_profile_t  *profile,
   /*Total selected cells weigth could be calculated once and not for each layer
    * but keep as this because of current code structure (avoid de create a
    * dedicated function and re compute each cell weight*/
-  cs_parall_sum(1, CS_DOUBLE, &sel_cells_weight);
+  cs_parall_sum(1, CS_REAL_TYPE, &sel_cells_weight);
   profile->sel_cells_weigth = sel_cells_weight;
 
-  BFT_FREE(selected_cells);
+  CS_FREE(selected_cells);
 }
 
 /*----------------------------------------------------------------------------
@@ -326,7 +324,7 @@ _compute_sample_moment(cs_real_t *sample,
   cs_real_t *w_n;
   cs_real_t  w_tot = 0.0;
 
-  BFT_MALLOC(w_n, n_elts_sample, cs_real_t);
+  CS_MALLOC(w_n, n_elts_sample, cs_real_t);
 
   for (cs_lnum_t iel = 0; iel < n_elts_sample; iel++)
     w_tot += weights[iel];
@@ -352,7 +350,7 @@ _compute_sample_moment(cs_real_t *sample,
     variance += w_n[iel] * pow(sample[iel] - mu, 2.0);
 
   /* Sum over all MPI ranks */
-  cs_parall_sum(1, CS_DOUBLE, &variance);
+  cs_parall_sum(1, CS_REAL_TYPE, &variance);
 
   sigma = pow(variance, 1.0 / 2.0);
 
@@ -369,7 +367,7 @@ _compute_sample_moment(cs_real_t *sample,
   min_max[0] = min_sample;
   min_max[1] = max_sample;
 
-  BFT_FREE(w_n);
+  CS_FREE(w_n);
 }
 
 /*----------------------------------------------------------------------------
@@ -448,7 +446,7 @@ _fill_histogram_classes_u_bandwidth(user_histogram_t  *histogram,
 
   /*Sum height classes over all MPI ranks*/
 
-  cs_parall_sum(n_bins, CS_DOUBLE, histogram->h_i);
+  cs_parall_sum(n_bins, CS_REAL_TYPE, histogram->h_i);
 
   /*update histogram*/
   histogram->n_bins = n_bins;
@@ -581,7 +579,7 @@ _compute_histogram(user_histogram_t  *histogram,
 
   cs_lnum_t n_loop = 1;
   cs_real_t bandwidth_variation
-    = CS_ABS(bandwidth - bandwidth_update) / bandwidth;
+    = cs::abs(bandwidth - bandwidth_update) / bandwidth;
 
   /*perform a loop to try top optimize bandwidth*/
   while (n_loop < 10 && bandwidth_variation > 0.05 && IQR > DBL_EPSILON
@@ -621,8 +619,8 @@ _compute_histogram(user_histogram_t  *histogram,
 
     bandwidth_update = (max - min) / ((cs_real_t)n_bins);
 
-    bandwidth_variation = CS_ABS(bandwidth - bandwidth_update) / bandwidth;
-    IQR_var             = CS_ABS(IQR - IQR_pre) / IQR;
+    bandwidth_variation = cs::abs(bandwidth - bandwidth_update) / bandwidth;
+    IQR_var             = cs::abs(IQR - IQR_pre) / IQR;
 
     n_loop++;
   }
@@ -639,8 +637,8 @@ _compute_histogram(user_histogram_t  *histogram,
  *----------------------------------------------------------------------------*/
 
 static void
-_output_histogram_ot(user_histogram_t  *histogram,
-                     const char        *dirname)
+_output_histogram_ot([[maybe_unused]]user_histogram_t  *histogram,
+                     [[maybe_unused]]const char        *dirname)
 {
 #if HAVE_OT == 1
 
@@ -656,7 +654,7 @@ _output_histogram_ot(user_histogram_t  *histogram,
   for (int b_id = 0; b_id < n_bins; b_id++) {
     h_i[b_id] = histogram->h_i[b_id];
     l_i[b_id] = histogram->l_i[b_id];
-    min_li    = CS_MIN(l_i[b_id], min_li);
+    min_li    = cs::min(l_i[b_id], min_li);
   }
 
   if (min_li < DBL_EPSILON * 1e4)
@@ -736,19 +734,19 @@ _calculate_min_max_dir(user_profile_t  *profile)
 
   // Define pointer and variable for cs_selector
   cs_lnum_t  n_selected_cells = 0;
-  cs_lnum_t *selected_cells   = NULL;
+  cs_lnum_t *selected_cells   = nullptr;
 
   // Allocate memory for the cells list which will be populated by cs_selector
-  BFT_MALLOC(selected_cells, m->n_cells, cs_lnum_t);
+  CS_MALLOC(selected_cells, m->n_cells, cs_lnum_t);
 
   cs_selector_get_cell_list(profile->criteria,
                             &n_selected_cells,
                             selected_cells);
 
   cs_lnum_t  n_selected_vertices = 0;
-  cs_lnum_t *selected_vertices   = NULL;
+  cs_lnum_t *selected_vertices   = nullptr;
 
-  BFT_MALLOC(selected_vertices, n_vertices, cs_lnum_t);
+  CS_MALLOC(selected_vertices, n_vertices, cs_lnum_t);
   cs_selector_get_cell_vertices_list_by_ids(n_selected_cells,
                                             selected_cells,
                                             &n_selected_vertices,
@@ -800,11 +798,11 @@ _calculate_min_max_dir(user_profile_t  *profile)
   cs_real_t min_mesh_ijn[3] = { 0.0, 0.0, 0.0 };
   cs_real_t max_mesh_ijn[3] = { 0.0, 0.0, 0.0 };
 
-  cs_real_t **vtx_dist = NULL;
+  cs_real_t **vtx_dist = nullptr;
 
-  BFT_MALLOC(vtx_dist, 3, cs_real_t *);
+  CS_MALLOC(vtx_dist, 3, cs_real_t *);
   for (int k = 0; k < 3; k++)
-    BFT_MALLOC(vtx_dist[k], n_selected_vertices, cs_real_t);
+    CS_MALLOC(vtx_dist[k], n_selected_vertices, cs_real_t);
 
   for (cs_lnum_t ii = 0; ii < n_selected_vertices; ii++) {
     cs_lnum_t vtx_id = selected_vertices[ii];
@@ -838,11 +836,11 @@ _calculate_min_max_dir(user_profile_t  *profile)
   profile->min_dir = min_mesh_ijn[2];
   profile->max_dir = max_mesh_ijn[2];
 
-  BFT_FREE(selected_cells);
-  BFT_FREE(selected_vertices);
+  CS_FREE(selected_cells);
+  CS_FREE(selected_vertices);
   for (int k = 0; k < 3; k++)
-    BFT_FREE(vtx_dist[k]);
-  BFT_FREE(vtx_dist);
+    CS_FREE(vtx_dist[k]);
+  CS_FREE(vtx_dist);
 }
 
 /*----------------------------------------------------------------------------
@@ -1039,13 +1037,13 @@ _set_stl_layers_seeds(user_profile_t  *profile,
 
   // Get mesh quantities
   const cs_mesh_quantities_t *mq         = cs_glob_mesh_quantities;
-  const cs_real_t            *cell_cen   = mq->cell_cen;
+  const cs_real_3_t          *cell_cen   = mq->cell_cen;
 
   // define pointer and variable for cs_selector
   cs_lnum_t  n_selected_cells = 0;
-  cs_lnum_t *selected_cells   = NULL;
+  cs_lnum_t *selected_cells   = nullptr;
   // Allocate memory for the cells list which will be populated by cs_selector
-  BFT_MALLOC(selected_cells, cs_glob_mesh->n_cells_with_ghosts, cs_lnum_t);
+  CS_MALLOC(selected_cells, cs_glob_mesh->n_cells_with_ghosts, cs_lnum_t);
 
   cs_selector_get_cell_list(
     profile->criteria, &n_selected_cells, selected_cells);
@@ -1077,12 +1075,12 @@ _set_stl_layers_seeds(user_profile_t  *profile,
 
   /* Set an array of selected cell center coordinates */
   cs_real_t *point_coord;
-  BFT_MALLOC(point_coord, 3 * n_selected_cells, cs_real_t);
+  CS_MALLOC(point_coord, 3 * n_selected_cells, cs_real_t);
 
   for (int ii = 0; ii < n_selected_cells; ii++) {
     cs_lnum_t c_id = selected_cells[ii];
     for (int k = 0; k < 3; k++)
-      point_coord[3 * ii + k] = cell_cen[3 * c_id + k];
+      point_coord[3 * ii + k] = cell_cen[c_id][k];
   }
 
   cs_lnum_t   point_id[2];
@@ -1090,9 +1088,10 @@ _set_stl_layers_seeds(user_profile_t  *profile,
   cs_real_3_t closest_point_coord[2];
 
   /* Initialiaze values of closest_point_coord */
-  for (int jj = 0; jj < 2; jj++)
+  for (int jj = 0; jj < 2; jj++) {
     for (int k = 0; k < 3; k++)
-      closest_point_coord[jj][k] = -1.E20;
+      closest_point_coord[jj][k] = -1.e20;
+  }
 
   /* For each target point, find the closest cell center in the cell sell over
      all ranks Doing so, the seeds are in the fluid domain */
@@ -1107,10 +1106,10 @@ _set_stl_layers_seeds(user_profile_t  *profile,
         closest_point_coord[jj][k] = point_coord[3 * point_id[jj] + k];
     }
 
-    cs_parall_max(3, CS_DOUBLE, closest_point_coord[jj]);
+    cs_parall_max(3, CS_REAL_TYPE, closest_point_coord[jj]);
   }
 
-  BFT_MALLOC(stl_mesh->seed_coords, 3 * (n_layers - 1), cs_real_t);
+  CS_MALLOC(stl_mesh->seed_coords, 3 * (n_layers - 1), cs_real_t);
   cs_lnum_t n_seeds = 0;
 
   /* Associate the found closest point to stl seeds */
@@ -1139,9 +1138,9 @@ _set_stl_layers_seeds(user_profile_t  *profile,
 
   stl_mesh->n_seeds = n_seeds;
 
-  BFT_FREE(selected_cells);
+  CS_FREE(selected_cells);
 
-  BFT_FREE(point_coord);
+  CS_FREE(point_coord);
 }
 
 /*----------------------------------------------------------------------------
@@ -1166,7 +1165,7 @@ _set_layers_stl_mesh(user_profile_t  *profile,
 
   // Allocate memory for stl mesh
   stl_mesh->n_faces = 6 * 2; // 2 triangles per faces
-  BFT_MALLOC(stl_mesh->coords, 3 * stl_mesh->n_faces, cs_real_3_t);
+  CS_MALLOC(stl_mesh->coords, 3 * stl_mesh->n_faces, cs_real_3_t);
 
   // Set vector orthogonal spatial system
   cs_real_t n_v[3];
@@ -1189,7 +1188,7 @@ _set_layers_stl_mesh(user_profile_t  *profile,
   /* plane size is calculated to be enveloppe of cell selected size*/
   cs_real_t i_size     = (profile->max_i - profile->min_i);
   cs_real_t j_size     = (profile->max_j - profile->min_j);
-  cs_real_t plane_size = CS_MAX(i_size, j_size) * 1.5;
+  cs_real_t plane_size = cs::max(i_size, j_size) * 1.5;
 
   // Calculate center  of each planes
   cs_real_3_t O_planes_coord[6];
@@ -1336,8 +1335,8 @@ _set_layers_stl_mesh(user_profile_t  *profile,
  *----------------------------------------------------------------------------*/
 
 static void
-_set_med_layer_mesh(user_profile_t  *profile,
-                    cs_lnum_t        layer_id)
+_set_med_layer_mesh([[maybe_unused]]user_profile_t  *profile,
+                    [[maybe_unused]]cs_lnum_t        layer_id)
 {
 #if defined(HAVE_MEDCOUPLING)
   // Get mesh quantities
@@ -1379,9 +1378,9 @@ _set_med_layer_mesh(user_profile_t  *profile,
   z_max = layer_thickness / 2.0;
 
   double *x_coords, *y_coords, *z_coords;
-  BFT_MALLOC(x_coords, n_x, double);
-  BFT_MALLOC(y_coords, n_y, double);
-  BFT_MALLOC(z_coords, n_z, double);
+  CS_MALLOC(x_coords, n_x, double);
+  CS_MALLOC(y_coords, n_y, double);
+  CS_MALLOC(z_coords, n_z, double);
 
   for (int x_id = 0; x_id < n_x; x_id++)
     x_coords[x_id] = (x_max - x_min) * x_id / (n_x - 1) + x_min;
@@ -1585,9 +1584,9 @@ _set_med_layer_mesh(user_profile_t  *profile,
   arrZ->decrRef();
   Cmesh->decrRef();
 
-  BFT_FREE(x_coords);
-  BFT_FREE(y_coords);
-  BFT_FREE(z_coords);
+  CS_FREE(x_coords);
+  CS_FREE(y_coords);
+  CS_FREE(z_coords);
 
 #endif
 }
@@ -1609,7 +1608,7 @@ _compute_cell_volume_per_layer_basic(user_profile_t  *profile)
 {
   // Get mesh quantities
   const cs_mesh_quantities_t *mq       = cs_glob_mesh_quantities;
-  const cs_real_t            *cell_cen = mq->cell_cen;
+  const cs_real_3_t          *cell_cen = mq->cell_cen;
   const cs_lnum_t             n_cells  = cs_glob_mesh->n_cells;
   const cs_lnum_t n_cells_with_ghosts  = cs_glob_mesh->n_cells_with_ghosts;
 
@@ -1627,9 +1626,9 @@ _compute_cell_volume_per_layer_basic(user_profile_t  *profile)
 
   // Define pointer and variable for cs_selector
   cs_lnum_t  n_selected_cells = 0;
-  cs_lnum_t *selected_cells   = NULL;
+  cs_lnum_t *selected_cells   = nullptr;
   // Allocate memory for the cells list which will be populated by cs_selector
-  BFT_MALLOC(selected_cells, n_cells_with_ghosts, cs_lnum_t);
+  CS_MALLOC(selected_cells, n_cells_with_ghosts, cs_lnum_t);
 
   cs_selector_get_cell_list(profile->criteria,
                             &n_selected_cells,
@@ -1646,9 +1645,9 @@ _compute_cell_volume_per_layer_basic(user_profile_t  *profile)
   for (cs_lnum_t ii = 0; ii < n_selected_cells; ii++) {
     cs_lnum_t c_id = selected_cells[ii];
 
-    cs_real_t x = cell_cen[3 * c_id + 0];
-    cs_real_t y = cell_cen[3 * c_id + 1];
-    cs_real_t z = cell_cen[3 * c_id + 2];
+    cs_real_t x = cell_cen[c_id][0];
+    cs_real_t y = cell_cen[c_id][1];
+    cs_real_t z = cell_cen[c_id][2];
 
     // project cell cen vector of dir vector
     cs_real_t dist
@@ -1672,7 +1671,7 @@ _compute_cell_volume_per_layer_basic(user_profile_t  *profile)
 
   } // end of for loop for layer cell vol / weigth calculation
 
-  BFT_FREE(selected_cells);
+  CS_FREE(selected_cells);
 }
 
 /*----------------------------------------------------------------------------
@@ -1696,14 +1695,14 @@ _compute_cell_volume_per_layer_stl(user_profile_t  *profile)
   // Profile shorter variables
   cs_lnum_t n_layers = profile->n_layers;
 
-  cs_real_t *cells_l_id_vol = NULL;
-  BFT_MALLOC(cells_l_id_vol, n_cells_with_ghosts, cs_real_t);
+  cs_real_t *cells_l_id_vol = nullptr;
+  CS_MALLOC(cells_l_id_vol, n_cells_with_ghosts, cs_real_t);
 
   // Define pointer and variable for cs_selector
   cs_lnum_t  n_selected_cells = 0;
-  cs_lnum_t *selected_cells   = NULL;
+  cs_lnum_t *selected_cells   = nullptr;
   // Allocate memory for the cells list which will be populated by cs_selector
-  BFT_MALLOC(selected_cells, n_cells_with_ghosts, cs_lnum_t);
+  CS_MALLOC(selected_cells, n_cells_with_ghosts, cs_lnum_t);
 
   cs_selector_get_cell_list(
     profile->criteria, &n_selected_cells, selected_cells);
@@ -1723,7 +1722,7 @@ _compute_cell_volume_per_layer_stl(user_profile_t  *profile)
 
     cs_stl_mesh_t *stl_mesh = profile->mesh_list[s_id];
     /* Compute porisity associated to each layer using cs_stl_mesh features */
-    cs_stl_compute_porosity(stl_mesh, cells_l_id_vol, NULL);
+    cs_stl_compute_porosity(stl_mesh, cells_l_id_vol, nullptr);
 
     for (cs_lnum_t ii = 0; ii < n_selected_cells; ii++) {
       cs_lnum_t c_id = selected_cells[ii];
@@ -1731,8 +1730,8 @@ _compute_cell_volume_per_layer_stl(user_profile_t  *profile)
     }
   }
 
-  BFT_FREE(cells_l_id_vol);
-  BFT_FREE(selected_cells);
+  CS_FREE(cells_l_id_vol);
+  CS_FREE(selected_cells);
 }
 
 /*----------------------------------------------------------------------------
@@ -1747,9 +1746,12 @@ _compute_cell_volume_per_layer_stl(user_profile_t  *profile)
  *----------------------------------------------------------------------------*/
 
 static void
-_compute_intersection_volume_med(user_profile_med_t *med_t,
-                                 cs_real_t          *vol_intersect,
-                                 cs_lnum_t           layer_id)
+_compute_intersection_volume_med
+(
+ [[maybe_unused]]user_profile_med_t *med_t,
+ [[maybe_unused]]cs_real_t          *vol_intersect,
+ [[maybe_unused]]cs_lnum_t           layer_id
+)
 {
 #if defined(HAVE_MEDCOUPLING)
   cs_lnum_t n_elts = med_t->local_mesh->n_elts;
@@ -1809,7 +1811,7 @@ _compute_intersection_volume_med(user_profile_med_t *med_t,
  *----------------------------------------------------------------------------*/
 
 static void
-_compute_cell_vol_per_layer_med(user_profile_t *profile)
+_compute_cell_vol_per_layer_med([[maybe_unused]] user_profile_t *profile)
 {
 #if defined(HAVE_MEDCOUPLING)
 
@@ -1821,14 +1823,14 @@ _compute_cell_vol_per_layer_med(user_profile_t *profile)
   // profile shorter variables
   cs_lnum_t n_layers = profile->n_layers;
 
-  cs_real_t *cells_l_id_vol = NULL;
-  BFT_MALLOC(cells_l_id_vol, n_cells_with_ghosts, cs_real_t);
+  cs_real_t *cells_l_id_vol = nullptr;
+  CS_MALLOC(cells_l_id_vol, n_cells_with_ghosts, cs_real_t);
 
   // define pointer and variable for cs_selector
   cs_lnum_t  n_selected_cells = 0;
-  cs_lnum_t *selected_cells   = NULL;
+  cs_lnum_t *selected_cells   = nullptr;
   // Allocate memory for the cells list which will be populated by cs_selector
-  BFT_MALLOC(selected_cells, n_cells_with_ghosts, cs_lnum_t);
+  CS_MALLOC(selected_cells, n_cells_with_ghosts, cs_lnum_t);
 
   cs_selector_get_cell_list(
     profile->criteria, &n_selected_cells, selected_cells);
@@ -1857,8 +1859,8 @@ _compute_cell_vol_per_layer_med(user_profile_t *profile)
     }
   }
 
-  BFT_FREE(cells_l_id_vol);
-  BFT_FREE(selected_cells);
+  CS_FREE(cells_l_id_vol);
+  CS_FREE(selected_cells);
 
 #endif
 }
@@ -1876,13 +1878,13 @@ _free_profile_all(user_profile_t *profile)
   // free stl meshes
   for (int s_id = 0; s_id < profile->n_layers; s_id++) {
     cs_stl_mesh_t *stl_mesh = profile->mesh_list[s_id];
-    BFT_FREE(stl_mesh->coords);
-    BFT_FREE(stl_mesh->seed_coords);
-    BFT_FREE(stl_mesh->ext_mesh);
-    BFT_FREE(stl_mesh);
+    CS_FREE(stl_mesh->coords);
+    CS_FREE(stl_mesh->seed_coords);
+    CS_FREE(stl_mesh->ext_mesh);
+    CS_FREE(stl_mesh);
   }
 
-  BFT_FREE(profile->mesh_list);
+  CS_FREE(profile->mesh_list);
 
 #if defined(HAVE_MEDCOUPLING)
   /* Free med mesh if created */
@@ -1892,10 +1894,10 @@ _free_profile_all(user_profile_t *profile)
     for (int m_id = 0; m_id < profile->n_layers; m_id++) {
       med_t->layer_mesh[m_id]->decrRef();
     }
-    BFT_FREE(med_t->layer_mesh);
+    CS_FREE(med_t->layer_mesh);
     // Mesh will deallocated afterwards since it can be shared
-    med_t->local_mesh = NULL;
-    BFT_FREE(profile->med_mesh_struct);
+    med_t->local_mesh = nullptr;
+    CS_FREE(profile->med_mesh_struct);
   }
 
 #endif
@@ -1905,21 +1907,21 @@ _free_profile_all(user_profile_t *profile)
     user_histogram_t *histogram = profile->histogram_list[l_id];
     user_destroy_histogram(histogram);
   }
-  BFT_FREE(profile->histogram_list);
+  CS_FREE(profile->histogram_list);
 
-  BFT_FREE(profile->l_thick);
-  BFT_FREE(profile->pos);
-  BFT_FREE(profile->pos_n);
-  BFT_FREE(profile->n_cells);
-  BFT_FREE(profile->weigth);
-  BFT_FREE(profile->mean_f);
-  BFT_FREE(profile->mean_f_n);
-  BFT_FREE(profile->sd_f);
-  BFT_FREE(profile->sd_f_n);
+  CS_FREE(profile->l_thick);
+  CS_FREE(profile->pos);
+  CS_FREE(profile->pos_n);
+  CS_FREE(profile->n_cells);
+  CS_FREE(profile->weigth);
+  CS_FREE(profile->mean_f);
+  CS_FREE(profile->mean_f_n);
+  CS_FREE(profile->sd_f);
+  CS_FREE(profile->sd_f_n);
 
   for (int layer_id = 0; layer_id < profile->n_layers; layer_id++)
-    BFT_FREE(profile->cells_layer_vol[layer_id]);
-  BFT_FREE(profile->cells_layer_vol);
+    CS_FREE(profile->cells_layer_vol[layer_id]);
+  CS_FREE(profile->cells_layer_vol);
 }
 
 /*----------------------------------------------------------------------------
@@ -1940,7 +1942,7 @@ _output_profile_setup_log(user_profile_t  *profile,
   char filename[80];
 
   sprintf(filename, "%s/profile.log", dirname);
-  FILE *ptrSetupLog = NULL;
+  FILE *ptrSetupLog = nullptr;
 
   ptrSetupLog = fopen(filename,
                       "w+"); /* create the file (should not exist
@@ -2036,12 +2038,12 @@ _output_profile_log(user_profile_t  *profile,
 
   char filename[80];
   sprintf(filename, "%s/profile.log", dirname);
-  FILE *ptrLog = NULL;
+  FILE *ptrLog = nullptr;
 
   ptrLog = fopen(filename,
                  "a+"); // File already created when this function is called
 
-  cs_time_step_t *ts = cs_get_glob_time_step();
+  const cs_time_step_t *ts = cs_glob_time_step;
 
   fprintf(ptrLog,
           "\n\n"
@@ -2115,8 +2117,8 @@ _output_profile_values_csv(user_profile_t  *profile,
                            const char      *dirname)
 {
   /* Profile shorter variables */
-  cs_lnum_t       n_layers = profile->n_layers;
-  cs_time_step_t *ts       = cs_get_glob_time_step();
+  cs_lnum_t             n_layers = profile->n_layers;
+  const cs_time_step_t *ts = cs_glob_time_step;
 
   cs_lnum_t   n_l_header = 7;
   const char *layer_header[]
@@ -2130,13 +2132,13 @@ _output_profile_values_csv(user_profile_t  *profile,
   char filename[80];
 
   sprintf(filename, "%s/results_profile.csv", dirname);
-  FILE *ptrResults = NULL;
+  FILE *ptrResults = nullptr;
 
   /* Check if the file exist*/
   ptrResults = fopen(filename, "r+"); /* Create the file (should not exist
                                          when this function is called) */
 
-  if (ptrResults == NULL) {
+  if (ptrResults == nullptr) {
     /* Create a file and write header*/
     ptrResults = fopen(filename, "w+");
     fprintf(ptrResults, "time_step, time");
@@ -2201,8 +2203,8 @@ _user_output_profile_stl_mesh(user_profile_t  *profile,
  *----------------------------------------------------------------------------*/
 
 static void
-_output_profile_med_mesh(user_profile_t  *profile,
-                         const char      *dirname)
+_output_profile_med_mesh([[maybe_unused]] user_profile_t  *profile,
+                         [[maybe_unused]] const char      *dirname)
 {
 #if defined(HAVE_MEDCOUPLING_LOADER)
   if (cs_glob_rank_id <= 0) {
@@ -2236,7 +2238,7 @@ BEGIN_C_DECLS
 user_profile_t *
 user_profile_get_by_name(const char  *name)
 {
-  user_profile_t *ptr = NULL;
+  user_profile_t *ptr = nullptr;
   for (int p_id = 0; p_id < _profile_list.n_profiles; p_id++) {
     user_profile_t *profile = _profile_list.profile_list[p_id];
     int             test      = strcmp(profile->name, name);
@@ -2280,38 +2282,38 @@ user_create_profile(const char  *name,
 
   user_profile_t *profile = user_profile_get_by_name(name);
 
-  if (profile != NULL) {
+  if (profile != nullptr) {
     bft_printf("profile %s already exist - profile not created \n", name);
     return profile;
   }
 
   _profile_list.n_profiles++;
-  BFT_REALLOC(_profile_list.profile_list,
-              _profile_list.n_profiles,
-              user_profile_t *);
+  CS_REALLOC(_profile_list.profile_list,
+             _profile_list.n_profiles,
+             user_profile_t *);
 
   const cs_lnum_t   n_cells  = cs_glob_mesh->n_cells;
 
   // Initialize and allocate memory for profile
-  BFT_MALLOC(profile, 1, user_profile_t);
+  CS_MALLOC(profile, 1, user_profile_t);
 
-  char *_dummy = (char *)profile->name;
-  strncpy(_dummy, name, strlen(name));
-  _dummy[strlen(name)] = '\0';
+  char *_dummy = const_cast<char *>(profile->name);
+  strncpy(_dummy, name, 511);
+  _dummy[511] = '\0';
 
-  _dummy = (char *)profile->field;
-  strncpy(_dummy, field, strlen(field));
-  _dummy[strlen(field)] = '\0';
+  _dummy = const_cast<char *>(profile->field);
+  strncpy(_dummy, field, 511);
+  _dummy[511] = '\0';
 
-  _dummy = (char *)profile->criteria;
-  strncpy(_dummy, criteria, strlen(criteria));
-  _dummy[strlen(criteria)] = '\0';
+  _dummy = const_cast<char *>(profile->criteria);
+  strncpy(_dummy, criteria, 511);
+  _dummy[511] = '\0';
 
   profile->n_layers        = n_layers;
 
-  _dummy = (char *)profile->progression_law;
-  strncpy(_dummy, progression_law, strlen(progression_law));
-  _dummy[strlen(progression_law)] = '\0';
+  _dummy = const_cast<char *>(profile->progression_law);
+  strncpy(_dummy, progression_law, 511);
+  _dummy[511] = '\0';
 
   profile->progression     = progression;
 
@@ -2327,9 +2329,9 @@ user_create_profile(const char  *name,
               __func__);
 
 
-  _dummy = (char *)profile->weighted;
-  strncpy(_dummy, weighted, strlen(weighted));
-  _dummy[strlen(weighted)] = '\0';
+  _dummy = const_cast<char *>(profile->weighted);
+  strncpy(_dummy, weighted, 511);
+  _dummy[511] = '\0';
 
   /* In case of Medcoupling method, check CS has been compiled with
    * MEDCouppling*/
@@ -2343,33 +2345,33 @@ user_create_profile(const char  *name,
                 "MEDCoupling support.\n"));
 #endif
   }
-  _dummy = (char *)profile->intersect_method;
-  strncpy(_dummy, intersect_method, strlen(intersect_method));
-  _dummy[strlen(intersect_method)] = '\0';
+  _dummy = const_cast<char *>(profile->intersect_method);
+  strncpy(_dummy, intersect_method, 511);
+  _dummy[511] = '\0';
 
-  BFT_MALLOC(profile->l_thick, n_layers, cs_real_t);
-  BFT_MALLOC(profile->pos, n_layers, cs_real_t);
-  BFT_MALLOC(profile->pos_n, n_layers, cs_real_t);
-  BFT_MALLOC(profile->n_cells, n_layers, cs_lnum_t);
-  BFT_MALLOC(profile->weigth, n_layers, cs_real_t);
-  BFT_MALLOC(profile->mean_f, n_layers, cs_real_t);
-  BFT_MALLOC(profile->mean_f_n, n_layers, cs_real_t);
-  BFT_MALLOC(profile->sd_f, n_layers, cs_real_t);
-  BFT_MALLOC(profile->sd_f_n, n_layers, cs_real_t);
-  BFT_MALLOC(profile->cells_layer_vol, n_layers, cs_real_t *);
+  CS_MALLOC(profile->l_thick, n_layers, cs_real_t);
+  CS_MALLOC(profile->pos, n_layers, cs_real_t);
+  CS_MALLOC(profile->pos_n, n_layers, cs_real_t);
+  CS_MALLOC(profile->n_cells, n_layers, cs_lnum_t);
+  CS_MALLOC(profile->weigth, n_layers, cs_real_t);
+  CS_MALLOC(profile->mean_f, n_layers, cs_real_t);
+  CS_MALLOC(profile->mean_f_n, n_layers, cs_real_t);
+  CS_MALLOC(profile->sd_f, n_layers, cs_real_t);
+  CS_MALLOC(profile->sd_f_n, n_layers, cs_real_t);
+  CS_MALLOC(profile->cells_layer_vol, n_layers, cs_real_t *);
   for (int layer_id = 0; layer_id < n_layers; layer_id++)
-    BFT_MALLOC(profile->cells_layer_vol[layer_id], n_cells, cs_real_t);
+    CS_MALLOC(profile->cells_layer_vol[layer_id], n_cells, cs_real_t);
 
-  BFT_MALLOC(profile->mesh_list, n_layers, cs_stl_mesh_t *);
+  CS_MALLOC(profile->mesh_list, n_layers, cs_stl_mesh_t *);
   for (int layer_id = 0; layer_id < n_layers; layer_id++)
-    BFT_MALLOC(profile->mesh_list[layer_id], 1, cs_stl_mesh_t);
+    CS_MALLOC(profile->mesh_list[layer_id], 1, cs_stl_mesh_t);
 
   /* Allocate mesh med struct*/
   if (test_med == 0)
     profile->med_mesh_struct = _allocate_med_mesh_struct(n_layers);
 
   /* Allocate array of histogram */
-  BFT_MALLOC(profile->histogram_list, n_layers, user_histogram_t *);
+  CS_MALLOC(profile->histogram_list, n_layers, user_histogram_t *);
   for (int layer_id = 0; layer_id < n_layers; layer_id++) {
     char pname[100];
     sprintf(pname, "layer_%d", layer_id);
@@ -2398,11 +2400,11 @@ user_create_profile(const char  *name,
 
     memset(stl_mesh->header, 0, 80);
     stl_mesh->n_faces     = 0;
-    stl_mesh->coords      = NULL;
+    stl_mesh->coords      = nullptr;
     stl_mesh->n_seeds     = 0;
-    stl_mesh->seed_coords = NULL;
+    stl_mesh->seed_coords = nullptr;
     stl_mesh->is_porous   = false;
-    stl_mesh->ext_mesh    = NULL;
+    stl_mesh->ext_mesh    = nullptr;
 
     for (cs_lnum_t c_id = 0; c_id < n_cells; c_id++)
       profile->cells_layer_vol[layer_id][c_id] = 0.0;
@@ -2452,11 +2454,11 @@ user_create_histogram(char        *name,
 {
   user_histogram_t *histogram;
 
-  BFT_MALLOC(histogram, 1, user_histogram_t);
-  BFT_MALLOC(histogram->h_i, n_bins_max, cs_real_t);
-  BFT_MALLOC(histogram->l_i, n_bins_max, cs_real_t);
-  BFT_MALLOC(histogram->c_i, n_bins_max, cs_real_t);
-  BFT_MALLOC(histogram->name, 105, char);
+  CS_MALLOC(histogram, 1, user_histogram_t);
+  CS_MALLOC(histogram->h_i, n_bins_max, cs_real_t);
+  CS_MALLOC(histogram->l_i, n_bins_max, cs_real_t);
+  CS_MALLOC(histogram->c_i, n_bins_max, cs_real_t);
+  CS_MALLOC(histogram->name, 105, char);
 
   /* Populate histogram general informations */
   sprintf(histogram->name, "%s", name);
@@ -2533,12 +2535,12 @@ user_histogram_compute(user_histogram_t  *histogram,
 void
 user_destroy_histogram(user_histogram_t  *histogram)
 {
-  BFT_FREE(histogram->name);
-  BFT_FREE(histogram->h_i);
-  BFT_FREE(histogram->l_i);
-  BFT_FREE(histogram->c_i);
+  CS_FREE(histogram->name);
+  CS_FREE(histogram->h_i);
+  CS_FREE(histogram->l_i);
+  CS_FREE(histogram->c_i);
 
-  BFT_FREE(histogram);
+  CS_FREE(histogram);
 }
 
 /*----------------------------------------------------------------------------
@@ -2555,7 +2557,6 @@ user_destroy_histogram(user_histogram_t  *histogram)
 void
 user_compute_cell_volume_per_layer(user_profile_t *profile)
 {
-  user_profile_med_t *med_t = profile->med_mesh_struct;
   if (strcmp(profile->intersect_method, "MEDCOUPLING") == 0) {
 #if !defined(HAVE_MEDCOUPLING)
     bft_error(__FILE__,
@@ -2564,9 +2565,7 @@ user_compute_cell_volume_per_layer(user_profile_t *profile)
               _("Error: This intersection method cannot be called without "
                 "MEDCoupling support.\n"));
 #else
-
     _compute_cell_vol_per_layer_med(profile);
-
 #endif
   }
   else if (strcmp(profile->intersect_method, "STL") == 0) {
@@ -2622,8 +2621,8 @@ user_profile_compute(user_profile_t  *profile)
   cs_real_t min_field = DBL_MAX;
   cs_real_t max_field = DBL_MIN;
 
-  BFT_MALLOC(sample, n_cells, cs_real_t);
-  BFT_MALLOC(weights, n_cells, cs_real_t);
+  CS_MALLOC(sample, n_cells, cs_real_t);
+  CS_MALLOC(weights, n_cells, cs_real_t);
   cs_lnum_t n_elts_sample = 0;
 
   for (int l_id = 0; l_id < n_layers; l_id++) {
@@ -2639,7 +2638,7 @@ user_profile_compute(user_profile_t  *profile)
     for (cs_lnum_t iel = 0; iel < n_elts_sample; iel++)
       profile->weigth[l_id] += weights[iel];
 
-    cs_parall_sum(1, CS_DOUBLE, &profile->weigth[l_id]);
+    cs_parall_sum(1, CS_REAL_TYPE, &profile->weigth[l_id]);
 
     user_histogram_compute(histogram, sample, weights, n_elts_sample);
 
@@ -2647,13 +2646,13 @@ user_profile_compute(user_profile_t  *profile)
     profile->mean_f[l_id] = histogram->mean;
     profile->sd_f[l_id]   = histogram->sd;
 
-    min_field = CS_MIN(min_field, histogram->min);
-    max_field = CS_MAX(max_field, histogram->max);
+    min_field = cs::min(min_field, histogram->min);
+    max_field = cs::max(max_field, histogram->max);
   }
 
   /*update min and max field over all layer and all MPI ranks*/
-  cs_parall_min(1, CS_DOUBLE, &min_field);
-  cs_parall_max(1, CS_DOUBLE, &max_field);
+  cs_parall_min(1, CS_REAL_TYPE, &min_field);
+  cs_parall_max(1, CS_REAL_TYPE, &max_field);
 
   profile->min_field = min_field;
   profile->max_field = max_field;
@@ -2682,8 +2681,8 @@ user_profile_compute(user_profile_t  *profile)
     }
   }
 
-  BFT_FREE(sample);
-  BFT_FREE(weights);
+  CS_FREE(sample);
+  CS_FREE(weights);
 }
 
 /*----------------------------------------------------------------------------
@@ -2714,7 +2713,7 @@ void
 user_profile_output(user_profile_t  *profile,
                     int              interval)
 {
-  cs_time_step_t *ts = cs_get_glob_time_step();
+  const cs_time_step_t *ts = cs_glob_time_step;
 
   if (ts->nt_cur % interval != 0)
     return;
@@ -2805,7 +2804,7 @@ user_output_histogram_csv(user_histogram_t  *histogram,
                           const char        *dirname)
 {
   /*shorter cs variables*/
-  cs_time_step_t *ts = cs_get_glob_time_step();
+  const cs_time_step_t *ts = cs_glob_time_step;
 
   char filename[200];
 
@@ -2828,12 +2827,12 @@ user_output_histogram_csv(user_histogram_t  *histogram,
 
   n_l_header = sizeof(histogram_header) / sizeof(char *);
 
-  FILE *ptrResults = NULL;
+  FILE *ptrResults = nullptr;
 
   /* Check if the file exist*/
   ptrResults = fopen(filename, "r+");
 
-  if (ptrResults == NULL) {
+  if (ptrResults == nullptr) {
     /* Create a file and write header*/
     ptrResults = fopen(filename, "w+");
 
@@ -2899,13 +2898,13 @@ user_histogram_ot_output(user_histogram_t  *histogram,
  *----------------------------------------------------------------------------*/
 
 void
-user_profile_histogram_ot_output(user_profile_t  *profile,
-                                 int              interval)
+user_profile_histogram_ot_output([[maybe_unused]] user_profile_t  *profile,
+                                 [[maybe_unused]] int              interval)
 {
 #if HAVE_OT == 1
   /*Output the PDF historgam thks to OT lib features*/
   /*Assume histograms directory already created*/
-  cs_time_step_t *ts = cs_get_glob_time_step();
+  const cs_time_step_t *ts = cs_glob_time_step;
 
   cs_lnum_t n_layers = profile->n_layers;
 
@@ -2957,7 +2956,7 @@ user_free_profiles(void)
     _free_profile_all(profile);
   }
   _profile_list.n_profiles = 0;
-  BFT_FREE(_profile_list.profile_list);
+  CS_FREE(_profile_list.profile_list);
 }
 
 /*----------------------------------------------------------------------------*/
