@@ -7,9 +7,9 @@ var cs__fan_8h =
     [ "cs_fan_compute_force", "cs__fan_8h.html#a0a772f1fee352b6b17d692438a0b1e1b", null ],
     [ "cs_fan_define", "cs__fan_8h.html#ac970888ce7767b56d672b1be519cbd69", null ],
     [ "cs_fan_destroy_all", "cs__fan_8h.html#ac2f51ea067bfd59a2b78c553cc99a116", null ],
+    [ "cs_fan_field_create", "cs__fan_8h.html#aa965fb5e31cc1c433cfd96473d60174e", null ],
     [ "cs_fan_flag_cells", "cs__fan_8h.html#ada767fe26f90192409ea1eb97b79660a", null ],
     [ "cs_fan_log_iteration", "cs__fan_8h.html#ad50016ec51d614570005d911bce4e600", null ],
     [ "cs_fan_log_setup", "cs__fan_8h.html#a2a4f4cd47bd42917f32401b79dca7aea", null ],
-    [ "cs_fan_n_fans", "cs__fan_8h.html#aa87b179a6e7b71065a41fe9634c8dd21", null ],
-    [ "debvtl", "cs__fan_8h.html#a2189211e20d6e4c1da08b4a028cfafe0", null ]
+    [ "cs_fan_n_fans", "cs__fan_8h.html#aa87b179a6e7b71065a41fe9634c8dd21", null ]
 ];
\ No newline at end of file
