@@ -1,15 +1,14 @@
 var cs__gui__mobile__mesh_8h =
 [
     [ "cs_gui_ale_diffusion_type", "cs__gui__mobile__mesh_8h.html#a8b0312867cefaabc02fee71f5a073c94", null ],
+    [ "cs_gui_ale_params", "cs__gui__mobile__mesh_8h.html#a53313fb7b39d184b4931c1d262fb5cad", null ],
     [ "cs_gui_get_ale_viscosity_type", "cs__gui__mobile__mesh_8h.html#a1b0473a02ce42cd839747be95379e62f", null ],
     [ "cs_gui_mesh_viscosity", "cs__gui__mobile__mesh_8h.html#ab6fcf2b04a9f0446341fba6ef69af1b2", null ],
-    [ "cs_gui_mobile_mesh_bc_structures", "cs__gui__mobile__mesh_8h.html#ab20e677eb1189b543365ea7687c62807", null ],
+    [ "cs_gui_mobile_mesh_bc_structures", "cs__gui__mobile__mesh_8h.html#a38f4fbab587f32cc8896b3306b524e19", null ],
     [ "cs_gui_mobile_mesh_boundary_conditions", "cs__gui__mobile__mesh_8h.html#afb29e3097e09c932d1bf90217e00c9ee", null ],
     [ "cs_gui_mobile_mesh_get_boundaries", "cs__gui__mobile__mesh_8h.html#a87983dc30715413e7b01b72e3c5044d7", null ],
-    [ "cs_gui_mobile_mesh_get_fixed_velocity", "cs__gui__mobile__mesh_8h.html#a6784ce1ec61ca4a157ba9ec29ce788ff", null ],
-    [ "cs_gui_mobile_mesh_init_structures", "cs__gui__mobile__mesh_8h.html#a8ba6f1e726f7de1215ceb95fcc5525cf", null ],
+    [ "cs_gui_mobile_mesh_get_fixed_velocity", "cs__gui__mobile__mesh_8h.html#a5952070f04a5989205b0ab47171af6ba", null ],
+    [ "cs_gui_mobile_mesh_init_structures", "cs__gui__mobile__mesh_8h.html#a5e765e04d5488b38f77d11d76cfb0420", null ],
     [ "cs_gui_mobile_mesh_internal_structures", "cs__gui__mobile__mesh_8h.html#a70b15549420c26084c84baa9a80e0fdc", null ],
-    [ "cs_gui_mobile_mesh_structures_add", "cs__gui__mobile__mesh_8h.html#ac8b0389a7572b3635aa506475b7a9261", null ],
-    [ "uialin", "cs__gui__mobile__mesh_8h.html#a48166ab117f9dc486727d68cb965b026", null ],
-    [ "uiaste", "cs__gui__mobile__mesh_8h.html#a664d8d3b4a9b2f50a72a0c52f359731d", null ]
+    [ "cs_gui_mobile_mesh_structures_add", "cs__gui__mobile__mesh_8h.html#ac8b0389a7572b3635aa506475b7a9261", null ]
 ];
\ No newline at end of file
