@@ -1,7 +1,9 @@
 var cs__les__mu__t_8h =
 [
+    [ "cs_les_mu_t_ksgs", "cs__les__mu__t_8h.html#a3d8aebd403e9d16da107bb904e2848d1", null ],
     [ "cs_les_mu_t_smago_const", "cs__les__mu__t_8h.html#af7d775ae96ee0189765b5583217af08d", null ],
     [ "cs_les_mu_t_smago_dyn", "cs__les__mu__t_8h.html#a30585b0b64c4bd07d2b487d05dfd4fbf", null ],
     [ "cs_les_mu_t_smago_dyn_prepare", "cs__les__mu__t_8h.html#a973101a584e77e7649013c14462c93f6", null ],
+    [ "cs_les_mu_t_tausgs", "cs__les__mu__t_8h.html#a30988c9986ee070d211448e0af479818", null ],
     [ "cs_les_mu_t_wale", "cs__les__mu__t_8h.html#aec416185c8f93dc4048b662c7be5335d", null ]
 ];
\ No newline at end of file
