@@ -10,6 +10,5 @@ var cs__preprocessor__data_8h =
     [ "cs_preprocessor_data_get_restart_mode", "cs__preprocessor__data_8h.html#a33ea5f04ce40637e05b3f17c99c37dd9", null ],
     [ "cs_preprocessor_data_read_headers", "cs__preprocessor__data_8h.html#a24c57dc9c3e9ad31aef5fde7c011a450", null ],
     [ "cs_preprocessor_data_read_mesh", "cs__preprocessor__data_8h.html#a6913da3a5774bbd32214194eee5b8699", null ],
-    [ "cs_preprocessor_data_set_restart_mode", "cs__preprocessor__data_8h.html#a9c91d5ca326f2e046366873f420123d9", null ],
-    [ "ledevi", "cs__preprocessor__data_8h.html#abb5572bcf71c0fa95b714597d2753307", null ]
+    [ "cs_preprocessor_data_set_restart_mode", "cs__preprocessor__data_8h.html#a9c91d5ca326f2e046366873f420123d9", null ]
 ];
\ No newline at end of file
