@@ -7,6 +7,8 @@ var cs__time__control_8h =
       [ "CS_TIME_CONTROL_TIME", "cs__time__control_8h.html#a1636eab5864ccb745a34de2ac9b1ae18a91699746a1a082dd1a84e362ba6b2c3c", null ],
       [ "CS_TIME_CONTROL_FUNCTION", "cs__time__control_8h.html#a1636eab5864ccb745a34de2ac9b1ae18a1946237a368e8c8a42161f4cd246c68d", null ]
     ] ],
+    [ "cs_time_control_copy", "cs__time__control_8h.html#a989401696c4f836ce2f647d9fcda896f", null ],
+    [ "cs_time_control_copy_from_default", "cs__time__control_8h.html#a5482001d238bc4a75acf5ffe5bee4be8", null ],
     [ "cs_time_control_get_description", "cs__time__control_8h.html#a9416c6710daea3aed96a6c15c302d32e", null ],
     [ "cs_time_control_init_by_func", "cs__time__control_8h.html#adbd8ab7d4a40f9567190b68048b92b9b", null ],
     [ "cs_time_control_init_by_time", "cs__time__control_8h.html#acb18a8a30b1fd956c1338566968b501d", null ],
