@@ -6,10 +6,11 @@ var cs__timer_8h =
     [ "CS_TIMER_COUNTER_INIT", "cs__timer_8h.html#a0ec4c95c1e50f0f07a19ae1d83674ab8", null ],
     [ "cs_timer_counter_add_diff", "cs__timer_8h.html#a1a64fa3f54bb8431c0671e9741f1f993", null ],
     [ "cs_timer_cpu_time", "cs__timer_8h.html#a94bbc0babba71eb3af257b8e7d17f79a", null ],
-    [ "cs_timer_cpu_time_method", "cs__timer_8h.html#a81ba43596d2b1594c4ca400675492d40", null ],
+    [ "cs_timer_cpu_time_method", "cs__timer_8h.html#a35f2ce2e7cfb402a2120f906a54a6f84", null ],
     [ "cs_timer_cpu_times", "cs__timer_8h.html#a38f0818c95c3cc0a03cf16d1a5b7a019", null ],
     [ "cs_timer_diff", "cs__timer_8h.html#a9a724ea3c37de419cf62d17660b6d499", null ],
     [ "cs_timer_time", "cs__timer_8h.html#a7d5d2345df8b074f098e6f62c685b983", null ],
     [ "cs_timer_wtime", "cs__timer_8h.html#a08f64132a9fa24cf2634fc6153d1e64e", null ],
-    [ "cs_timer_wtime_method", "cs__timer_8h.html#abfa463ae26871fcc32633839efa389fa", null ]
+    [ "cs_timer_wtime_method", "cs__timer_8h.html#a1f016a22250f299e0d8d77d67c022815", null ],
+    [ "cs_glob_timer_kernels_flag", "cs__timer_8h.html#a272499efbdb8f1512e2833a4fa081faf", null ]
 ];
\ No newline at end of file
