@@ -2,7 +2,5 @@ var group__vof =
 [
     [ "Masks used to specify Volume of Fluid models", "group__vof__masks.html", "group__vof__masks" ],
     [ "Mixture properties", "group__vof__mixture__properties.html", "group__vof__mixture__properties" ],
-    [ "Cavitation model", "group__cavitation.html", "group__cavitation" ],
-    [ "idrift", "group__vof.html#ga3eaa0b0a074424fce04a6da4fb2f819d", null ],
-    [ "ivofmt", "group__vof.html#ga4177d46429e1b533235c38300b44eeae", null ]
+    [ "Cavitation model", "group__cavitation.html", "group__cavitation" ]
 ];
\ No newline at end of file
