@@ -1,17 +1,18 @@
 var indexSectionsWithContent =
 {
-  0: "_abcdefghijklmnopqrstuvwxyz",
-  1: "_abcdefgilmprstuvy",
-  2: "acdeflmnoprstv",
-  3: "abcdefgiklmnopqrstuvw",
-  4: "_abcdefghijklmnprstuvwy",
+  0: "<_abcdefghijklmnopqrstuvwxyz~",
+  1: "_acdfmpt",
+  2: "acfmop",
+  3: "abcdfgikmnopqrstuw",
+  4: "_abcdefgilmnoprstuvwz~",
   5: "_abcdefghijklmnopqrstuvwxyz",
-  6: "bcf",
-  7: "cf",
+  6: "abcdftu",
+  7: "cfl",
   8: "acdefghijklmnopqrstuvwxyz",
-  9: "_bcdefghikmnprtu",
-  10: "abcdefghilmnopstv",
-  11: "abcdefghilmnpqrstuvw"
+  9: "as",
+  10: "_bcdefghikmnprtu",
+  11: "acdfghimnpstv",
+  12: "<abcdefghilmnpqrstuvw"
 };
 
 var indexSectionNames =
@@ -25,15 +26,16 @@ var indexSectionNames =
   6: "typedefs",
   7: "enums",
   8: "enumvalues",
-  9: "defines",
-  10: "groups",
-  11: "pages"
+  9: "related",
+  10: "defines",
+  11: "groups",
+  12: "pages"
 };
 
 var indexSectionLabels =
 {
   0: "All",
-  1: "Data Structures",
+  1: "Classes",
   2: "Namespaces",
   3: "Files",
   4: "Functions",
@@ -41,8 +43,9 @@ var indexSectionLabels =
   6: "Typedefs",
   7: "Enumerations",
   8: "Enumerator",
-  9: "Macros",
-  10: "Modules",
-  11: "Pages"
+  9: "Friends",
+  10: "Macros",
+  11: "Modules",
+  12: "Pages"
 };
 
