@@ -1,7 +1,9 @@
 var structcs__equation__system__param__t =
 [
     [ "block_var_dim", "structcs__equation__system__param__t.html#a4fb68bfb14d3d8fcee534e266c1de546", null ],
+    [ "incremental_solve", "structcs__equation__system__param__t.html#af832f27939f42534a37a738dd47ab748", null ],
     [ "name", "structcs__equation__system__param__t.html#ab74e6bf80237ddc4109968cedc58c151", null ],
+    [ "relax_pty", "structcs__equation__system__param__t.html#a88969a8ee8ec6c256e9d1820b488f9d3", null ],
     [ "sles_param", "structcs__equation__system__param__t.html#a1ed8a3a67e2ade90d16d98201b62a534", null ],
     [ "sles_strategy", "structcs__equation__system__param__t.html#a7328793379ef1e9eae9e8c9e7ed9ea40", null ],
     [ "space_scheme", "structcs__equation__system__param__t.html#af22d0d3b0ea61d6ac393712bbc4e824f", null ],
