@@ -1,6 +1,5 @@
 var structcs__field__bc__coeffs__t =
 [
-    [ "_hext", "structcs__field__bc__coeffs__t.html#af885c2bf10eec2d85d1b62537b1b36b6", null ],
     [ "a", "structcs__field__bc__coeffs__t.html#a4124bc0a9335c27f086f24ba207a4912", null ],
     [ "ac", "structcs__field__bc__coeffs__t.html#a9063eb76c0cc024f54d08e4afdf284a3", null ],
     [ "ad", "structcs__field__bc__coeffs__t.html#a44d9dbb60b6c2c24922cd62d249412f9", null ],
@@ -9,10 +8,15 @@ var structcs__field__bc__coeffs__t =
     [ "bc", "structcs__field__bc__coeffs__t.html#a14999c4ae2ddabd6cec2230bf6817c08", null ],
     [ "bd", "structcs__field__bc__coeffs__t.html#ab902b0b77052eb54e74c3947bac33e85", null ],
     [ "bf", "structcs__field__bc__coeffs__t.html#a9d6235c623541ab4175144c028436097", null ],
+    [ "flux", "structcs__field__bc__coeffs__t.html#ae35041ca69e739118834c2a12872d994", null ],
+    [ "flux_lim", "structcs__field__bc__coeffs__t.html#af04be8221f2d1cf0328d8030907f66aa", null ],
     [ "hint", "structcs__field__bc__coeffs__t.html#a5949df62722e5dd4de75e19a0487b42a", null ],
     [ "icodcl", "structcs__field__bc__coeffs__t.html#aef9f38ed73b3830c3b5072a817a018fb", null ],
     [ "location_id", "structcs__field__bc__coeffs__t.html#a08ee638b5ed01945e74202e4908f762c", null ],
     [ "rcodcl1", "structcs__field__bc__coeffs__t.html#a93de324443a76f21816304361a34d7f3", null ],
     [ "rcodcl2", "structcs__field__bc__coeffs__t.html#a0689c3b3e63071fa148ea5fff8c29400", null ],
-    [ "rcodcl3", "structcs__field__bc__coeffs__t.html#a1a191254f1753cb5415f76699fb1a3b9", null ]
+    [ "rcodcl3", "structcs__field__bc__coeffs__t.html#a1a191254f1753cb5415f76699fb1a3b9", null ],
+    [ "val_f", "structcs__field__bc__coeffs__t.html#ad481ddd96d6b68a440086593503f27a7", null ],
+    [ "val_f_lim", "structcs__field__bc__coeffs__t.html#a2193a4dc4e49f68ae7d6320700434476", null ],
+    [ "val_f_pre", "structcs__field__bc__coeffs__t.html#abd2fc4e327c7eb3891bb8e41e84f34f5", null ]
 ];
\ No newline at end of file
