@@ -1,18 +1,19 @@
 var structcs__halo__t =
 [
-    [ "c_domain_group", "structcs__halo__t.html#acd388a72e04cf97e6f2fd01f9b484f69", null ],
     [ "c_domain_rank", "structcs__halo__t.html#a7f464e09144e3b7c07dfd4a105258da2", null ],
-    [ "c_domain_s_shift", "structcs__halo__t.html#adbbc4e7e79ad01d7c95f12b1e6a14c1c", null ],
     [ "index", "structcs__halo__t.html#a1e9e5714c0580fe06817d4c33d6cc0c8", null ],
     [ "n_c_domains", "structcs__halo__t.html#a70266a0b5b78cbaac3b253099487f4ad", null ],
     [ "n_elts", "structcs__halo__t.html#af8d8d2589bec20a4bcfc1fe7c1921472", null ],
     [ "n_local_elts", "structcs__halo__t.html#a4dd863c3bc97cdb7a4475afdb9eb7c3e", null ],
     [ "n_rotations", "structcs__halo__t.html#a4406e467c2238281d60d76a610fd9b9d", null ],
     [ "n_send_elts", "structcs__halo__t.html#ae2c70c522d758012ac6bae250682d8ef", null ],
+    [ "n_std_send_blocks", "structcs__halo__t.html#a51cefcc8d01bdeada5b5b94428e66db6", null ],
     [ "n_transforms", "structcs__halo__t.html#a08ee5e0c41c86a3e6c93ca15fc824ae2", null ],
     [ "perio_lst", "structcs__halo__t.html#a8d5a030aa830ab0a8e4343dca10c0658", null ],
     [ "periodicity", "structcs__halo__t.html#aba624699549bea2c12b85a2d55c189aa", null ],
     [ "send_index", "structcs__halo__t.html#a3dffe4be795e90cc6416955b3554d314", null ],
     [ "send_list", "structcs__halo__t.html#a3bbd60c85b2d6f87fddf20a083155e39", null ],
-    [ "send_perio_lst", "structcs__halo__t.html#aae76d596267ddd1b522083b0669ff036", null ]
+    [ "send_perio_lst", "structcs__halo__t.html#aae76d596267ddd1b522083b0669ff036", null ],
+    [ "std_send_block_size", "structcs__halo__t.html#a8d892cc6b04d91484cf00416add71faa", null ],
+    [ "std_send_blocks", "structcs__halo__t.html#a478ec63e8fd3f1043fb8568884cd783d", null ]
 ];
\ No newline at end of file
