@@ -2,6 +2,5 @@ var structcs__inflow__sem__t =
 [
     [ "energy", "structcs__inflow__sem__t.html#ab603e1d5c93f641c4db2748f90feaf62", null ],
     [ "n_structures", "structcs__inflow__sem__t.html#a6f582811d8d6a675f6708660f8e2a366", null ],
-    [ "position", "structcs__inflow__sem__t.html#af37da5ac7b4d1f35edabebbab77e186e", null ],
-    [ "volume_mode", "structcs__inflow__sem__t.html#a16d43c418781837bd20b0d0ebe2e06b9", null ]
+    [ "position", "structcs__inflow__sem__t.html#af37da5ac7b4d1f35edabebbab77e186e", null ]
 ];
\ No newline at end of file
