@@ -1,6 +1,7 @@
 var structcs__lagr__time__scheme__t =
 [
     [ "added_mass_const", "structcs__lagr__time__scheme__t.html#a8131396c9fc07961bda9eb811e166614", null ],
+    [ "cell_wise_integ", "structcs__lagr__time__scheme__t.html#a99066e87ecabb463af087267b2a09142", null ],
     [ "extended_t_scheme", "structcs__lagr__time__scheme__t.html#a448819318f7fe5b01725c37b6709b3e3", null ],
     [ "iadded_mass", "structcs__lagr__time__scheme__t.html#ac85f379c24eb78c135c090fe10701f04", null ],
     [ "iilagr", "structcs__lagr__time__scheme__t.html#ac3d1433050b77f18fb59b8cf4155c596", null ],
@@ -8,5 +9,7 @@ var structcs__lagr__time__scheme__t =
     [ "interpol_field", "structcs__lagr__time__scheme__t.html#a1069ce0fc4421a7e6782dbbfbd6491e8", null ],
     [ "isttio", "structcs__lagr__time__scheme__t.html#a2b656e2a5f36a9ef4e1a967173a2ce88", null ],
     [ "isuila", "structcs__lagr__time__scheme__t.html#a58fc7a12025bc159aab288848628aa67", null ],
+    [ "max_perio_or_rank_crossed", "structcs__lagr__time__scheme__t.html#ae1877c76a367952a1315db5c6928eb87", null ],
+    [ "max_track_propagation_loops", "structcs__lagr__time__scheme__t.html#a9d7b24e21ce36f754e174c580e747766", null ],
     [ "t_order", "structcs__lagr__time__scheme__t.html#ab1ec9c22214a84f4ad978fb24c4bcb51", null ]
 ];
\ No newline at end of file
