@@ -3,6 +3,8 @@ var structcs__navsto__projection__t =
     [ "bdy_pressure_incr", "structcs__navsto__projection__t.html#ad98c9f4b717f26038b967afa227c5a3f", null ],
     [ "correction", "structcs__navsto__projection__t.html#a133a28d73188cd2c98d71880222d6153", null ],
     [ "div_st", "structcs__navsto__projection__t.html#aec540b7795e24f5e089435fec04572b4", null ],
+    [ "phi", "structcs__navsto__projection__t.html#a49724536f655ccfc0c0274b69d6df289", null ],
     [ "predicted_velocity", "structcs__navsto__projection__t.html#a4ab6320527753ec0acfc197d97e40dac", null ],
-    [ "prediction", "structcs__navsto__projection__t.html#a94a2d9506dbf04fb5275240917518c61", null ]
+    [ "prediction", "structcs__navsto__projection__t.html#a94a2d9506dbf04fb5275240917518c61", null ],
+    [ "pressure_incr_gradient", "structcs__navsto__projection__t.html#abcae97ba6b87534d1c17f9159ba9ffb6", null ]
 ];
\ No newline at end of file
